@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,10 +25,10 @@ int main(int argc, char **argv)
 {
 	try
 	{
-		GlobalAttributes::setCustomUiScaleFactor();
+		GlobalAttributes::init(argv[0], true);
 		Application app(argc,argv);
 		QStringList args = app.arguments();
-		app.loadTranslation(QLocale::system().name());
+		app.loadTranslations(QLocale::system().name(), false);
 
 		CrashHandlerForm crashhandler(args.size() > 1 && args[1]==CrashHandlerForm::AnalysisMode);
 		GuiUtilsNs::resizeDialog(&crashhandler);
