@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,20 +18,21 @@
 
 #include "application.h"
 #include <QTranslator>
-#include "guiutilsns.h"
 #include "schemaeditorform.h"
 #include "pgmodelerapp.h"
+#include "exception.h"
+#include "enumtype.h"
 
 int main(int argc, char **argv)
 {
 	try
 	{
-		GlobalAttributes::setCustomUiScaleFactor();
+		GlobalAttributes::init(argv[0], true);
 		PgModelerApp app(argc,argv);
 		QStringList args = app.arguments();
 		SchemaEditorForm syntaxchk;
 
-		app.loadTranslation(QLocale::system().name());
+		app.loadTranslations(QLocale::system().name(), false);
 
 		args.pop_front();
 		syntaxchk.loadFiles(args);
