@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include "aboutsewidget.h"
 #include "baseform.h"
 #include "utilsns.h"
+#include "qtconnectmacros.h"
 
 const QString SchemaEditorForm::UntitledFile = QT_TR_NOOP("(untitled)");
 
@@ -53,7 +54,7 @@ SchemaEditorForm::SchemaEditorForm(QWidget *parent) : QWidget(parent)
 
 	AppearanceConfigWidget appearance_conf_wgt;
 	appearance_conf_wgt.loadConfiguration();
-	appearance_conf_wgt.updateDropShadows();
+	GuiUtilsNs::updateDropShadows(qApp->allWidgets());
 
 	GeneralConfigWidget general_conf_wgt;
 	general_conf_wgt.loadConfiguration();
@@ -108,39 +109,41 @@ subcontrol-position: right center; }");
 
 	syntax_cfg_menu.installEventFilter(this);
 
-	connect(apply_conf_tb, &QToolButton::clicked, this, &SchemaEditorForm::applySyntaxConfig);
-	connect(save_conf_tb, &QToolButton::clicked, this, &SchemaEditorForm::saveSyntaxConfig);
-	connect(reload_conf_tb, &QToolButton::clicked, this, &SchemaEditorForm::loadSyntaxConfig);
+	connect(apply_conf_tb, &QToolButton::clicked, this, __slot(this, SchemaEditorForm::applySyntaxConfig));
+	connect(save_conf_tb, &QToolButton::clicked, this, __slot(this, SchemaEditorForm::saveSyntaxConfig));
+	connect(reload_conf_tb, &QToolButton::clicked, this, __slot(this, SchemaEditorForm::loadSyntaxConfig));
 
 	connect(new_tb, &QToolButton::clicked, this, [this](){
-		addEditorTab();
+		__trycatch( addEditorTab(); )
 	});
 
-	connect(load_tb, &QToolButton::clicked, this, &SchemaEditorForm::loadFile);
+	connect(load_tb, &QToolButton::clicked, this, __slot(this, SchemaEditorForm::loadFile));
 	connect(exit_tb, &QToolButton::clicked, this, &SchemaEditorForm::close);
-	connect(save_tb, &QToolButton::clicked, this, &SchemaEditorForm::saveFile);
+
+	connect(save_tb, &QToolButton::clicked, this, __slot(this, SchemaEditorForm::saveFile));
 	connect(indent_all_tb, &QToolButton::clicked, this, &SchemaEditorForm::indentAll);
-	connect(save_all_tb, &QToolButton::clicked, this, &SchemaEditorForm::saveAll);
+
+	connect(save_all_tb, &QToolButton::clicked, this, __slot(this, SchemaEditorForm::saveAll));
 	connect(close_all_tb, &QToolButton::clicked, this, &SchemaEditorForm::closeAll);
 
 	connect(editors_tbw, &QTabWidget::tabCloseRequested, this, [this](int idx){
 		closeEditorTab(idx);
 	});
 
-	connect(editors_tbw, &QTabWidget::currentChanged, this, &SchemaEditorForm::loadSyntaxFromCurrentTab);
-	connect(use_tmpl_file_chk, &QCheckBox::toggled, this, &SchemaEditorForm::loadSyntaxConfig);
+	connect(editors_tbw, &QTabWidget::currentChanged, this, __slot(this, SchemaEditorForm::loadSyntaxFromCurrentTab));
+	connect(use_tmpl_file_chk, &QCheckBox::toggled, this, __slot(this, SchemaEditorForm::loadSyntaxConfig));
 
 	connect(syntax_txt, &NumberedTextEditor::textChanged, this, [this](){
 		alert_frm->setVisible(true);
 	});
 
 	connect(save_as_tb, &QToolButton::clicked, this, [this](){
-		saveFile(true);
+		__trycatch( saveFile(true); )
 	});
 
 	connect(about_tb, &QToolButton::clicked, this, [](){
 		AboutSEWidget *info_wgt = new AboutSEWidget;
-		BaseForm base_frm;
+		BaseForm base_frm;	
 		base_frm.setMainWidget(info_wgt);
 		base_frm.exec();
 	});
@@ -359,7 +362,7 @@ void SchemaEditorForm::indentAll()
 {
 	SourceEditorWidget *editor = nullptr;
 
-	QApplication::setOverrideCursor(Qt::WaitCursor);
+	qApp->setOverrideCursor(Qt::WaitCursor);
 
 	for(int tab = 0; tab < editors_tbw->count(); tab++)
 	{
@@ -367,12 +370,12 @@ void SchemaEditorForm::indentAll()
 		editor->indent_tb->click();
 	}
 
-	QApplication::restoreOverrideCursor();
+	qApp->restoreOverrideCursor();
 }
 
 void SchemaEditorForm::saveAll()
 {
-	QApplication::setOverrideCursor(Qt::WaitCursor);
+	qApp->setOverrideCursor(Qt::WaitCursor);
 
 	for(int tab = 0; tab < editors_tbw->count(); tab++)
 	{
@@ -384,13 +387,14 @@ void SchemaEditorForm::saveAll()
 		}
 		catch(Exception &e)
 		{
-			Messagebox msgbox;
-			msgbox.show(e);
+			//Messagebox msgbox;
+			//msgbox.show(e);
+			Messagebox::error(e, __PRETTY_FUNCTION__, __FILE__, __LINE__);
 			break;
 		}
 	}
 
-	QApplication::restoreOverrideCursor();
+	qApp->restoreOverrideCursor();
 }
 
 void SchemaEditorForm::closeAll()
@@ -405,12 +409,12 @@ void SchemaEditorForm::closeAll()
 			return;
 	}
 
-	QApplication::setOverrideCursor(Qt::WaitCursor);
+	qApp->setOverrideCursor(Qt::WaitCursor);
 
 	while(editors_tbw->count() > 0)
 		closeEditorTab(0, false);
 
-	QApplication::restoreOverrideCursor();
+	qApp->restoreOverrideCursor();
 }
 
 QStringList SchemaEditorForm::showFileDialog(bool save_mode)
@@ -477,16 +481,16 @@ void SchemaEditorForm::loadFiles(const QStringList &filenames)
 {
 	try
 	{
-		QApplication::setOverrideCursor(Qt::WaitCursor);
+		qApp->setOverrideCursor(Qt::WaitCursor);
 
 		for(auto &file : filenames)
 			addEditorTab(file);
 
-		QApplication::restoreOverrideCursor();
+		qApp->restoreOverrideCursor();
 	}
 	catch(Exception &e)
 	{
-		QApplication::restoreOverrideCursor();
+		qApp->restoreOverrideCursor();
 		throw Exception(e.getErrorMessage(), e.getErrorCode(), __PRETTY_FUNCTION__, __FILE__, __LINE__, &e);
 	}
 }
