@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 */
 
 #include "graphicalview.h"
+#include "utilsns.h"
 
 GraphicalView::GraphicalView(View *view) : BaseTableView(view)
 {
@@ -31,6 +32,14 @@ GraphicalView::GraphicalView(View *view) : BaseTableView(view)
 
 void GraphicalView::configureObject()
 {
+	View *view = dynamic_cast<View *>(this->getUnderlyingObject());
+
+	if(!BaseGraphicObject::isUpdatesEnabled() ||
+			(!pending_geom_update && !curr_hash_code.isEmpty() && curr_hash_code == view->getHashCode()))
+		return;
+
+	curr_hash_code = view->getHashCode();
+
 	/* If the table isn't visible we abort the current configuration
 	 * and mark its geometry update as pending so in the next call to
 	 * setVisible(true) the geometry can be updated (see BaseObjectView::itemChange()) */
@@ -40,7 +49,6 @@ void GraphicalView::configureObject()
 		return;
 	}
 
-	View *view=dynamic_cast<View *>(this->getUnderlyingObject());
 	int i = 0, count = 0;
 	unsigned start_col = 0, end_col = 0, start_ext = 0, end_ext = 0;
 	QPen pen;
@@ -311,14 +319,14 @@ void GraphicalView::configureObject()
 	pen.setStyle(Qt::DashLine);
 	attribs_toggler->setPen(pen);
 
-	if(!view->getAlias().isEmpty())
-		table_tooltip += QString("\nAlias: %1").arg(view->getAlias());
+	//if(!view->getAlias().isEmpty())
+	//	table_tooltip += QString("\n%1 Alias: %2").arg(UtilsNs::DataSeparator, view->getAlias());
 
-	if(!view->getComment().isEmpty())
-		table_tooltip += QString("\n---\n%1").arg(view->getComment());
+	//if(!view->getComment().isEmpty())
+	//	table_tooltip += QString("\n\n%1").arg(view->getComment());
 
 	BaseObjectView::__configureObject();
-	BaseObjectView::configureObjectShadow();
+	BaseTableView::configureObjectShadow();
 	BaseObjectView::configureObjectSelection();
 	configureTag();
 	configureSQLDisabledInfo();
