@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,11 +34,18 @@ class __libcanvas StyledTextboxView: public TextboxView {
 		//! \brief Fold indicator appended at bottom-right corner of the object
 		QGraphicsPolygonItem *fold;
 
+		QGraphicsTextItem *styled_txt_item;
+
 	public:
+		static constexpr double DefaultWidth = 40;
+
 		StyledTextboxView(Textbox *txtbox, bool override_style=false);
+
+		virtual void mouseMoveEvent(QGraphicsSceneMouseEvent *event) override;
+
 		virtual ~StyledTextboxView();
 
-	protected slots:
+	 protected slots:
 		virtual void configureObject() override;
 };
 
