@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
 # Also, you can get the complete GNU General Public License at <http://www.gnu.org/licenses/>
 */
 #include "catalog.h"
-#include "coreutilsns.h"
 #include "utilsns.h"
+#include "tableobject.h"
 
 const QString Catalog::QueryList("list");
 const QString Catalog::QueryAttribs("attribs");
@@ -29,9 +29,12 @@ const QString Catalog::PgModelerTempDbObj("__pgmodeler_tmp");
 const QString Catalog::InvFilterPattern("__invalid__pattern__");
 const QString Catalog::AliasPlaceholder("$alias$");
 const QString Catalog::EscapedNullChar("\\000");
+
+/* This query retrieve all extension child object except for data types because
+ * they are handled in extension catalog query */
 const QString Catalog::GetExtensionObjsSql("SELECT d.objid AS oid, e.extname AS name FROM pg_depend AS d \
 																					 LEFT JOIN pg_extension AS e ON e.oid = d.refobjid \
-																					 WHERE objid > 0 AND refobjid > 0 AND deptype='e'\
+																					 WHERE objid > 0 AND refobjid > 0 AND deptype='e' AND classid::regclass::text != 'pg_type'\
 																					 ORDER BY extname;");
 attribs_map Catalog::catalog_queries;
 
@@ -57,6 +60,25 @@ std::map<ObjectType, QString> Catalog::ext_oid_fields={
 	{ObjectType::Policy, "pl.polrelid"}
 };
 
+std::map<ObjectType, QString> Catalog::obj_relnames={
+	{ObjectType::Aggregate, "pg_aggregate"},	{ObjectType::Cast, "pg_cast"},
+	{ObjectType::Collation, "pg_collation"},	{ObjectType::Column, "pg_attribute"},
+	{ObjectType::Constraint, "pg_constraint"},	{ObjectType::Conversion, "pg_conversion"},
+	{ObjectType::Database, "pg_database"},	{ObjectType::Domain, "pg_type"},
+	{ObjectType::Extension, "pg_extension"},	{ObjectType::EventTrigger, "pg_event_trigger"},
+	{ObjectType::ForeignDataWrapper, "pg_foreign_data_wrapper"},	{ObjectType::ForeignTable, "pg_foreign_table"},
+	{ObjectType::Function, "pg_proc"},	{ObjectType::Index, "pg_index"},
+	{ObjectType::Operator, "pg_operator"},	{ObjectType::OpClass, "pg_opclass"},
+	{ObjectType::OpFamily, "pg_opfamily"},	{ObjectType::Policy, "pg_policy"},
+	{ObjectType::Language, "pg_language"},	{ObjectType::Procedure, "pg_proc"},
+	{ObjectType::Role, "pg_authid"},	{ObjectType::Rule, "pg_rewrite"},
+	{ObjectType::Schema, "pg_namespace"},	{ObjectType::Sequence, "pg_class"},
+	{ObjectType::ForeignServer, "pg_foreign_server"},	{ObjectType::Table, "pg_class"},
+	{ObjectType::Tablespace, "pg_tablespace"},	{ObjectType::Transform, "pg_transform"},
+	{ObjectType::Trigger, "pg_trigger"},	{ObjectType::Type, "pg_type"},
+	{ObjectType::View, "pg_class"}, {ObjectType::UserMapping, "pg_user_mapping"}
+};
+
 std::map<ObjectType, QString> Catalog::parent_aliases={
 	{ObjectType::Constraint, "tb"},
 	{ObjectType::Index, "tb"},
@@ -140,6 +162,11 @@ void Catalog::closeConnection()
 	connection.close();
 }
 
+bool Catalog::isConnectionValid()
+{
+	return connection.isConfigured();
+}
+
 void Catalog::setQueryFilter(QueryFilter filter)
 {
 	bool list_all=(ListAllObjects & filter) == ListAllObjects;
@@ -171,12 +198,28 @@ void Catalog::setObjectFilters(QStringList filters, bool only_matching, bool mat
 	if(filters.isEmpty())
 		return;
 
+	QStringList any_filters, filterable_types = getFilterableObjectNames();
+	QRegularExpression any_flt_regex = QRegularExpression(QString("^(%1)(.)+").arg(Attributes::Any));
+
+	any_filters = filters.filter(any_flt_regex);
+
+	for(auto &filter : any_filters)
+	{
+		/* If there's at least one "any" filter we create filters
+		 * for all object types using the pattern associated to the "any" filter */
+		for(auto &type : filterable_types)
+			filters.append(QString(filter).replace(Attributes::Any, type));
+	}
+
+	// Remove the any filters after converting them to object filters
+	for(auto &any_flt : any_filters)
+		filters.removeAll(any_flt);
+
 	ObjectType obj_type;
-	QString pattern, mode, aux_filter, parent_alias_ref, tab_filter = "^(%1)(.)+", _tmpl_filter;
+	QString pattern, mode, parent_alias_ref, tab_filter = "^(%1)(.)+";
 	QStringList values,	modes = { UtilsNs::FilterWildcard, UtilsNs::FilterRegExp };
 	std::map<ObjectType, QStringList> tab_patterns;
 	std::map<ObjectType, QStringList> parsed_filters;
-	attribs_map fmt_filter;
 
 	bool has_tab_filter = filters.indexOf(QRegularExpression(tab_filter.arg(BaseObject::getSchemaName(ObjectType::Table)))) >= 0,
 			 has_view_filter = filters.indexOf(QRegularExpression(tab_filter.arg(BaseObject::getSchemaName(ObjectType::View)))) >= 0,
@@ -197,7 +240,7 @@ void Catalog::setObjectFilters(QStringList filters, bool only_matching, bool mat
 		 * This one comes in form of a regexp matching on oid::regclass::text */
 		parent_alias_ref = QString("%1 %2 ~* '(#)'")
 											 .arg(match_signature ? parent_sch_ref : "")
-											 .arg(AliasPlaceholder + QString(".relname"))
+											 .arg(AliasPlaceholder + ".relname")
 											 .replace("#", "%1");
 
 		// Validating the provided table children objects types
@@ -270,14 +313,11 @@ void Catalog::setObjectFilters(QStringList filters, bool only_matching, bool mat
 
 				pattern = list.join(any_str);
 			}
-			else
-			{
-				/* If the pattern is wildcard mode but has not wildcard char we
-				 * assume that the matching should be exact so we prepend ^ and append $
-				 * in order to force a regular expression with exact match */
-				pattern.prepend('^');
-				pattern.append('$');
-			}
+
+			/* In wildcard mode the pattern matching must be exact, so we prepend ^ and append $
+			 * in order to force a regular expression with exact match. */
+			pattern.prepend('^');
+			pattern.append('$');
 		}
 
 		parsed_filters[obj_type].append(QString("(%1)").arg(pattern));
@@ -307,13 +347,13 @@ void Catalog::setObjectFilters(QStringList filters, bool only_matching, bool mat
 			 * "relation kind" in pg_class in order to avoid bringing children object of
 			 * table types not filtered */
 			if(has_tab_filter && BaseObject::isChildObjectType(ObjectType::Table, obj_type))
-				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::Table] + QString("IN ('r','p')")));
+				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::Table] + "IN ('r','p')"));
 
 			if(has_view_filter && BaseObject::isChildObjectType(ObjectType::View, obj_type))
-				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::View] + QString("IN ('v','m')")));
+				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::View] + "IN ('v','m')"));
 
 			if(has_ftab_filter && BaseObject::isChildObjectType(ObjectType::ForeignTable, obj_type))
-				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::ForeignTable] + QString("= 'f'")));
+				fmt_conds.append(QString("(%1)").arg(fmt_tab_patterns[ObjectType::ForeignTable] + "= 'f'"));
 
 			if(!fmt_conds.isEmpty())
 			{
@@ -394,17 +434,17 @@ QString Catalog::getCatalogQuery(const QString &qry_type, ObjectType obj_type, b
 		}
 	}
 
-	schparser.__setPgSQLVersion(connection.getPgSQLVersion(true),
-															Connection::isDbVersionIgnored());
+	schparser.setPgSQLVersion(connection.getPgSQLVersion(true),
+														Connection::isDbVersionIgnored());
 	attribs[qry_type]=Attributes::True;
 
 	if(exclude_sys_objs || list_only_sys_objs)
 		attribs[Attributes::LastSysOid]=QString::number(last_sys_oid);
 
 	if(list_only_sys_objs)
-		attribs[Attributes::OidFilterOp]=QString("<=");
+		attribs[Attributes::OidFilterOp]="<=";
 	else
-		attribs[Attributes::OidFilterOp]=QString(">");
+		attribs[Attributes::OidFilterOp]=">";
 
 	if(obj_type==ObjectType::Type && exclude_array_types)
 		attribs[Attributes::ExcBuiltinArrays]=Attributes::True;
@@ -483,8 +523,10 @@ QString Catalog::getCatalogQuery(const QString &qry_type, ObjectType obj_type, b
 	//Append a LIMIT clause when the single_result is set
 	if(single_result)
 	{
-		if(sql.endsWith(';'))	sql.remove(sql.size()-1, 1);
-		sql+=QString(" LIMIT 1");
+		if(sql.endsWith(';'))
+			sql.remove(sql.size()-1, 1);
+
+		sql+=" LIMIT 1";
 	}
 
 	return sql;
@@ -503,7 +545,7 @@ void Catalog::executeCatalogQuery(const QString &qry_type, ObjectType obj_type,
 	}
 }
 
-unsigned Catalog::getObjectCount(ObjectType obj_type, const QString &sch_name, const QString &tab_name, attribs_map extra_attribs)
+/*unsigned Catalog::getObjectCount(ObjectType obj_type, const QString &sch_name, const QString &tab_name, attribs_map extra_attribs)
 {
 	try
 	{
@@ -520,6 +562,55 @@ unsigned Catalog::getObjectCount(ObjectType obj_type, const QString &sch_name, c
 	{
 		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 	}
+} */
+
+unsigned Catalog::getObjectsCount(std::vector<ObjectType> obj_types, bool incl_sys_objs, const QString &sch_name, const QString &tab_name, attribs_map extra_attribs)
+{
+	try
+	{
+		QStringList queries;
+		QString sql, extra_info_token = Attributes::ExtraInfo;
+
+		extra_info_token.replace('-', '_');
+
+		if(!incl_sys_objs)
+			extra_attribs[Attributes::LastSysOid] = QString::number(last_sys_oid);
+
+		extra_attribs[Attributes::Schema] = sch_name;
+		extra_attribs[Attributes::Table] = tab_name;
+
+		for(auto &obj_type : obj_types)
+		{
+			//Build the catalog query for the specified object type
+			sql = getCatalogQuery(QueryList, obj_type, false, extra_attribs);
+
+			/* An catalog query will be empty if the object type doesn't exist in the
+			 * current database version being queried */
+			if(sql.isEmpty())
+				continue;
+
+			/* Removing the section of the query where columns are selected until the column extra_info,
+			 * and injecting a count(oid) instruction */
+			//sql.remove(sql.indexOf("SELECT"), sql.indexOf("FROM"));
+			sql.remove(sql.indexOf("SELECT"), sql.indexOf(extra_info_token) + extra_info_token.length());
+			sql.prepend(QString("SELECT count(%1) ").arg(oid_fields[obj_type]));
+			queries.append(sql);
+		}
+
+		sql = QString("SELECT (") +  queries.join(") + (") + QChar(')');
+
+		ResultSet res;
+		connection.executeDMLCommand(sql, res);
+
+		if(res.accessTuple(ResultSet::FirstTuple))
+			return QString(res.getColumnValue(0)).toUInt();
+
+		return 0;
+	}
+	catch(Exception &e)
+	{
+		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+	}
 }
 
 Catalog::QueryFilter Catalog::getQueryFilter()
@@ -634,7 +725,7 @@ std::vector<attribs_map> Catalog::getObjectsNames(std::vector<ObjectType> obj_ty
 	{
 		ResultSet res;
 		std::vector<attribs_map> objects;
-		QString sql, select_kw=QString("SELECT");
+		QString sql, select_kw="SELECT";
 		QStringList queries;
 		attribs_map attribs;
 
@@ -661,27 +752,34 @@ std::vector<attribs_map> Catalog::getObjectsNames(std::vector<ObjectType> obj_ty
 		}
 
 		//Joining the generated queries by using union in order to retrieve all results at once
-		sql = QChar('(') +  queries.join(QString(") UNION (")) + QChar(')');
+		sql = QChar('(') +  queries.join(") UNION (") + QChar(')');
 
 		if(sort_results)
-			sql += QString(" ORDER BY oid, object_type");
+			sql += " ORDER BY oid, object_type";
 
 		connection.executeDMLCommand(sql, res);
 
 		if(res.accessTuple(ResultSet::FirstTuple))
 		{
-			QString obj_type_attr = QString(Attributes::ObjectType).replace('-', '_'),
-					parent_type_attr = QString(Attributes::ParentType).replace('-', '_');
+			QString fmt_attr_name;
 
 			do
 			{
-				attribs[Attributes::Oid]=res.getColumnValue(Attributes::Oid);
-				attribs[Attributes::Name]=res.getColumnValue(Attributes::Name);
-				attribs[Attributes::ObjectType]=res.getColumnValue(obj_type_attr);
-				attribs[Attributes::Parent]=res.getColumnValue(Attributes::Parent);
-				attribs[Attributes::ParentType]=res.getColumnValue(parent_type_attr);
+				for(auto &col_name : res.getColumnNames())
+				{
+					fmt_attr_name = QString(col_name).replace('_', '-');
+					attribs[fmt_attr_name] = res.getColumnValue(col_name);
+				}
+
+				// Creating a signature attribute by joining the parent name and the object name.
+				if(!attribs[Attributes::Parent].isEmpty())
+					attribs[Attributes::Signature] = attribs[Attributes::Parent] + ".";
+
+				attribs[Attributes::Signature] += attribs[Attributes::Name];
+
 				objects.push_back(attribs);
 				attribs.clear();
+				fmt_attr_name.clear();
 			}
 			while(res.accessTuple(ResultSet::NextTuple));
 		}
@@ -787,14 +885,15 @@ std::vector<attribs_map> Catalog::getMultipleAttributes(const QString &catalog_s
 	}
 }
 
-QString Catalog::getCommentQuery(const QString &oid_field, bool is_shared_obj)
+QString Catalog::getCommentQuery(const QString &oid_field, ObjectType obj_type, bool is_shared_obj)
 {
 	QString query_id=Attributes::Comment;
 
 	try
 	{
-		attribs_map attribs={{Attributes::Oid, oid_field},
-												 {Attributes::SharedObj, (is_shared_obj ? Attributes::True : "")}};
+		attribs_map attribs={{ Attributes::Oid, oid_field },
+												 { Attributes::SharedObj, (is_shared_obj ? Attributes::True : "") },
+												 { Attributes::ObjRelationName, obj_relnames[obj_type] }};
 
 		loadCatalogQuery(query_id);
 		return schparser.getSourceCode(attribs).simplified();
@@ -808,7 +907,7 @@ QString Catalog::getCommentQuery(const QString &oid_field, bool is_shared_obj)
 
 QString Catalog::getNotExtObjectQuery(const QString &oid_field)
 {
-	QString query_id=QString("notextobject");
+	QString query_id="notextobject";
 
 	try
 	{
@@ -881,7 +980,7 @@ std::vector<attribs_map> Catalog::getObjectsAttributes(ObjectType obj_type, cons
 
 		//Retrieve the comment catalog query. Only columns need to retreive comments in their own catalog query file
 		if(obj_type != ObjectType::Column)
-			extra_attribs[Attributes::Comment]=getCommentQuery(oid_fields[obj_type], is_shared_obj);
+			extra_attribs[Attributes::Comment] = getCommentQuery(oid_fields[obj_type], obj_type, is_shared_obj);
 
 		return getMultipleAttributes(obj_type, extra_attribs);
 	}
@@ -947,7 +1046,7 @@ attribs_map Catalog::getServerAttributes()
 		QString sql, attr_name;
 		attribs_map tuple, attribs_aux;
 
-		loadCatalogQuery(QString("server"));
+		loadCatalogQuery("server");
 		schparser.ignoreUnkownAttributes(true);
 		schparser.ignoreEmptyAttributes(true);
 		sql = schparser.getSourceCode(attribs).simplified();
@@ -978,38 +1077,16 @@ attribs_map Catalog::getServerAttributes()
 	return attribs;
 }
 
-unsigned Catalog::getObjectCount(bool incl_sys_objs)
+bool Catalog::isServerSupported()
 {
-	unsigned count = 0;
-
 	try
 	{
-		ResultSet res = ResultSet();
-		QString sql, attr_name;
-		attribs_map tuple, attribs;
-
-		if(!incl_sys_objs)
-			attribs[Attributes::LastSysOid]=QString::number(last_sys_oid);
-
-		loadCatalogQuery(Attributes::ObjCount);
-		schparser.ignoreUnkownAttributes(true);
-		schparser.ignoreEmptyAttributes(true);
-		sql = schparser.getSourceCode(attribs).simplified();
-		connection.executeDMLCommand(sql, res);
-
-		if(res.accessTuple(ResultSet::FirstTuple))
-		{
-			tuple = res.getTupleValues();
-			count = tuple[Attributes::ObjCount].toUInt();
-		}
+		return connection.isServerSupported();
 	}
 	catch(Exception &e)
 	{
-		throw Exception(e.getErrorMessage(), e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e,
-						QApplication::translate("Catalog","Object type: server","", -1));
+		throw Exception(e.getErrorMessage(), e.getErrorCode(), __PRETTY_FUNCTION__, __FILE__, __LINE__, &e);
 	}
-
-	return count;
 }
 
 QStringList Catalog::parseArrayValues(const QString &array_val)
@@ -1025,7 +1102,7 @@ QStringList Catalog::parseArrayValues(const QString &array_val)
 		QString value=array_val.mid(start, (end - start)+1);
 
 		if(value.contains('"'))
-			list = parseDefaultValues(value, QString("\""), QString(","));
+			list = parseDefaultValues(value, "\"", ",");
 		else
 			list = value.split(',', Qt::SkipEmptyParts);
 	}
@@ -1057,7 +1134,7 @@ QStringList Catalog::parseDefaultValues(const QString &def_values, const QString
 
 		if(pos >= 0)
 		{
-			idx = aux_def_vals.indexOf(QString("], "), pos + 1);
+			idx = aux_def_vals.indexOf("], ", pos + 1);
 
 			if(idx < 0)
 				idx = aux_def_vals.indexOf(']', pos + 1);
