@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,38 +19,39 @@
 #include "connection.h"
 #include <QTextStream>
 #include <iostream>
-#include "attributes.h"
 #include "globalattributes.h"
 #include "pgsqlversions.h"
+#include "exception.h"
 
-const QString Connection::SslDisable=QString("disable");
-const QString Connection::SslAllow=QString("allow");
-const QString Connection::SslPrefer=QString("prefer");
-const QString Connection::SslRequire=QString("require");
-const QString Connection::SslCaVerify=QString("verify-ca");
-const QString Connection::SslFullVerify=QString("verify-full");
+const QString Connection::SslDisable("disable");
+const QString Connection::SslAllow("allow");
+const QString Connection::SslPrefer("prefer");
+const QString Connection::SslRequire("require");
+const QString Connection::SslCaVerify("verify-ca");
+const QString Connection::SslFullVerify("verify-full");
 
-const QString Connection::ParamAlias=QString("alias");
-const QString Connection::ParamApplicationName=QString("application_name");
-const QString Connection::ParamServerFqdn=QString("host");
-const QString Connection::ParamServerIp=QString("hostaddr");
-const QString Connection::ParamPort=QString("port");
-const QString Connection::ParamDbName=QString("dbname");
-const QString Connection::ParamUser=QString("user");
-const QString Connection::ParamPassword=QString("password");
-const QString Connection::ParamConnTimeout=QString("connect_timeout");
-const QString Connection::ParamOthers=QString("options");
-const QString Connection::ParamSslMode=QString("sslmode");
-const QString Connection::ParamSslCert=QString("sslcert");
-const QString Connection::ParamSslKey=QString("sslkey");
-const QString Connection::ParamSslRootCert=QString("sslrootcert");
-const QString Connection::ParamSslCrl=QString("sslcrl");
-const QString Connection::ParamKerberosServer=QString("krbsrvname");
-const QString Connection::ParamLibGssapi=QString("gsslib");
+const QString Connection::ParamAlias("alias");
+const QString Connection::ParamApplicationName("application_name");
+const QString Connection::ParamServerFqdn("host");
+const QString Connection::ParamServerIp("hostaddr");
+const QString Connection::ParamPort("port");
+const QString Connection::ParamDbName("dbname");
+const QString Connection::ParamUser("user");
+const QString Connection::ParamPassword("password");
+const QString Connection::ParamConnTimeout("connect_timeout");
+const QString Connection::ParamOthers("options");
+const QString Connection::ParamSslMode("sslmode");
+const QString Connection::ParamSslCert("sslcert");
+const QString Connection::ParamSslKey("sslkey");
+const QString Connection::ParamSslRootCert("sslrootcert");
+const QString Connection::ParamSslCrl("sslcrl");
+const QString Connection::ParamKerberosServer("krbsrvname");
+const QString Connection::ParamLibGssapi("gsslib");
+const QString Connection::ParamSetRole("setrole");
 
-const QString Connection::ServerPid=QString("server-pid");
-const QString Connection::ServerProtocol=QString("server-protocol");
-const QString Connection::ServerVersion=QString("server-version");
+const QString Connection::ServerPid("server-pid");
+const QString Connection::ServerProtocol("server-protocol");
+const QString Connection::ServerVersion("server-version");
 
 bool Connection::notice_enabled=false;
 bool Connection::print_sql=false;
@@ -140,25 +141,24 @@ void Connection::generateConnectionString()
 
 	for(auto &itr : connection_params)
 	{
-		if(itr.first!=ParamAlias)
+		if(itr.first == ParamAlias || itr.first == ParamSetRole)
+			continue;
+
+		value=itr.second;
+		value.replace("\\","\\\\");
+		value.replace("'","\\'");
+
+		if(itr.first==ParamPassword && (value.contains(' ') || value.isEmpty()))
+			value=QString("'%1'").arg(value);
+
+		if(!value.isEmpty())
 		{
-			value=itr.second;
-
-			value.replace("\\","\\\\");
-			value.replace("'","\\'");
-
-			if(itr.first==ParamPassword && (value.contains(' ') || value.isEmpty()))
-				value=QString("'%1'").arg(value);
-
-			if(!value.isEmpty())
-			{
-				if(itr.first==ParamDbName)
-					connection_str.prepend(param_str.arg(itr.first).arg(value));
-				else if(itr.first!=ParamOthers)
-					connection_str+=param_str.arg(itr.first).arg(value);
-				else
-					connection_str+=value;
-			}
+			if(itr.first == ParamDbName)
+				connection_str.prepend(param_str.arg(itr.first, value));
+			else if(itr.first != ParamOthers)
+				connection_str += param_str.arg(itr.first, value);
+			else
+				connection_str += value;
 		}
 	}
 
@@ -249,14 +249,14 @@ void Connection::connect()
 		{
 			QTextStream err(stderr);
 			err << QT_TR_NOOP("ERROR: trying to open an already stablished connection.") << Qt::endl
-				<< QString("Conn. info: [ ") << connection_str << QString("]") << Qt::endl;
+				<< "Conn. info: [ " << connection_str << "]" << Qt::endl;
 			this->close();
 		}
 	}
 
 	//Try to connect to the database
-	connection=PQconnectdb(connection_str.toStdString().c_str());
-	last_cmd_execution=QDateTime::currentDateTime();
+	connection = PQconnectdb(connection_str.toStdString().c_str());
+	last_cmd_execution = QDateTime::currentDateTime();
 
 	/* If the connection descriptor has not been allocated or if the connection state
 		is CONNECTION_BAD it indicates that the connection was not successful */
@@ -277,15 +277,20 @@ void Connection::connect()
 		//Enable the notice/warnings in the connection by pushing them into the list of generated notices
 		PQsetNoticeProcessor(connection, noticeProcessor, nullptr);
 
-	// Aborts the connection is PostgreSQL 9x is detected
-	QString pgver = getPgSQLVersion(true);
-	if(!ignore_db_version && pgver.toFloat() < PgSqlVersions::PgSqlVersion100.toFloat())
+	// Aborts the connection if an unsupported version of PostgreSQL is detected
+	if(!ignore_db_version && !isServerSupported())
 	{
+		QString pgver = getPgSQLVersion(true);
 		close();
+
 		throw Exception(Exception::getErrorMessage(ErrorCode::UnsupportedPGVersion).arg(pgver),
 										ErrorCode::UnsupportedPGVersion,
 										__PRETTY_FUNCTION__, __FILE__, __LINE__);
 	}
+
+	// Switching to another role if the related parameter is set
+	if(!connection_params[ParamSetRole].isEmpty())
+		executeDDLCommand(QString("SET ROLE '%1'").arg(connection_params[ParamSetRole]));
 }
 
 void Connection::close()
@@ -446,7 +451,7 @@ void Connection::executeDMLCommand(const QString &sql, ResultSet &result)
 	if(print_sql)
 	{
 		QTextStream out(stdout);
-		out << QString("\n---\n") << sql << Qt::endl;
+		out << "\n---\n" << sql << Qt::endl;
 	}
 
 	//Raise an error in case the command sql execution is not sucessful
@@ -485,7 +490,7 @@ void Connection::executeDDLCommand(const QString &sql)
 	if(print_sql)
 	{
 		QTextStream out(stdout);
-		out << QString("\n---\n") << sql << Qt::endl;
+		out << "\n---\n" << sql << Qt::endl;
 	}
 
 	//Raise an error in case the command sql execution is not sucessful
@@ -577,3 +582,16 @@ void Connection::requestCancel()
 		PQfreeCancel(cancel);
 	}
 }
+
+bool Connection::isServerSupported()
+{
+	try
+	{
+		QString version = getPgSQLVersion(true);
+		return version.toDouble() >= PgSqlVersions::MinimumVersion.toDouble();
+	}
+	catch(Exception &e)
+	{
+		throw Exception(e.getErrorMessage(), e.getErrorCode(), __PRETTY_FUNCTION__, __FILE__, __LINE__, &e);
+	}
+}
