@@ -40,7 +40,7 @@ Column::Column()
 	attributes[Attributes::Cache]="";
 	attributes[Attributes::Cycle]="";
 
-	parent_rel=sequence=nullptr;
+	sequence=nullptr;
 	identity_type = IdentityType::Null;
 }
 
@@ -168,19 +168,6 @@ QString Column::getOldName(bool format)
 		return old_name;
 }
 
-void Column::setParentRelationship(BaseObject *parent_rel)
-{
-	if(parent_rel && parent_rel->getObjectType()!=ObjectType::Relationship)
-		throw Exception(ErrorCode::AsgObjectInvalidType,__PRETTY_FUNCTION__,__FILE__,__LINE__);
-
-	this->parent_rel=parent_rel;
-}
-
-BaseObject *Column::getParentRelationship()
-{
-	return parent_rel;
-}
-
 void Column::setSequence(BaseObject *seq)
 {
 	if(seq)
@@ -307,11 +294,6 @@ QString Column::getAlterCode(BaseObject *object)
 		QString def_val, alter_def;
 		bool ident_seq_changed = false;
 
-		BaseObject::setBasicAttributes(true);
-
-		if(getParentTable())
-			attribs[Attributes::Table]=getParentTable()->getName(true);
-
 		if(!this->type.isEquivalentTo(col->type) ||
 				(this->type.isEquivalentTo(col->type) &&
 
@@ -398,8 +380,8 @@ QString Column::getAlterCode(BaseObject *object)
 		}
 
 		copyAttributes(attribs);
-		alter_def = BaseObject::getAlterCode(this->getSchemaName(), attributes, false, true);
-		alter_def += getAlterCommentDefinition(object, attributes);
+		alter_def = TableObject::getAlterCode(col);
+		alter_def += BaseObject::getAlterCode(this->getSchemaName(), attributes, false, true);
 
 		return alter_def;
 	}
@@ -429,7 +411,6 @@ void Column::operator = (Column &col)
 
 	this->not_null=col.not_null;
 	this->generated=col.generated;
-	this->parent_rel=col.parent_rel;
 	this->sequence=col.sequence;
 	this->identity_type=col.identity_type;
 
@@ -445,6 +426,7 @@ void Column::operator = (Column &col)
 	this->setAddedByGeneralization(false);
 	this->setAddedByLinking(false);
 	this->setCodeInvalidated(true);
+	this->setParentRelationship(col.getParentRelationship());
 }
 
 QString Column::getDataDictionary(const attribs_map &extra_attribs)
