@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@
 #define DOMAIN_H
 
 #include "baseobject.h"
-#include "schema.h"
 #include "pgsqltypes/pgsqltype.h"
 
 class __libcore Domain: public BaseObject{
@@ -47,6 +46,8 @@ class __libcore Domain: public BaseObject{
 	public:
 		Domain();
 
+		virtual ~Domain(){}
+
 		void addCheckConstraint(const QString &name, const QString &expr);
 
 		void removeCheckConstraints();
@@ -64,11 +65,11 @@ class __libcore Domain: public BaseObject{
 
 		/*! \brief Overloaded BaseObject name definition method.
 		 Updates the reference of the domain as a PostgreSQL data type */
-		void setName(const QString &name);
+		virtual void setName(const QString &name) override;
 
 		/*! \brief Overloaded BaseObject schema definition method.
 		 Updates the reference of the domain as a PostgreSQL data type */
-		void setSchema(BaseObject *schema);
+		virtual void setSchema(BaseObject *schema) override;
 
 		//! \brief Methods to access domain's attributes
 		QString getConstraintName();
@@ -83,6 +84,8 @@ class __libcore Domain: public BaseObject{
 		virtual QString getAlterCode(BaseObject *object) final;
 
 		void operator = (Domain &domain);
+
+		virtual void updateDependencies() override;
 };
 
 #endif
