@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #define EXTENSION_H
 
 #include "baseobject.h"
+#include "type.h"
 
 class __libcore Extension: public BaseObject {
 	private:
@@ -39,6 +40,9 @@ class __libcore Extension: public BaseObject {
 		is being updated */
 		QString versions[2];
 
+		//! \brief Store the type names that are created when installing the extension
+		QStringList type_names;
+
 	public:
 		enum VersionId: unsigned {
 			CurVersion,
@@ -47,20 +51,15 @@ class __libcore Extension: public BaseObject {
 
 		Extension();
 
-		void setName(const QString &name);
-		void setSchema(BaseObject *schema);
+		virtual void setSchema(BaseObject *schema) override;
 
-		/*! \brief Defines if the extension handles a datatype. When setting to true
-		the extension will be registered as a datatype on DatabaseModel class. This method has no effect when
-		the extension was already inserted on the model. */
-		void setHandlesType(bool value);
+		void setTypeNames(const QStringList &tp_names);
+
+		QStringList getTypeNames();
 
 		//! \brief Set the versions of the extension
 		void setVersion(VersionId ver, const QString &value);
 
-		//! \brief Returns if the extension handles a datatype
-		bool handlesType();
-
 		//! \brief Returns on of the versions of the extension
 		QString getVersion(VersionId ver);
 
@@ -77,8 +76,6 @@ class __libcore Extension: public BaseObject {
 		 * to be false by default (instead of true in BaseObject::getName) so the SQL code definition of the
 		 * extension can be created correctly since the CREATE EXTENSION does not allow the schema name appended to the object's name */
 		virtual QString getName(bool format = false, bool prepend_schema = false) final;
-
-		void operator = (Extension &ext);
 };
 
 #endif
