@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,6 +38,8 @@ class __libcore ForeignServer: public BaseObject, public ForeignObject {
 	public:
 		ForeignServer();
 
+		virtual ~ForeignServer(){}
+
 		void setType(const QString &type);
 		void setVersion(const QString &version);
 		void setForeignDataWrapper(ForeignDataWrapper *fdw);
@@ -46,9 +48,11 @@ class __libcore ForeignServer: public BaseObject, public ForeignObject {
 		QString getVersion();
 		ForeignDataWrapper *getForeignDataWrapper();
 
-		virtual QString getSourceCode(SchemaParser::CodeType def_type);
-		virtual QString getSourceCode(SchemaParser::CodeType def_type, bool reduced_form);
-		virtual QString getAlterCode(BaseObject *object);
+		virtual QString getSourceCode(SchemaParser::CodeType def_type) override;
+		virtual QString getSourceCode(SchemaParser::CodeType def_type, bool reduced_form) override;
+		virtual QString getAlterCode(BaseObject *object) override;
+
+		virtual void updateDependencies() override;
 };
 
 #endif
