@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -104,7 +104,7 @@ QString ForeignTable::getAlterCode(BaseObject *object)
 	try
 	{
 		attribs_map attribs;
-		attributes[Attributes::AlterCmds] = BaseObject::getAlterCode(object);
+		attributes[Attributes::AlterCmds] = BaseTable::getAlterCode(object);
 		getAlteredAttributes(dynamic_cast<ForeignObject *>(object), attribs);
 		copyAttributes(attribs);
 		return BaseObject::getAlterCode(this->getSchemaName(), attributes, false, true);
@@ -114,3 +114,8 @@ QString ForeignTable::getAlterCode(BaseObject *object)
 		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
 }
+
+void ForeignTable::updateDependencies()
+{
+	PhysicalTable::updateDependencies({ foreign_server });
+}
