@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@ class __libcore ForeignTable: public PhysicalTable, public ForeignObject {
 
 	public:
 		ForeignTable();
+
 		virtual ~ForeignTable();
 
 		void setForeignServer(ForeignServer *server);
@@ -43,11 +44,11 @@ class __libcore ForeignTable: public PhysicalTable, public ForeignObject {
 		/*! \brief Adds an child object to the foreign table.
 		 * This will raise an error if the user try to add constraints other than CHECK,
 		 * indexes, rules and policies. This because foreign tables only accepts columns, check constraints, triggers */
-		void addObject(BaseObject *object, int obj_idx = -1);
+		virtual void addObject(BaseObject *object, int obj_idx = -1) override;
 
 		/*! \brief This method ignores any partitioning type provided for the foreign table.
 		 * It always set partitioning type as null since foreign tables doesn't support partitioning */
-		void setPartitioningType(PartitioningType);
+		virtual void setPartitioningType(PartitioningType) override;
 
 		//! \brief Returns the SQL / XML definition for table
 		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
@@ -64,6 +65,8 @@ class __libcore ForeignTable: public PhysicalTable, public ForeignObject {
 		 * invalidate the tables code (see setCodeInvalidated()) after retrieving the resulting code */
 		QString __getSourceCode(SchemaParser::CodeType def_type, bool incl_rel_added_objs);
 
+		virtual void updateDependencies() override;
+
 		friend class Relationship;
 		friend class OperationList;
 };
