@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,31 +25,19 @@
 #ifndef GENERIC_SQL_H
 #define GENERIC_SQL_H
 
-#include "baseobject.h"
-#include <unordered_map>
+#include "reference.h"
 
 class __libcore GenericSQL: public BaseObject{
-	protected:
-
-		//! \brief This is a internal structure used to hold object references configuration
-		struct ObjectRefConfig {
-			QString ref_name; // Name of the reference (in SQL it be used between {} in order to be parsed)
-			BaseObject *object; // The object being referenced
-			bool use_signature,  // Indicates that the signature of the object should be used instead of the name
-			format_name; // Indicates that the name of the object need to be automatically quoted or the schema name appended
-			ObjectRefConfig(const QString &_ref_name, BaseObject *_object, bool _use_signature, bool _format_name) :
-				ref_name(_ref_name), object(_object), use_signature(_use_signature), format_name(_format_name) {}
-		};
-
-		//! \brief Returns a copy of the objects references list
-		std::vector<ObjectRefConfig> getObjectsReferences();
-
 	private:
 		//! \brief The SQL definition of the generic object
 		QString definition;
 
+		/*! \brief Indicate whether the SQL comment description (-- object: ... type: ...)
+		 * of the generic object must be displayed in the SQL code generation */
+		bool hide_description;
+
 		//! \brief The list of references to other object in the model
-		std::vector<ObjectRefConfig> objects_refs;
+		std::vector<Reference> objects_refs;
 
 		/*! \brief Returns the index of a object reference searching by its name.
 		 * A negative return value indicates the reference doens't exist */
@@ -58,22 +46,25 @@ class __libcore GenericSQL: public BaseObject{
 		/*! \brief Check if the provided object reference is correclty configured.
 		 * The method will raise exceptions if any validation rule is broken.
 		 * The parameter ignore_duplic makes the method ignore duplicated references names */
-		void validateObjectReference(ObjectRefConfig ref, bool ignore_duplic);
+		void validateReference(const Reference &ref, bool ignore_duplic);
 
 	public:
 		GenericSQL();
 
+		virtual ~GenericSQL(){}
+
 		void setDefinition(const QString &def);
+
 		QString getDefinition();
 
-		void addObjectReference(BaseObject *object, const QString &ref_name, bool use_signature, bool format_name);
-		void updateObjectReference(const QString &ref_name, BaseObject *object, const QString &new_ref_name, bool use_signature, bool format_name);
+		void setHideDescription(bool value);
+
+		void addReference(const Reference &ref);
+		void addReferences(const std::vector<Reference> &refs);
+
 		void removeObjectReference(const QString &ref_name);
 		void removeObjectReferences();
 
-		//! \brief Returns true when the provided object is being referenced by the generic SQL object
-		bool isObjectReferenced(BaseObject *object);
-
 		/*! \brief Returns whether the object references columns or constraints added
 		 * by relationship to their parent tables. This method is used as auxiliary
 		 * to control which generic SQL object references objects added by the
@@ -81,14 +72,21 @@ class __libcore GenericSQL: public BaseObject{
 		 * connections and disconnections of relationships */
 		bool isReferRelationshipAddedObject();
 
-		/*! \brief Returns a list of objectes being referenced by the generic object.
-		 * For performance reasons this method doesn't eliminate duplicated values in
-		 * the retunring list*/
-		std::vector<BaseObject *> getReferencedObjects();
+		//! \brief Returns a copy of the objects references list
+		std::vector<Reference> getObjectsReferences();
 
-		virtual QString getSourceCode(SchemaParser::CodeType def_type);
+		void validateReferences(bool ignore_duplic);
+
+		virtual QString getSourceCode(SchemaParser::CodeType def_type) override;
+
+		virtual void updateDependencies() override;
 
 		friend class GenericSQLWidget;
 };
 
+/* Registering the Reference struct as a Qt MetaType in order to make
+ * it liable to be sent through signal parameters as well as to be
+ * to be used by QVariant */
+Q_DECLARE_METATYPE(Reference)
+
 #endif
