@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 
 #include "baseobject.h"
 #include "function.h"
-#include "role.h"
 
 class __libcore Language: public BaseObject{
 	private:
@@ -53,8 +52,10 @@ class __libcore Language: public BaseObject{
 
 		Language();
 
+		virtual ~Language(){}
+
 		//! \brief Sets the language name
-		void setName(const QString &name);
+		virtual void setName(const QString &name) override;
 
 		//! \brief Sets whether the language is trusted or not
 		void setTrusted(bool value);
@@ -71,6 +72,8 @@ class __libcore Language: public BaseObject{
 		//! \brief Returns the SQL / XML code definition for the language
 		virtual QString getSourceCode(SchemaParser::CodeType def_type, bool reduced_form) final;
 		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
+
+		virtual void updateDependencies() override;
 };
 
 #endif
