@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,21 +33,31 @@ Collation *PartitionKey::getCollation()
 	return collation;
 }
 
-QString PartitionKey::getCodeDefinition(unsigned def_type)
+QString PartitionKey::getSourceCode(SchemaParser::CodeType def_type)
 {
 	attribs_map attribs;
-	schparser.setPgSQLVersion(BaseObject::getPgSQLVersion());
+	schparser.setPgSQLVersion(BaseObject::getPgSQLVersion(), BaseObject::isDbVersionIgnored());
 
 	attribs[Attributes::Collation]="";
 	configureAttributes(attribs, def_type);
 
 	if(collation)
 	{
-		if(def_type==SchemaParser::SqlDefinition)
+		if(def_type==SchemaParser::SqlCode)
 			attribs[Attributes::Collation]=collation->getName(true);
 		else
-			attribs[Attributes::Collation]=collation->getCodeDefinition(def_type, true);
+			attribs[Attributes::Collation]=collation->getSourceCode(def_type, true);
 	}
 
-	return schparser.getCodeDefinition(Attributes::PartitionKey, attribs, def_type);
+	return schparser.getSourceCode(Attributes::PartitionKey, attribs, def_type);
+}
+
+std::vector<BaseObject *> PartitionKey::getDependencies()
+{
+	std::vector<BaseObject *> deps = Element::getDependencies();
+
+	if(collation)
+		deps.push_back(collation);
+
+	return deps;
 }
