@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 #include "templatetype.h"
 
-class ActionType: public TemplateType<ActionType>{
+class __libcore ActionType: public TemplateType<ActionType>{
+	private:
+		static QStringList type_names;
+
 	public:
 		static constexpr unsigned NoAction = 1,
 		Restrict = 2,
@@ -38,6 +41,12 @@ class ActionType: public TemplateType<ActionType>{
 		ActionType(const QString &type_name);
 		ActionType(unsigned type_id);
 		ActionType();
+
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
 };
 
 #endif
