@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 
 #include "constrainttype.h"
 
-template<>
-QStringList ConstraintType::TemplateType<ConstraintType>::type_names =
+QStringList ConstraintType::type_names =
 {
-	"", // Reserved for BaseType::null
+	"", // Reserved for Class::Null
 
 	"PRIMARY KEY",
 	"FOREIGN KEY",
@@ -44,3 +43,23 @@ ConstraintType::ConstraintType()
 {
 	type_idx = PrimaryKey;
 }
+
+QStringList ConstraintType::getTypes()
+{
+	return TemplateType<ConstraintType>::getTypes(type_names);
+}
+
+unsigned ConstraintType::setType(unsigned type_id)
+{
+	return TemplateType<ConstraintType>::setType(type_id, type_names);
+}
+
+unsigned ConstraintType::setType(const QString &type_name)
+{
+	return TemplateType<ConstraintType>::setType(type_name, type_names);
+}
+
+QString ConstraintType::getTypeName(unsigned type_id)
+{
+	return TemplateType<ConstraintType>::getTypeName(type_id, type_names);
+}
