@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 
 #include "deferraltype.h"
 
-template<>
-QStringList DeferralType::TemplateType<DeferralType>::type_names =
+QStringList DeferralType::type_names =
 {
-	"", // Reserved for BaseType::null
+	"", // Reserved for Class::Null
 
 	"INITIALLY IMMEDIATE",
 	"INITIALLY DEFERRED"
@@ -41,3 +40,23 @@ DeferralType::DeferralType()
 {
 	type_idx = Immediate;
 }
+
+QStringList DeferralType::getTypes()
+{
+	return TemplateType<DeferralType>::getTypes(type_names);
+}
+
+unsigned DeferralType::setType(unsigned type_id)
+{
+	return TemplateType<DeferralType>::setType(type_id, type_names);
+}
+
+unsigned DeferralType::setType(const QString &type_name)
+{
+	return TemplateType<DeferralType>::setType(type_name, type_names);
+}
+
+QString DeferralType::getTypeName(unsigned type_id)
+{
+	return TemplateType<DeferralType>::getTypeName(type_id, type_names);
+}
