@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 #include "templatetype.h"
 
-class EventType: public TemplateType<EventType>{
+class __libcore EventType: public TemplateType<EventType>{
+	private:
+		static QStringList type_names;
+
 	public:
 		static constexpr unsigned OnSelect = 1,
 		OnInsert = 2,
@@ -39,6 +42,12 @@ class EventType: public TemplateType<EventType>{
 		EventType(unsigned type_id);
 		EventType();
 
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
+
 		/*! \brief These two operators were created to permit the use of the
 		 class EventType on STL containers (specially maps) */
 		bool operator < (EventType type) const;
