@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 
 #include "executiontype.h"
 
-template<>
-QStringList ExecutionType::TemplateType<ExecutionType>::type_names =
+QStringList ExecutionType::type_names =
 {
-	"", // Reserved for BaseType::null
+	"", // Reserved for Class::Null
 
 	"ALSO",
 	"INSTEAD"
@@ -32,6 +31,11 @@ ExecutionType::ExecutionType()
 	type_idx = Also;
 }
 
+QStringList ExecutionType::getTypes()
+{
+	return TemplateType<ExecutionType>::getTypes(type_names);
+}
+
 ExecutionType::ExecutionType(unsigned type_id)
 {
 	setType(type_id);
@@ -41,3 +45,18 @@ ExecutionType::ExecutionType(const QString &type_name)
 {
 	setType(type_name);
 }
+
+unsigned ExecutionType::setType(unsigned type_id)
+{
+	return TemplateType<ExecutionType>::setType(type_id, type_names);
+}
+
+unsigned ExecutionType::setType(const QString &type_name)
+{
+	return TemplateType<ExecutionType>::setType(type_name, type_names);
+}
+
+QString ExecutionType::getTypeName(unsigned type_id)
+{
+	return TemplateType<ExecutionType>::getTypeName(type_id, type_names);
+}
