@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 
 #include "firingtype.h"
 
-template<>
-QStringList FiringType::TemplateType<FiringType>::type_names =
+QStringList FiringType::type_names =
 {
-	"", // Reserved for BaseType::null
+	"", // Reserved for Class::Null
 
 	"BEFORE",
 	"AFTER",
@@ -33,6 +32,11 @@ FiringType::FiringType()
 	type_idx = Before;
 }
 
+QStringList FiringType::getTypes()
+{
+	return TemplateType<FiringType>::getTypes(type_names);
+}
+
 FiringType::FiringType(unsigned type_id)
 {
 	setType(type_id);
@@ -42,3 +46,18 @@ FiringType::FiringType(const QString &type_name)
 {
 	setType(type_name);
 }
+
+unsigned FiringType::setType(unsigned type_id)
+{
+	return TemplateType<FiringType>::setType(type_id, type_names);
+}
+
+unsigned FiringType::setType(const QString &type_name)
+{
+	return TemplateType<FiringType>::setType(type_name, type_names);
+}
+
+QString FiringType::getTypeName(unsigned type_id)
+{
+	return TemplateType<FiringType>::getTypeName(type_id, type_names);
+}
