@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 #include "templatetype.h"
 
-class FunctionType: public TemplateType<FunctionType>{
+class __libcore FunctionType: public TemplateType<FunctionType>{
+	private:
+		static QStringList type_names;
+
 	public:
 		static constexpr unsigned Volatile = 1,
 		Stable = 2,
@@ -36,6 +39,12 @@ class FunctionType: public TemplateType<FunctionType>{
 		FunctionType(const QString &type_name);
 		FunctionType(unsigned type_id);
 		FunctionType();
+
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
 };
 
 #endif 
