@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 
 #include "partitioningtype.h"
 
-template<>
-QStringList PartitioningType::TemplateType<PartitioningType>::type_names =
+QStringList PartitioningType::type_names =
 {
-	"", // Reserved for BaseType::null
+	"", // Reserved for Class::Null
 
 	"RANGE",
 	"LIST",
@@ -33,6 +32,11 @@ PartitioningType::PartitioningType()
 	type_idx = Range;
 }
 
+QStringList PartitioningType::getTypes()
+{
+	return TemplateType<PartitioningType>::getTypes(type_names);
+}
+
 PartitioningType::PartitioningType(unsigned type_id)
 {
 	setType(type_id);
@@ -42,3 +46,18 @@ PartitioningType::PartitioningType(const QString &type_name)
 {
 	setType(type_name);
 }
+
+unsigned PartitioningType::setType(unsigned type_id)
+{
+	return TemplateType<PartitioningType>::setType(type_id, type_names);
+}
+
+unsigned PartitioningType::setType(const QString &type_name)
+{
+	return TemplateType<PartitioningType>::setType(type_name, type_names);
+}
+
+QString PartitioningType::getTypeName(unsigned type_id)
+{
+	return TemplateType<PartitioningType>::getTypeName(type_id, type_names);
+}
