@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@
 #include "../coreglobal.h"
 #include <QString>
 
+class BaseObject;
+
 /*! \brief This class stores the user defined type configureation.
 	 When the user creates a Type, Sequence, Domain, even a Table,
 	 it can be used as a type on certain configurations so this
@@ -40,11 +42,10 @@ class __libcore UserTypeConfig {
 			TableType=4, //! \brief The type refers to a table
 			SequenceType=8, //! \brief The type refers to a sequence
 			ViewType=16, //! \brief The type refers to a view
-			ExtensionType=32, //! \brief The type refers to a extension used as datatype
-			ForeignTableType=64, //! \brief The type refers to a extension used as datatype
+			ForeignTableType=32, //! \brief The type refers to a extension used as datatype
 
 			//! \brief This constant refers to all types above and must be used only on type searches
-			AllUserTypes=127
+			AllUserTypes=63
 		};
 
 		UserTypeConfig(void)
@@ -58,10 +59,10 @@ class __libcore UserTypeConfig {
 
 	protected:
 		//! \brief Pointer to the instance of the user defined type
-		void *ptype;
+		BaseObject *ptype;
 
 		//! \brief Pointer to the model that the type belongs to
-		void *pmodel;
+		BaseObject *pmodel;
 
 		//! \brief Name of the type
 		QString name;
