@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,6 +52,8 @@ class __libcore Policy : public TableObject {
 	public:
 		Policy();
 
+		virtual ~Policy(){}
+
 		virtual void setParentTable(BaseTable *table) final;
 
 		//! \brief Defines if the the policy is permissive or restrictive
@@ -93,6 +95,10 @@ class __libcore Policy : public TableObject {
 		virtual QString getAlterCode(BaseObject *object) final;
 
 		bool isRoleExists(Role *role);
+
+		virtual void updateDependencies() override;
+
+		virtual void generateHashCode() override;
 };
 
 #endif
