@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -78,6 +78,8 @@ class __libcore Role: public BaseObject {
 
 		Role();
 
+		virtual ~Role(){}
+
 		//! \brief Sets one option for the role (Via OP_??? constants)
 		void setOption(RoleOpts op_type, bool value);
 
@@ -129,6 +131,8 @@ class __libcore Role: public BaseObject {
 		virtual QString getSourceCode(SchemaParser::CodeType def_type, bool reduced_form) final;
 
 		virtual QString getAlterCode(BaseObject *object) final;
+
+		virtual void updateDependencies() override;
 };
 
 #endif
