@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@
 #define RULE_H
 
 #include "tableobject.h"
-#include "column.h"
 #include "pgsqltypes/executiontype.h"
 #include "pgsqltypes/eventtype.h"
 
@@ -51,6 +50,8 @@ class __libcore Rule: public TableObject{
 	public:
 		Rule();
 
+		virtual ~Rule(){}
+
 		//! \brief Adds the SQL command to be executed by the rule
 		void addCommand(const QString &cmd);
 
@@ -86,6 +87,8 @@ class __libcore Rule: public TableObject{
 
 		//! \brief Returns the SQL / XML definition for the rule
 		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
+
+		virtual void generateHashCode() override;
 };
 
 #endif
