@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,7 +38,9 @@ class __libcore Tablespace: public BaseObject{
 	public:
 		Tablespace();
 
-		void setName(const QString &name);
+		virtual ~Tablespace(){}
+
+		virtual void setName(const QString &name) override;
 
 		//! \brief Sets the directory where tablespace resides
 		void setDirectory(const QString &dir);
