@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ void Transform::setName(const QString &)
 	//	If the type is based upon a user-defined type we remove the schema name form its name
 	if(type.isUserType())
 	{
-		type_obj = reinterpret_cast<BaseObject *>(type.getUserTypeReference());
+		type_obj = type.getObject();
 
 		if(type_obj && type_obj->getSchema())
 			tp_name.remove(type_obj->getSchema()->getName() + ".");
@@ -204,6 +204,12 @@ QString Transform::getDropCode(bool cascade)
 	return BaseObject::getDropCode(cascade);
 }
 
+void Transform::updateDependencies()
+{
+	BaseObject::updateDependencies({ type.getObject(), language,
+																	 functions[FromSqlFunc], functions[ToSqlFunc] });
+}
+
 void Transform::operator = (Transform &transf)
 {
 	*(dynamic_cast<BaseObject *>(this))=dynamic_cast<BaseObject &>(transf);
