@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,75 +21,69 @@
 #include "widgets/customsqlwidget.h"
 #include "baseform.h"
 #include "settings/generalconfigwidget.h"
+#include "utilsns.h"
+#include "dbobjects/pgsqltypewidget.h"
+#include "guiutilsns.h"
 
 BaseObjectWidget::BaseObjectWidget(QWidget *parent, ObjectType obj_type): QWidget(parent)
 {
-	try
-	{
-		QSpacerItem *spacer=nullptr;
+	QSpacerItem *spacer=nullptr;
 
-		setWindowTitle("");
-		setupUi(this);
+	setWindowTitle("");
+	setupUi(this);
 
-		handled_obj_type=obj_type;
-		operation_count=0;
-		new_object=false;
-		model=nullptr;
-		table=nullptr;
-		relationship=nullptr;
-		prev_schema=nullptr;
-		op_list=nullptr;
-		object=nullptr;
-		object_px=DNaN;
-		object_py=DNaN;
-		schema_sel=nullptr;
-		owner_sel=nullptr;
-		tablespace_sel=nullptr;
-		object_protected = false;
+	handled_obj_type=obj_type;
+	operation_count=0;
+	new_object=false;
+	model=nullptr;
+	table=nullptr;
+	relationship=nullptr;
+	prev_schema=nullptr;
+	op_list=nullptr;
+	object=nullptr;
+	object_px=DNaN;
+	object_py=DNaN;
+	schema_sel=nullptr;
+	owner_sel=nullptr;
+	tablespace_sel=nullptr;
+	object_protected = false;
 
-		//GuiUtilsNs::configureWidgetFont(protected_obj_lbl, GuiUtilsNs::MediumFontFactor);
+	connect(edt_perms_tb, &QPushButton::clicked, this, &BaseObjectWidget::editPermissions);
+	connect(append_sql_tb, &QPushButton::clicked, this, &BaseObjectWidget::editCustomSQL);
 
-		connect(edt_perms_tb, &QPushButton::clicked, this, &BaseObjectWidget::editPermissions);
-		connect(append_sql_tb, &QPushButton::clicked, this, &BaseObjectWidget::editCustomSQL);
+	schema_sel=new ObjectSelectorWidget(ObjectType::Schema, this);
+	collation_sel=new ObjectSelectorWidget(ObjectType::Collation, this);
+	tablespace_sel=new ObjectSelectorWidget(ObjectType::Tablespace, this);
+	owner_sel=new ObjectSelectorWidget(ObjectType::Role, this);
 
-		schema_sel=new ObjectSelectorWidget(ObjectType::Schema, this);
-		collation_sel=new ObjectSelectorWidget(ObjectType::Collation, this);
-		tablespace_sel=new ObjectSelectorWidget(ObjectType::Tablespace, this);
-		owner_sel=new ObjectSelectorWidget(ObjectType::Role, this);
+	baseobject_grid = new QGridLayout;
+	baseobject_grid->setObjectName("objetobase_grid");
+	baseobject_grid->addWidget(protected_obj_frm, 0, 0, 1, 0);
+	baseobject_grid->addWidget(name_lbl, 1, 0, 1, 1);
+	baseobject_grid->addWidget(name_edt, 1, 1, 1, 1);
+	baseobject_grid->addWidget(id_ico_wgt, 1, 2, 1, 3);
+	baseobject_grid->addWidget(logical_name_lbl, 2, 0, 1, 1);
+	baseobject_grid->addWidget(alias_edt, 2, 1, 1, 1);
+	baseobject_grid->addWidget(schema_lbl, 4, 0, 1, 1);
+	baseobject_grid->addWidget(schema_sel, 4, 1, 1, 4);
+	baseobject_grid->addWidget(collation_lbl, 5, 0, 1, 1);
+	baseobject_grid->addWidget(collation_sel, 5, 1, 1, 4);
+	baseobject_grid->addWidget(tablespace_lbl, 6, 0, 1, 1);
+	baseobject_grid->addWidget(tablespace_sel, 6, 1, 1, 4);
+	baseobject_grid->addWidget(owner_lbl, 7, 0, 1, 1);
+	baseobject_grid->addWidget(owner_sel, 7, 1, 1, 4);
+	baseobject_grid->addWidget(comment_lbl, 8, 0, 1, 1);
+	baseobject_grid->addWidget(comment_edt, 8, 1, 1, 4);
 
-		baseobject_grid = new QGridLayout;
-		baseobject_grid->setObjectName("objetobase_grid");
-		baseobject_grid->addWidget(protected_obj_frm, 0, 0, 1, 0);
-		baseobject_grid->addWidget(name_lbl, 1, 0, 1, 1);
-		baseobject_grid->addWidget(name_edt, 1, 1, 1, 1);
-		baseobject_grid->addWidget(id_ico_wgt, 1, 2, 1, 3);
-		baseobject_grid->addWidget(logical_name_lbl, 2, 0, 1, 1);
-		baseobject_grid->addWidget(alias_edt, 2, 1, 1, 1);
-		baseobject_grid->addWidget(schema_lbl, 4, 0, 1, 1);
-		baseobject_grid->addWidget(schema_sel, 4, 1, 1, 4);
-		baseobject_grid->addWidget(collation_lbl, 5, 0, 1, 1);
-		baseobject_grid->addWidget(collation_sel, 5, 1, 1, 4);
-		baseobject_grid->addWidget(tablespace_lbl, 6, 0, 1, 1);
-		baseobject_grid->addWidget(tablespace_sel, 6, 1, 1, 4);
-		baseobject_grid->addWidget(owner_lbl, 7, 0, 1, 1);
-		baseobject_grid->addWidget(owner_sel, 7, 1, 1, 4);
-		baseobject_grid->addWidget(comment_lbl, 8, 0, 1, 1);
-		baseobject_grid->addWidget(comment_edt, 8, 1, 1, 4);
+	misc_btns_lt=new QHBoxLayout;
+	spacer=new QSpacerItem(20,1,QSizePolicy::Expanding);
 
-		misc_btns_lt=new QHBoxLayout;
-		spacer=new QSpacerItem(20,1,QSizePolicy::Expanding);
+	misc_btns_lt->addItem(spacer);
+	misc_btns_lt->addWidget(append_sql_tb);
+	misc_btns_lt->addWidget(edt_perms_tb);
+	misc_btns_lt->addWidget(disable_sql_chk);
 
-		misc_btns_lt->addItem(spacer);
-		misc_btns_lt->addWidget(append_sql_tb);
-		misc_btns_lt->addWidget(edt_perms_tb);
-		misc_btns_lt->addWidget(disable_sql_chk);
-
-		baseobject_grid->addLayout(misc_btns_lt,9,0,1,5);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
+	baseobject_grid->addLayout(misc_btns_lt,9,0,1,5);
 }
 
 BaseObjectWidget::~BaseObjectWidget()
@@ -150,9 +144,9 @@ void BaseObjectWidget::setRequiredField(QWidget *widget)
 				lbl->setText(str_aux + lbl->text());
 
 			if(pgtype || grp)
-				widget->setStyleSheet(QString("QGroupBox {	font-weight: bold; }"));
+				widget->setStyleSheet("QGroupBox {	font-weight: bold; }");
 			else if(lbl)
-				widget->setStyleSheet(QString("QWidget {	font-weight: bold; }"));
+				widget->setStyleSheet("QWidget {	font-weight: bold; }");
 		}
 		else if(edt || txt || sel)
 		{
@@ -165,7 +159,7 @@ void BaseObjectWidget::setRequiredField(QWidget *widget)
 				widget->setStyleSheet(QString("%1 { border: 2px solid %2; padding-top: 2px; padding-bottom: 2px; border-radius: 4px; }").arg(widget->metaObject()->className()).arg(border_color.name()));
 		}
 
-		str_aux=(!widget->toolTip().isEmpty() ? QString("\n") : "");
+		str_aux=(!widget->toolTip().isEmpty() ? "\n" : "");
 		widget->setToolTip(widget->toolTip() + str_aux + tr("Required field. Leaving this empty will raise errors!"));
 	}
 }
@@ -177,29 +171,24 @@ void BaseObjectWidget::setAttributes(DatabaseModel *model, BaseObject *object, B
 
 void BaseObjectWidget::disableReferencesSQL(BaseObject *object)
 {
-	std::vector<BaseObject *> refs;
-	TableObject *tab_obj=nullptr;
+	TableObject *tab_obj = nullptr;
 
-	model->getObjectReferences(object, refs);
-
-	while(!refs.empty())
+	for(auto &obj : object->getReferences())
 	{
-		tab_obj=dynamic_cast<TableObject *>(refs.back());
+		tab_obj = dynamic_cast<TableObject *>(obj);
 
 		//If the object is a relationship added does not do anything since the relationship itself will be disabled
 		if(!tab_obj || (tab_obj && !tab_obj->isAddedByRelationship()))
 		{
-			refs.back()->setSQLDisabled(disable_sql_chk->isChecked());
+			obj->setSQLDisabled(disable_sql_chk->isChecked());
 
 			//Update the parent table graphical representation to show the disabled child object
 			if(tab_obj)
 				tab_obj->getParentTable()->setModified(true);
 
 			//Disable the references of the current object too
-			disableReferencesSQL(refs.back());
+			disableReferencesSQL(obj);
 		}
-
-		refs.pop_back();
 	}
 }
 
@@ -398,23 +387,21 @@ void BaseObjectWidget::setAttributes(DatabaseModel *model, OperationList *op_lis
 
 void BaseObjectWidget::configureFormLayout(QGridLayout *grid, ObjectType obj_type)
 {
-	bool show_comment;
-	QObjectList chld_list;
-	QWidget *wgt=nullptr;
-
-
-	if(grid)
+	if(!grid)
+		setLayout(baseobject_grid);
+	else
 	{
-		QLayoutItem *item=nullptr;
-		int lin, col, col_span,row_span, item_id, item_count;
+		QLayoutItem *item = nullptr;
+		int lin = 0, col = 0, col_span = 0,
+				row_span = 0, item_id = 0, item_count = 0;
 
 		/* Move all the widgets of the passed grid layout one row down,
 		 permiting the insertion of the 'baseobject_grid' at the top
 		 of the items */
-		item_count=grid->count();
-		for(item_id=item_count-1; item_id >= 0; item_id--)
+		item_count = grid->count();
+		for(item_id = item_count-1; item_id >= 0; item_id--)
 		{
-			item=grid->itemAt(item_id);
+			item = grid->itemAt(item_id);
 			grid->getItemPosition(item_id, &lin, &col, &row_span, &col_span);
 			grid->removeItem(item);
 			grid->addItem(item, lin+1, col, row_span, col_span);
@@ -428,12 +415,18 @@ void BaseObjectWidget::configureFormLayout(QGridLayout *grid, ObjectType obj_typ
 
 		//Adding the base layout on the top
 		grid->addLayout(baseobject_grid, 0,0,1,0);
-		baseobject_grid=grid;
+		baseobject_grid = grid;
 	}
-	else
-		this->setLayout(baseobject_grid);
 
 	baseobject_grid->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
+	configureFormFields(obj_type, obj_type != ObjectType::BaseObject);
+}
+
+void BaseObjectWidget::configureFormFields(ObjectType obj_type, bool inst_ev_filter)
+{
+	QObjectList chld_list;
+	QWidget *wgt = nullptr;
+
 	disable_sql_chk->setVisible(obj_type!=ObjectType::BaseObject && obj_type!=ObjectType::Permission &&
 															obj_type!=ObjectType::Textbox && obj_type!=ObjectType::Tag &&
 															obj_type!=ObjectType::Parameter);
@@ -456,11 +449,8 @@ void BaseObjectWidget::configureFormLayout(QGridLayout *grid, ObjectType obj_typ
 	collation_lbl->setVisible(BaseObject::acceptsCollation(obj_type));
 	collation_sel->setVisible(BaseObject::acceptsCollation(obj_type));
 
-	show_comment=obj_type!=ObjectType::Relationship && obj_type!=ObjectType::Textbox &&
-							 obj_type!=ObjectType::Parameter && obj_type!=ObjectType::UserMapping &&
-							 obj_type!=ObjectType::Permission;
-	comment_lbl->setVisible(show_comment);
-	comment_edt->setVisible(show_comment);
+	comment_lbl->setVisible(BaseObject::acceptsComment(obj_type));
+	comment_edt->setVisible(BaseObject::acceptsComment(obj_type));
 
 	if(obj_type!=ObjectType::BaseObject)
 	{
@@ -468,7 +458,7 @@ void BaseObjectWidget::configureFormLayout(QGridLayout *grid, ObjectType obj_typ
 		obj_icon_lbl->setToolTip(BaseObject::getTypeName(obj_type));
 
 		if(obj_type != ObjectType::Permission && obj_type != ObjectType::Cast &&
-			 obj_type != ObjectType::UserMapping && obj_type != ObjectType::Transform)
+				obj_type != ObjectType::UserMapping && obj_type != ObjectType::Transform)
 		{
 			setRequiredField(name_lbl);
 			setRequiredField(name_edt);
@@ -488,30 +478,34 @@ void BaseObjectWidget::configureFormLayout(QGridLayout *grid, ObjectType obj_typ
 		}
 	}
 
-	//Install the event filter into all children object in order to capture key press
-	chld_list=this->children();
-	while(!chld_list.isEmpty())
+	if(inst_ev_filter)
 	{
-		wgt=dynamic_cast<QWidget *>(chld_list.front());
+		//Install the event filter into all children object in order to capture key press
+		chld_list = this->children();
 
-		//Avoids install event filters in objects that are inteneded to edit multiple lines
-		if(wgt &&
-				wgt->metaObject()->className()!=QString("QPlainTextEdit") &&
-				wgt->metaObject()->className()!=QString("NumberedTextEditor"))
-			wgt->installEventFilter(this);
+		while(!chld_list.isEmpty())
+		{
+			wgt=dynamic_cast<QWidget *>(chld_list.front());
 
-		chld_list.pop_front();
+			//Avoids install event filters in objects that are inteneded to edit multiple lines
+			if(wgt &&
+					wgt->metaObject()->className()!=QString("QPlainTextEdit") &&
+					wgt->metaObject()->className()!=QString("NumberedTextEditor"))
+				wgt->installEventFilter(this);
+
+			chld_list.pop_front();
+		}
 	}
 }
 
 QString BaseObjectWidget::generateVersionsInterval(unsigned ver_interv_id, const QString &ini_ver, const QString &end_ver)
 {
 	if(ver_interv_id==UntilVersion && !ini_ver.isEmpty())
-		return (XmlParser::CharLt + QString("= ") + ini_ver);
+		return (UtilsNs::EntityLt + "= " + ini_ver);
 	else if(ver_interv_id==VersionsInterval && !ini_ver.isEmpty() && !end_ver.isEmpty())
-		return (XmlParser::CharGt + QString("= ") + ini_ver + XmlParser::CharAmp + XmlParser::CharLt + QString("= ") + end_ver);
+		return (UtilsNs::EntityGt + "= " + ini_ver + UtilsNs::EntityAmp + UtilsNs::EntityLt + "= " + end_ver);
 	else if(ver_interv_id==AfterVersion &&  !ini_ver.isEmpty())
-		return (XmlParser::CharGt + QString("= ") + ini_ver);
+		return (UtilsNs::EntityGt + "= " + ini_ver);
 	else
 		return "";
 }
@@ -575,7 +569,7 @@ void BaseObjectWidget::highlightVersionSpecificFields(std::map<QString, std::vec
 		{
 			if(values && values->count(wgt) > 0)
 			{
-				field_name+=QString("<br/>") + tr("Value(s)") + QString(": (");
+				field_name+="<br/>" + tr("Value(s)") + ": (";
 				for(auto value : values->at(wgt))
 				{
 					field_name += value;
@@ -586,8 +580,8 @@ void BaseObjectWidget::highlightVersionSpecificFields(std::map<QString, std::vec
 				field_name+=")";
 			}
 
-			wgt->setStyleSheet(QString("QWidget {	font-weight: bold; font-style: italic; text-decoration: underline; }"));
-			wgt->setToolTip(QString("<p>PostgreSQL") + itr.first + QString(" %1</p>").arg(field_name));
+			wgt->setStyleSheet("QWidget {	font-weight: bold; font-style: italic; text-decoration: underline; }");
+			wgt->setToolTip("<p>PostgreSQL" + itr.first + QString(" %1</p>").arg(field_name));
 		}
 	}
 }
@@ -653,7 +647,7 @@ void BaseObjectWidget::editPermissions()
 
 	permission_wgt->setAttributes(this->model, parent_obj, this->object);
 	parent_form.setMainWidget(permission_wgt);
-	parent_form.setButtonConfiguration(Messagebox::OkButton);
+	parent_form.setButtonConfiguration(Messagebox::CloseButton);
 
 	GeneralConfigWidget::restoreWidgetGeometry(&parent_form, permission_wgt->metaObject()->className());
 	parent_form.exec();
@@ -684,7 +678,7 @@ void BaseObjectWidget::applyConfiguration()
 			ObjectType obj_type=object->getObjectType();
 			QString obj_name;
 
-			QApplication::setOverrideCursor(Qt::WaitCursor);
+			qApp->setOverrideCursor(Qt::WaitCursor);
 			obj_name=BaseObject::formatName(name_edt->text().toUtf8(), obj_type==ObjectType::Operator);
 
 			if(this->object->acceptsSchema() &&  schema_sel->getSelectedObject())
@@ -744,27 +738,27 @@ void BaseObjectWidget::applyConfiguration()
 				object->setName(name_edt->text().trimmed().toUtf8());
 			}
 
-			if(alias_edt->isVisible())
+			if(object->acceptsAlias())
 				object->setAlias(alias_edt->text().trimmed());
 
 			//Sets the object's comment
-			if(comment_edt->isVisible())
+			if(object->acceptsComment())
 				object->setComment(comment_edt->toPlainText().toUtf8());
 
 			//Sets the object's tablespace
-			if(tablespace_sel->isVisible())
+			if(object->acceptsTablespace())
 				object->setTablespace(tablespace_sel->getSelectedObject());
 
 			//Sets the object's owner
-			if(owner_sel->isVisible())
+			if(object->acceptsOwner())
 				object->setOwner(owner_sel->getSelectedObject());
 
 			//Sets the object's collation
-			if(collation_sel->isVisible())
+			if(object->acceptsCollation())
 				object->setCollation(collation_sel->getSelectedObject());
 
-			//Sets the object's schema
-			if(schema_sel->isVisible())
+			//Sets the object's schema			
+			if(object->acceptsSchema())
 			{
 				Schema *esquema=dynamic_cast<Schema *>(schema_sel->getSelectedObject());
 				this->prev_schema=dynamic_cast<Schema *>(object->getSchema());
@@ -776,7 +770,7 @@ void BaseObjectWidget::applyConfiguration()
 		}
 		catch(Exception &e)
 		{
-			QApplication::restoreOverrideCursor();
+			qApp->restoreOverrideCursor();
 			throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
 		}
 	}
@@ -820,12 +814,11 @@ void BaseObjectWidget::finishConfiguration()
 					this->object->getSourceCode(SchemaParser::SqlCode);
 			}
 
-			model->getObjectReferences(object, ref_objs);
-			for(auto &obj : ref_objs)
+			for(auto &obj : object->getReferences())
 			{
 				obj->setCodeInvalidated(true);
 
-				if(obj->getObjectType()==ObjectType::Column)
+				if(obj->getObjectType() == ObjectType::Column)
 					dynamic_cast<Column *>(obj)->getParentTable()->setModified(true);
 			}
 
@@ -860,15 +853,18 @@ void BaseObjectWidget::finishConfiguration()
 					prev_schema->setModified(true);
 			}
 
+			object->clearDependencies();
+			object->updateDependencies();
+
 			emit s_objectManipulated();
 			emit s_closeRequested();
 		}
 
-		QApplication::restoreOverrideCursor();
+		qApp->restoreOverrideCursor();
 	}
 	catch(Exception &e)
 	{
-		QApplication::restoreOverrideCursor();
+		qApp->restoreOverrideCursor();
 
 		if(e.getErrorCode()==ErrorCode::AsgObjectInvalidDefinition)
 			throw Exception(Exception::getErrorMessage(ErrorCode::RequiredFieldsNotFilled)
@@ -921,7 +917,7 @@ void BaseObjectWidget::cancelConfiguration()
 		catch(Exception &){}
 	}
 
-	QApplication::restoreOverrideCursor();
+	qApp->restoreOverrideCursor();
 	emit s_objectManipulated();
 }
 
