@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,59 +21,53 @@
 #include "baseform.h"
 #include "settings/generalconfigwidget.h"
 #include "coreutilsns.h"
+#include "pgsqlversions.h"
 
 ColumnWidget::ColumnWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Column)
 {
-	try
-	{
-		QSpacerItem *spacer=new QSpacerItem(10,10,QSizePolicy::Fixed,QSizePolicy::Expanding);
-		QStringList list;
+	QSpacerItem *spacer=new QSpacerItem(10,10,QSizePolicy::Fixed,QSizePolicy::Expanding);
+	QStringList list;
 
-		Ui_ColumnWidget::setupUi(this);
-		edit_seq_btn->setVisible(false);
+	Ui_ColumnWidget::setupUi(this);
+	edit_seq_btn->setVisible(false);
 
-		identity_type_cmb->addItems(IdentityType::getTypes());
+	identity_type_cmb->addItems(IdentityType::getTypes());
 
-		data_type=nullptr;
-		data_type=new PgSQLTypeWidget(this);
+	data_type=nullptr;
+	data_type=new PgSQLTypeWidget(this);
 
-		hl_default_value=nullptr;
-		hl_default_value=new SyntaxHighlighter(def_value_txt, true);
-		hl_default_value->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
+	hl_default_value=nullptr;
+	hl_default_value=new SyntaxHighlighter(def_value_txt, true, false, font().pointSizeF());
+	hl_default_value->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 
-		sequence_sel=new ObjectSelectorWidget(ObjectType::Sequence, this);
-		sequence_sel->setEnabled(false);
+	sequence_sel=new ObjectSelectorWidget(ObjectType::Sequence, this);
+	sequence_sel->setEnabled(false);
 
-		column_grid->addWidget(data_type,0,0,1,0);
-		column_grid->addWidget(default_value_grp,1,0,1,1);
+	column_grid->addWidget(data_type,0,0,1,0);
+	column_grid->addWidget(default_value_grp,1,0,1,1);
 
-		column_grid->addItem(spacer,column_grid->count(),0);
-		dynamic_cast<QGridLayout *>(default_value_grp->layout())->addWidget(sequence_sel, 1, 1, 1, 6);
+	column_grid->addItem(spacer,column_grid->count(),0);
+	dynamic_cast<QGridLayout *>(default_value_grp->layout())->addWidget(sequence_sel, 1, 1, 1, 6);
 
-		configureFormLayout(column_grid, ObjectType::Column);
-		configureTabOrder({ data_type });
+	configureFormLayout(column_grid, ObjectType::Column);
+	configureTabOrder({ data_type });
 
-		std::map<QString, std::vector<QWidget *> > fields_map;
-		fields_map[generateVersionsInterval(AfterVersion, PgSqlVersions::PgSqlVersion120)].push_back(generated_chk);
-		highlightVersionSpecificFields(fields_map);
+	std::map<QString, std::vector<QWidget *> > fields_map;
+	fields_map[generateVersionsInterval(AfterVersion, PgSqlVersions::PgSqlVersion120)].push_back(generated_chk);
+	highlightVersionSpecificFields(fields_map);
 
-		connect(expression_rb, &QRadioButton::toggled, this, &ColumnWidget::enableDefaultValueFields);
-		connect(sequence_rb, &QRadioButton::toggled, this, &ColumnWidget::enableDefaultValueFields);
-		connect(identity_rb, &QRadioButton::toggled, this, &ColumnWidget::enableDefaultValueFields);
+	connect(expression_rb, &QRadioButton::toggled, this, &ColumnWidget::enableDefaultValueFields);
+	connect(sequence_rb, &QRadioButton::toggled, this, &ColumnWidget::enableDefaultValueFields);
+	connect(identity_rb, &QRadioButton::toggled, this, &ColumnWidget::enableDefaultValueFields);
 
-		connect(generated_chk, &QCheckBox::toggled, this, [this](bool value){
-			notnull_chk->setDisabled(value);
-			notnull_chk->setChecked(false);
-		});
+	connect(generated_chk, &QCheckBox::toggled, this, [this](bool value){
+		notnull_chk->setDisabled(value);
+		notnull_chk->setChecked(false);
+	});
 
-		connect(edit_seq_btn, &QPushButton::clicked, this, &ColumnWidget::editSequenceAttributes);
+	connect(edit_seq_btn, &QPushButton::clicked, this, __slot(this, ColumnWidget::editSequenceAttributes));
 
-		setMinimumSize(540, 480);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
+	setMinimumSize(540, 480);
 }
 
 void ColumnWidget::enableDefaultValueFields()
@@ -129,7 +123,7 @@ void ColumnWidget::setAttributes(DatabaseModel *model, OperationList *op_list, B
 	data_type->setAttributes(type, model, true,
 													 UserTypeConfig::BaseType | UserTypeConfig::TableType |
 													 UserTypeConfig::ViewType | UserTypeConfig::ForeignTableType |
-													 UserTypeConfig::DomainType | UserTypeConfig::ExtensionType, true, false);
+													 UserTypeConfig::DomainType, true, false);
 }
 
 void ColumnWidget::editSequenceAttributes()
@@ -145,7 +139,7 @@ void ColumnWidget::editSequenceAttributes()
 	else
 		schema = this->model->getSchema("public");
 
-	ident_col_seq.setName(QString("%1_%2_seq").arg(table ? table->getName() : "").arg(col ? col->getName() : QString("new_column")));
+	ident_col_seq.setName(QString("%1_%2_seq").arg(table ? table->getName() : "").arg(col ? col->getName() : "new_column"));
 	ident_col_seq.setName(CoreUtilsNs::generateUniqueName(&ident_col_seq, *model->getObjectList(ObjectType::Sequence), false));
 	ident_col_seq.setSchema(schema);
 
