@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,69 +17,64 @@
 */
 
 #include "constraintwidget.h"
+#include "guiutilsns.h"
 
 ConstraintWidget::ConstraintWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Constraint)
 {
-	try
-	{
-		QStringList list;
-		std::map<QString, std::vector<QWidget *> > fields_map;
-		std::map<QWidget *, std::vector<QString> > values_map;
-		QGridLayout *grid=nullptr;
+	QStringList list;
+	std::map<QString, std::vector<QWidget *> > fields_map;
+	std::map<QWidget *, std::vector<QString> > values_map;
+	QGridLayout *grid=nullptr;
 
-		Ui_ConstraintWidget::setupUi(this);
+	Ui_ConstraintWidget::setupUi(this);
 
-		excl_elems_tab=new ElementsTableWidget(this);
-		grid=new QGridLayout;
-		grid->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
-		grid->addWidget(excl_elems_tab,0,0);
-		excl_elems_grp->setLayout(grid);
+	excl_elems_tab=new ElementsTableWidget(this);
+	grid=new QGridLayout;
+	grid->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
+	grid->addWidget(excl_elems_tab,0,0);
+	excl_elems_grp->setLayout(grid);
 
-		expression_hl=new SyntaxHighlighter(expression_txt, false, true);
-		expression_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
+	expression_hl=new SyntaxHighlighter(expression_txt, false, true, font().pointSizeF());
+	expression_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 
-		ref_table_sel=new ObjectSelectorWidget(ObjectType::Table, this);
-		col_picker_wgt = new ColumnPickerWidget(this);
-		ref_col_picker_wgt = new ColumnPickerWidget(this);
+	ref_table_sel=new ObjectSelectorWidget(ObjectType::Table, this);
+	col_picker_wgt = new ColumnPickerWidget(this);
+	ref_col_picker_wgt = new ColumnPickerWidget(this);
 
-		QVBoxLayout *vbox = new QVBoxLayout(columns_tbw->widget(0));
-		vbox->addWidget(col_picker_wgt);
-		vbox->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
+	QVBoxLayout *vbox = new QVBoxLayout(columns_tbw->widget(0));
+	vbox->addWidget(col_picker_wgt);
+	vbox->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
 
-		dynamic_cast<QGridLayout *>(columns_tbw->widget(1)->layout())->addWidget(ref_table_sel, 0,1,1,2);
-		dynamic_cast<QGridLayout *>(columns_tbw->widget(1)->layout())->addWidget(ref_col_picker_wgt, 3,0,1,3);
+	dynamic_cast<QGridLayout *>(columns_tbw->widget(1)->layout())->addWidget(ref_table_sel, 0,1,1,2);
+	dynamic_cast<QGridLayout *>(columns_tbw->widget(1)->layout())->addWidget(ref_col_picker_wgt, 3,0,1,3);
 
-		configureFormLayout(constraint_grid, ObjectType::Constraint);
+	configureFormLayout(constraint_grid, ObjectType::Constraint);
 
-		constr_type_cmb->addItems(ConstraintType::getTypes());
-		match_cmb->addItems(MatchType::getTypes());
-		deferral_cmb->addItems(DeferralType::getTypes());
-		indexing_cmb->addItems(IndexingType::getTypes());
+	constr_type_cmb->addItems(ConstraintType::getTypes());
+	match_cmb->addItems(MatchType::getTypes());
+	deferral_cmb->addItems(DeferralType::getTypes());
+	indexing_cmb->addItems(IndexingType::getTypes());
 
-		list = ActionType::getTypes();
-		on_delete_cmb->addItems(list);
-		on_update_cmb->addItems(list);
+	list = ActionType::getTypes();
+	on_delete_cmb->addItems(list);
+	on_update_cmb->addItems(list);
 
-		info_frm=generateInformationFrame(tr("Columns which were included by relationship can not be added / removed manually from the primary key. If done such changes they can raise errors. To create primary key using columns included by relationship use the following options: identifier field, attributes & constraints tab or primary key tab on the relationship form."));
-		constraint_grid->addWidget(info_frm, constraint_grid->count()+1, 0, 1, 0);
-		info_frm->setParent(this);
+	info_frm=generateInformationFrame(tr("Columns which were included by relationship can not be added / removed manually from the primary key. If done such changes they can raise errors. To create primary key using columns included by relationship use the following options: identifier field, attributes & constraints tab or primary key tab on the relationship form."));
+	constraint_grid->addWidget(info_frm, constraint_grid->count()+1, 0, 1, 0);
+	info_frm->setParent(this);
 
-		connect(constr_type_cmb, &QComboBox::currentIndexChanged, this, &ConstraintWidget::selectConstraintType);
-		connect(deferrable_chk, &QCheckBox::toggled, deferral_cmb, &QComboBox::setEnabled);
-		connect(deferrable_chk, &QCheckBox::toggled, deferral_lbl, &QLabel::setEnabled);
-		connect(indexing_chk, &QCheckBox::toggled, indexing_cmb, &QComboBox::setEnabled);
-		connect(ref_table_sel, &ObjectSelectorWidget::s_selectorCleared, this, &ConstraintWidget::selectReferencedTable);
-		connect(ref_table_sel, &ObjectSelectorWidget::s_objectSelected, this, &ConstraintWidget::selectReferencedTable);
-		connect(fill_factor_chk, &QCheckBox::toggled, fill_factor_sb, &QSpinBox::setEnabled);
+	connect(constr_type_cmb, &QComboBox::currentIndexChanged, this, &ConstraintWidget::selectConstraintType);
+	connect(deferrable_chk, &QCheckBox::toggled, deferral_cmb, &QComboBox::setEnabled);
+	connect(deferrable_chk, &QCheckBox::toggled, deferral_lbl, &QLabel::setEnabled);
+	connect(indexing_chk, &QCheckBox::toggled, indexing_cmb, &QComboBox::setEnabled);
+	connect(fill_factor_chk, &QCheckBox::toggled, fill_factor_sb, &QSpinBox::setEnabled);
 
-		selectConstraintType();
-		configureTabOrder();
-		setMinimumSize(540, 600);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
+	connect(ref_table_sel, &ObjectSelectorWidget::s_selectorCleared, this, __slot(this, ConstraintWidget::selectReferencedTable));
+	connect(ref_table_sel, &ObjectSelectorWidget::s_objectSelected, this, __slot(this, ConstraintWidget::selectReferencedTable));
+
+	selectConstraintType();
+	configureTabOrder();
+	setMinimumSize(540, 600);
 }
 
 void ConstraintWidget::selectReferencedTable()
@@ -99,7 +94,8 @@ void ConstraintWidget::selectConstraintType()
 	expression_lbl->setVisible(constr_type==ConstraintType::Check || constr_type==ConstraintType::Exclude);
 	expression_txt->setVisible(constr_type==ConstraintType::Check || constr_type==ConstraintType::Exclude);
 	no_inherit_chk->setVisible(constr_type==ConstraintType::Check);
-	no_inherit_lbl->setVisible(constr_type==ConstraintType::Check);
+
+	nulls_not_distinct_chk->setVisible(constr_type==ConstraintType::Unique);
 
 	fill_factor_chk->setVisible(constr_type==ConstraintType::Unique ||
 								constr_type==ConstraintType::PrimaryKey ||
@@ -110,7 +106,6 @@ void ConstraintWidget::selectConstraintType()
 
 	info_frm->setVisible(constr_type==ConstraintType::PrimaryKey);
 
-	deferrable_lbl->setVisible(constr_type!=ConstraintType::Check);
 	deferrable_chk->setVisible(constr_type!=ConstraintType::Check);
 	deferral_cmb->setVisible(constr_type!=ConstraintType::Check);
 	deferral_lbl->setVisible(constr_type!=ConstraintType::Check);
@@ -173,6 +168,7 @@ void ConstraintWidget::setAttributes(DatabaseModel *model, OperationList *op_lis
 		expression_txt->setPlainText(constr->getExpression());
 		no_inherit_chk->setChecked(constr->isNoInherit());
 		deferrable_chk->setChecked(constr->isDeferrable());
+		nulls_not_distinct_chk->setChecked(constr->isNullsNotDistinct());
 		deferral_cmb->setCurrentIndex(deferral_cmb->findText(~constr->getDeferralType()));
 		match_cmb->setCurrentIndex(match_cmb->findText(~constr->getMatchType()));
 		on_delete_cmb->setCurrentIndex(on_delete_cmb->findText(~constr->getActionType(Constraint::DeleteAction)));
@@ -215,6 +211,7 @@ void ConstraintWidget::applyConfiguration()
 		constr->setActionType(ActionType(on_delete_cmb->currentText()),Constraint::DeleteAction);
 		constr->setActionType(ActionType(on_update_cmb->currentText()),Constraint::UpdateAction);
 		constr->setNoInherit(no_inherit_chk->isChecked());
+		constr->setNullsNotDistinct(nulls_not_distinct_chk->isChecked());
 
 		if(indexing_chk->isChecked())
 			constr->setIndexType(IndexingType(indexing_cmb->currentText()));
@@ -232,7 +229,7 @@ void ConstraintWidget::applyConfiguration()
 
 		//Raises an error if the user try to create a primary key that has columns added by relationship (not supported)
 		if(constr->getConstraintType()==ConstraintType::PrimaryKey &&
-				constr->isReferRelationshipAddedColumn())
+				constr->isReferRelationshipAddedColumns())
 			throw Exception(ErrorCode::UnsupportedPKColsAddedByRel,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 		BaseObjectWidget::applyConfiguration();
@@ -256,9 +253,10 @@ void ConstraintWidget::applyConfiguration()
 	}
 	catch(Exception &e)
 	{
-		Messagebox msg_box;
+		//Messagebox msg_box;
 		cancelConfiguration();
-		msg_box.show(e);
+		//msg_box.show(e);
+		Messagebox::error(e, __PRETTY_FUNCTION__, __FILE__, __LINE__);
 	}
 }
 
