@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,51 +17,44 @@
 */
 
 #include "domainwidget.h"
-#include "widgets/numberedtexteditor.h"
+#include "guiutilsns.h"
 
 DomainWidget::DomainWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Domain)
 {
-	try
-	{
-		Ui_DomainWidget::setupUi(this);
+	Ui_DomainWidget::setupUi(this);
 
-		check_expr_hl=nullptr;
-		check_expr_hl=new SyntaxHighlighter(check_expr_txt, false, true);
-		check_expr_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
+	check_expr_hl=nullptr;
+	check_expr_hl=new SyntaxHighlighter(check_expr_txt, false, true, font().pointSizeF());
+	check_expr_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 
-		data_type=nullptr;
-		data_type=new PgSQLTypeWidget(this);
+	data_type=nullptr;
+	data_type=new PgSQLTypeWidget(this);
 
-		QGridLayout *grid = dynamic_cast<QGridLayout *>(dom_attribs_tbw->widget(0)->layout());
-		grid->addWidget(data_type, 1, 0, 1, 2);
-		grid->addItem(new QSpacerItem(10, 1, QSizePolicy::Fixed,QSizePolicy::Expanding), 2, 0, 1, 1);
+	QGridLayout *grid = dynamic_cast<QGridLayout *>(dom_attribs_tbw->widget(0)->layout());
+	grid->addWidget(data_type, 1, 0, 1, 2);
+	grid->addItem(new QSpacerItem(10, 1, QSizePolicy::Fixed,QSizePolicy::Expanding), 2, 0, 1, 1);
 
-		constr_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^ (ObjectsTableWidget::DuplicateButton), true, this);
-		constr_tab->setColumnCount(2);
+	constr_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^ (ObjectsTableWidget::DuplicateButton), true, this);
+	constr_tab->setColumnCount(2);
 
-		constr_tab->setHeaderLabel(tr("Name"), 0);
-		constr_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("constraint_ck")), 0);
+	constr_tab->setHeaderLabel(tr("Name"), 0);
+	constr_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("constraint_ck")), 0);
 
-		constr_tab->setHeaderLabel(tr("Expression"), 1);
-		constr_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("sourcecode")), 1);
+	constr_tab->setHeaderLabel(tr("Expression"), 1);
+	constr_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("sourcecode")), 1);
 
-		grid = dynamic_cast<QGridLayout *>(dom_attribs_tbw->widget(1)->layout());
-		grid->addWidget(constr_tab, 2, 0, 1, 2);
+	grid = dynamic_cast<QGridLayout *>(dom_attribs_tbw->widget(1)->layout());
+	grid->addWidget(constr_tab, 2, 0, 1, 2);
 
-		connect(constr_tab, &ObjectsTableWidget::s_rowAdded, this, &DomainWidget::handleConstraint);
-		connect(constr_tab, &ObjectsTableWidget::s_rowUpdated, this, &DomainWidget::handleConstraint);
-		connect(constr_tab, &ObjectsTableWidget::s_rowEdited, this, &DomainWidget::editConstraint);
+	connect(constr_tab, &ObjectsTableWidget::s_rowAdded, this, &DomainWidget::handleConstraint);
+	connect(constr_tab, &ObjectsTableWidget::s_rowUpdated, this, &DomainWidget::handleConstraint);
+	connect(constr_tab, &ObjectsTableWidget::s_rowEdited, this, &DomainWidget::editConstraint);
 
-		configureFormLayout(domain_grid, ObjectType::Domain);
-		setRequiredField(data_type);
-		configureTabOrder({ def_value_edt, not_null_chk,	data_type, constr_name_edt, check_expr_txt });
+	configureFormLayout(domain_grid, ObjectType::Domain);
+	setRequiredField(data_type);
+	configureTabOrder({ def_value_edt, not_null_chk,	data_type, constr_name_edt, check_expr_txt });
 
-		setMinimumSize(580, 580);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
+	setMinimumSize(580, 580);
 }
 
 void DomainWidget::setAttributes(DatabaseModel *model, OperationList *op_list, Schema *schema, Domain *domain)
