@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,48 +18,42 @@
 
 #include "dbobjects/elementstablewidget.h"
 #include "settings/generalconfigwidget.h"
+#include "guiutilsns.h"
 
 ElementsTableWidget::ElementsTableWidget(QWidget *parent) : QWidget(parent)
 {
-	try
-	{
-		handled_elem = nullptr;
-		model = nullptr;
-		parent_obj = nullptr;
+	handled_elem = nullptr;
+	model = nullptr;
+	parent_obj = nullptr;
 
-		element_wgt = new ElementWidget;
-		element_form.setMainWidget(element_wgt);
-		element_form.setButtonConfiguration();
-		connect(&element_form, &BaseForm::accepted, element_wgt, &ElementWidget::applyConfiguration);
+	element_wgt = new ElementWidget;
+	element_form.setMainWidget(element_wgt);
+	element_form.setButtonConfiguration();
+	connect(&element_form, &BaseForm::accepted, element_wgt, &ElementWidget::applyConfiguration);
 
-		QVBoxLayout *vbox = new QVBoxLayout(this);
-		elements_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^
-																				(ObjectsTableWidget::UpdateButton | ObjectsTableWidget::DuplicateButton), true, this);
+	QVBoxLayout *vbox = new QVBoxLayout(this);
+	elements_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^
+																			(ObjectsTableWidget::UpdateButton | ObjectsTableWidget::DuplicateButton), true, this);
 
-		elements_tab->setColumnCount(7);
-		elements_tab->setHeaderLabel(tr("Element"), 0);
-		elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("column")),0);
-		elements_tab->setHeaderLabel(tr("Type"), 1);
-		elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("usertype")),1);
-		elements_tab->setHeaderLabel(tr("Operator"), 2);
-		elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("operator")),2);
-		elements_tab->setHeaderLabel(tr("Operator Class"), 3);
-		elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("opclass")),3);
-		elements_tab->setHeaderLabel(tr("Collation"), 4);
-		elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("collation")),4);
-		elements_tab->setHeaderLabel(tr("Sorting"), 5);
-		elements_tab->setHeaderLabel(tr("Nulls"), 6);
+	elements_tab->setColumnCount(7);
+	elements_tab->setHeaderLabel(tr("Element"), 0);
+	elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("column")),0);
+	elements_tab->setHeaderLabel(tr("Type"), 1);
+	elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("usertype")),1);
+	elements_tab->setHeaderLabel(tr("Operator"), 2);
+	elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("operator")),2);
+	elements_tab->setHeaderLabel(tr("Operator Class"), 3);
+	elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("opclass")),3);
+	elements_tab->setHeaderLabel(tr("Collation"), 4);
+	elements_tab->setHeaderIcon(QPixmap(GuiUtilsNs::getIconPath("collation")),4);
+	elements_tab->setHeaderLabel(tr("Sorting"), 5);
+	elements_tab->setHeaderLabel(tr("Nulls"), 6);
 
-		vbox->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
-		vbox->addWidget(elements_tab);
+	vbox->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
+	vbox->addWidget(elements_tab);
 
-		connect(elements_tab, &ObjectsTableWidget::s_rowAdded, this, &ElementsTableWidget::addElement);
-		connect(elements_tab, &ObjectsTableWidget::s_rowEdited, this, &ElementsTableWidget::editElement);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
+	connect(elements_tab, &ObjectsTableWidget::s_rowAdded, this, &ElementsTableWidget::addElement);
+	connect(elements_tab, &ObjectsTableWidget::s_rowEdited, this, &ElementsTableWidget::editElement);
 }
 
 ElementsTableWidget::~ElementsTableWidget()
@@ -80,7 +74,7 @@ void ElementsTableWidget::showElementData(Element *elem, int elem_idx)
 	}
 	else if(elem->getSimpleColumn().isValid())
 	{
-		elements_tab->setCellText(elem->getSimpleColumn().name, elem_idx, 0);
+		elements_tab->setCellText(elem->getSimpleColumn().getName(), elem_idx, 0);
 		elements_tab->setCellText(BaseObject::getTypeName(ObjectType::Column), elem_idx, 1);
 	}
 	else
