@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,10 +27,13 @@
 
 #include "baseobjectwidget.h"
 #include "ui_extensionwidget.h"
+#include "objectstablewidget.h"
 
 class __libgui ExtensionWidget: public BaseObjectWidget, public Ui::ExtensionWidget {
 	private:
 		Q_OBJECT
+
+		ObjectsTableWidget *types_tab;
 		
 	public:
 		ExtensionWidget(QWidget * parent = nullptr);
