@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
 */
 
 #include "functionwidget.h"
-#include "baseform.h"
-#include "defaultlanguages.h"
+#include "guiutilsns.h"
 
 FunctionWidget::FunctionWidget(QWidget *parent): BaseFunctionWidget(parent, ObjectType::Function)
 {
@@ -204,7 +203,6 @@ void FunctionWidget::alternateReturnTypes()
 
 void FunctionWidget::validateConfiguredFunction()
 {
-	std::vector<BaseObject *>::iterator itr, itr_end;
 	std::vector<BaseObject *> obj_list;
 	Conversion *conv = nullptr;
 	Cast *cast = nullptr;
@@ -213,25 +211,18 @@ void FunctionWidget::validateConfiguredFunction()
 	Operator *oper = nullptr;
 	Type *type = nullptr;
 	Function *func = nullptr;
-	BaseObject *object = nullptr;
 	Transform *transf = nullptr;
 	ForeignDataWrapper *fdw = nullptr;
 	ObjectType obj_type;
 	unsigned idx = 0;
 
-	func=dynamic_cast<Function *>(this->object);
+	func = dynamic_cast<Function *>(this->object);
 
 	try
 	{
-		model->getObjectReferences(func, obj_list);
-		itr = obj_list.begin();
-		itr_end = obj_list.end();
-
-		while(itr != itr_end)
+		for(auto &object : func->getReferences())
 		{
-			object = (*itr);
 			obj_type = object->getObjectType();
-			itr++;
 
 			/* The validation of the function happens as follows:
 
