@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,34 +28,30 @@
 #include "ui_genericsqlwidget.h"
 #include "baseobjectwidget.h"
 #include "codecompletionwidget.h"
+#include "dbobjects/referenceswidget.h"
 #include "widgets/objectstablewidget.h"
 #include "widgets/objectselectorwidget.h"
+#include "widgets/numberedtexteditor.h"
 
 class __libgui GenericSQLWidget: public BaseObjectWidget, public Ui::GenericSQLWidget {
 	private:
 		Q_OBJECT
 
+		ReferencesWidget *obj_refs_wgt;
+
 		NumberedTextEditor *definition_txt, *preview_txt;
 
 		SyntaxHighlighter *definition_hl, *preview_hl;
 
 		CodeCompletionWidget *definition_cp;
 
-		ObjectsTableWidget *objects_refs_tab;
-
-		ObjectSelectorWidget *object_sel;
-
 		/*! \brief This dummy object is used to generated the code preview while the user changes the fields
 		 * in form. Once the dummy is configure it is copied to the real object being handled by the form (this->object) */
 		GenericSQL dummy_gsql;
 
-		//! \brief A regular expression used to remove attribute/reference delimiters {} from the names of configured references
-		static const QRegularExpression AttrDelimRegexp;
-
-		void showObjectReferenceData(int row, BaseObject *object, const QString &ref_name, bool use_signature, bool format_name);
-
 	public:
 		GenericSQLWidget(QWidget * parent = nullptr);
+
 		void setAttributes(DatabaseModel *model, OperationList *op_list, GenericSQL *genericsql=nullptr);
 
 	public slots:
@@ -63,10 +59,6 @@ class __libgui GenericSQLWidget: public BaseObjectWidget, public Ui::GenericSQLW
 
 	private slots:
 		void updateCodePreview();
-		void addObjectReference(int row);
-		void editObjectReference(int row);
-		void updateObjectReference(int row);
-		void clearObjectReferenceForm();
 };
 
 #endif
