@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 #include "policy.h"
 #include "widgets/objectstablewidget.h"
 #include "widgets/modelobjectswidget.h"
+#include "utils/syntaxhighlighter.h"
+#include "widgets/numberedtexteditor.h"
 
 class __libgui PolicyWidget : public BaseObjectWidget, Ui::PolicyWidget {
 	private:
