@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,30 +20,23 @@
 
 SequenceWidget::SequenceWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Sequence)
 {
-	try
-	{
-		Ui_SequenceWidget::setupUi(this);
+	Ui_SequenceWidget::setupUi(this);
 
-		column_sel=nullptr;
-		column_sel=new ObjectSelectorWidget(ObjectType::Column, this);
-		sequence_grid->addWidget(column_sel, 4, 1, 1, 3);
+	column_sel=nullptr;
+	column_sel=new ObjectSelectorWidget(ObjectType::Column, this);
+	sequence_grid->addWidget(column_sel, 4, 1, 1, 3);
 
-		configureFormLayout(sequence_grid, ObjectType::Sequence);
-		sequence_grid->addItem(new QSpacerItem(10,0,QSizePolicy::Minimum,QSizePolicy::Expanding), sequence_grid->count(), 0);
-		configureTabOrder();
+	configureFormLayout(sequence_grid, ObjectType::Sequence);
+	sequence_grid->addItem(new QSpacerItem(10,0,QSizePolicy::Minimum,QSizePolicy::Expanding), sequence_grid->count(), 0);
+	configureTabOrder();
 
-		def_values_cmb->addItem(tr("User defined"));
-		def_values_cmb->addItem(QString("smallserial"));
-		def_values_cmb->addItem(QString("serial"));
-		def_values_cmb->addItem(QString("bigserial"));
-		setMinimumSize(520, 350);
+	def_values_cmb->addItem(tr("User defined"));
+	def_values_cmb->addItem("smallserial");
+	def_values_cmb->addItem("serial");
+	def_values_cmb->addItem("bigserial");
+	setMinimumSize(520, 350);
 
-		connect(def_values_cmb, &QComboBox::currentIndexChanged, this, &SequenceWidget::setDefaultValues);
-	}
-	catch(Exception &e)
-	{
-		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
-	}
+	connect(def_values_cmb, &QComboBox::currentIndexChanged, this, &SequenceWidget::setDefaultValues);
 }
 
 void SequenceWidget::setAttributesReadonly(DatabaseModel *model, OperationList *op_list, Schema *schema, Sequence *sequence, Column *column)
@@ -87,11 +80,11 @@ void SequenceWidget::setAttributes(DatabaseModel *model, Sequence *sequence)
 	else
 	{
 		cyclic_chk->setChecked(false);
-		start_edt->setText(QString("1"));
+		start_edt->setText("1");
 		maximum_edt->setText(Sequence::MaxPositiveValue);
-		minimum_edt->setText(QString("0"));
-		cache_edt->setText(QString("1"));
-		increment_edt->setText(QString("1"));
+		minimum_edt->setText("0");
+		cache_edt->setText("1");
+		increment_edt->setText("1");
 	}
 }
 
