@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "widgets/objectselectorwidget.h"
 #include "ui_transformwidget.h"
 
-class TransformWidget: public BaseObjectWidget, public Ui::TransformWidget {
+class __libgui TransformWidget: public BaseObjectWidget, public Ui::TransformWidget {
 	private:
 		Q_OBJECT
 
