@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,9 +19,19 @@
 #include "appearanceconfigwidget.h"
 #include "widgets/modelwidget.h"
 #include "widgets/objectstablewidget.h"
+#include "customuistyle.h"
+#include "guiutilsns.h"
+#include "relationshipview.h"
+#include "tableview.h"
+#include "styledtextboxview.h"
+#include "graphicalview.h"
 
 std::map<QString, attribs_map> AppearanceConfigWidget::config_params;
 
+QPalette AppearanceConfigWidget::system_pal;
+
+QString AppearanceConfigWidget::UiThemeId;
+
 std::map<QPalette::ColorRole, QStringList> AppearanceConfigWidget::system_ui_colors = {
 	{ QPalette::WindowText, {} },
 	{ QPalette::Button, {} },
@@ -107,6 +117,7 @@ AppearanceConfigWidget::AppearanceConfigWidget(QWidget * parent) : BaseConfigWid
 {
 	setupUi(this);
 	storeSystemUiColors();
+	show_grid = show_delimiters = false;
 
 	QStringList conf_ids={
 	/* 00 */	Attributes::Global,
@@ -194,7 +205,6 @@ AppearanceConfigWidget::AppearanceConfigWidget(QWidget * parent) : BaseConfigWid
 
 	model=new DatabaseModel;
 	scene=new ObjectsScene;
-	scene->setSceneRect(QRectF(0,0,500,500));
 	placeholder=new RoundedRectItem;
 
 	viewp=new QGraphicsView(scene);
@@ -240,11 +250,11 @@ AppearanceConfigWidget::AppearanceConfigWidget(QWidget * parent) : BaseConfigWid
 	font_preview_txt=new NumberedTextEditor(this);
 	font_preview_txt->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 	font_preview_txt->setPlainText(
-"-- object: public.foo | type: TABLE --\n \
+"-- object: public.foo | type: TABLE --\n\
 CREATE TABLE public.table_b (\n \
 \tid serial NOT NULL,\n \
 \tsku integer NOT NULL,\n \
-\tCONSTRAINT foo_pk PRIMARY KEY (id)\n \
+\tCONSTRAINT foo_pk PRIMARY KEY (id)\n\
 );\n");
 
 	font_preview_hl = new SyntaxHighlighter(font_preview_txt, false, true);
@@ -261,9 +271,7 @@ CREATE TABLE public.table_b (\n \
 	ui_theme_cmb->addItem(tr("System default"), Attributes::System);
 	ui_theme_cmb->addItem(tr("Light"), Attributes::Light);
 	ui_theme_cmb->addItem(tr("Dark"), Attributes::Dark);
-
-	syntax_hl_theme_cmb->addItem(tr("Light"), Attributes::Light);
-	syntax_hl_theme_cmb->addItem(tr("Dark"), Attributes::Dark);
+	ui_theme_cmb->addItem(tr("InkSaver"), Attributes::InkSaver);
 
 	icons_size_cmb->addItem(tr("Big"), Attributes::Big);
 	icons_size_cmb->addItem(tr("Medium"), Attributes::Medium);
@@ -307,10 +315,8 @@ CREATE TABLE public.table_b (\n \
 	connect(grid_size_spb, &QSpinBox::textChanged, this, &AppearanceConfigWidget::previewCanvasColors);
 	connect(grid_pattern_cmb, &QComboBox::currentIndexChanged, this, &AppearanceConfigWidget::previewCanvasColors);
 
-	connect(syntax_hl_theme_cmb, &QComboBox::currentTextChanged, this, &AppearanceConfigWidget::applySyntaxHighlightTheme);
-
-	connect(ui_theme_cmb, &QComboBox::currentTextChanged, this, &AppearanceConfigWidget::previewUiSettings);
-	connect(icons_size_cmb, &QComboBox::currentTextChanged, this, &AppearanceConfigWidget::previewUiSettings);
+	connect(ui_theme_cmb, &QComboBox::activated, this, __slot(this, AppearanceConfigWidget::previewUiSettings));
+	connect(icons_size_cmb, &QComboBox::currentTextChanged, this, __slot(this, AppearanceConfigWidget::previewUiSettings));
 
 	connect(custom_scale_chk, &QCheckBox::toggled, this, [this](bool toggled){
 		custom_scale_spb->setEnabled(toggled);
@@ -321,6 +327,10 @@ CREATE TABLE public.table_b (\n \
 		setConfigurationChanged(true);
 	});
 
+	connect(expansion_factor_spb, &QSpinBox::valueChanged, this, [this](){
+		setConfigurationChanged(true);
+	});
+
 	connect(min_obj_opacity_spb, &QSpinBox::valueChanged, this, [this](){
 		setConfigurationChanged(true);
 	});
@@ -336,7 +346,9 @@ CREATE TABLE public.table_b (\n \
 
 AppearanceConfigWidget::~AppearanceConfigWidget()
 {
+	scene->blockSignals(true);
 	scene->removeItem(placeholder);
+	scene->blockSignals(false);
 
 	delete placeholder;
 	delete viewp;
@@ -344,37 +356,38 @@ AppearanceConfigWidget::~AppearanceConfigWidget()
 	delete model;
 }
 
+void AppearanceConfigWidget::showEvent(QShowEvent *)
+{
+	/* We store the current changed state of the configurations
+	 * because the call to previewCanvasColors() always set
+	 * the settings as changed and since the show event
+	 * doens't need to change settings we do a small workaround.
+	 *
+	 * This will avoid reload appearance settings when the user
+	 * just displayed the appearance settings but don't changed
+	 * anything. */
+	bool conf_changed = isConfigurationChanged();
+
+	// Store the current state of grid/delimiters display
+	show_grid = ObjectsScene::isShowGrid();
+	show_delimiters = ObjectsScene::isShowPageDelimiters();
+	previewCanvasColors();
+
+	setConfigurationChanged(conf_changed);
+}
+
+void AppearanceConfigWidget::hideEvent(QHideEvent *)
+{
+	// Restore the original state of grid/delimiters display
+	ObjectsScene::setShowGrid(show_grid);
+	ObjectsScene::setShowPageDelimiters(show_delimiters);
+}
+
 std::map<QString, attribs_map> AppearanceConfigWidget::getConfigurationParams()
 {
 	return config_params;
 }
 
-void AppearanceConfigWidget::updateDropShadows(const QString theme_id)
-{
-	QColor color(0, 0, 0, 80);
-	int radius = 6, x = 1, y = 1;
-	QGraphicsDropShadowEffect *shadow = nullptr;
-	QString class_name = "QToolButton";
-
-	if(theme_id == Attributes::Light)
-	{
-		radius = 1;
-		color.setRgb(225, 225, 225);
-		color.setAlpha(255);
-	}
-
-	for(auto &wgt : qApp->allWidgets())
-	{
-		if(wgt->metaObject()->className() == class_name && wgt->graphicsEffect())
-		{
-			shadow = qobject_cast<QGraphicsDropShadowEffect *>(wgt->graphicsEffect());
-			shadow->setColor(color);
-			shadow->setOffset(x, y);
-			shadow->setBlurRadius(radius);
-		}
-	}
-}
-
 void AppearanceConfigWidget::loadExampleModel()
 {
 	try
@@ -382,77 +395,67 @@ void AppearanceConfigWidget::loadExampleModel()
 		if(model->getObjectCount() != 0)
 			return;
 
-		RelationshipView *rel=nullptr;
-		StyledTextboxView *txtbox=nullptr;
-		TableView *tab=nullptr;
-		GraphicalView *view=nullptr;
+		RelationshipView *rel = nullptr;
+		StyledTextboxView *txtbox = nullptr;
+		TableView *tab = nullptr;
+		GraphicalView *view = nullptr;
 		unsigned count = 0, i = 0;
-		QList<BaseObjectView *> graph_objs;
 
 		model->loadModel(GlobalAttributes::getTmplConfigurationFilePath("", GlobalAttributes::ExampleModel));
 
-		count=model->getObjectCount(ObjectType::Table);
+		count = model->getObjectCount(ObjectType::Table);
 		for(i=0; i < count; i++)
 		{
-			tab=new TableView(model->getTable(i));
-			tab->setSelected(i==1);
+			tab = new TableView(model->getTable(i));
 			scene->addItem(tab);
-			graph_objs.append(tab);
+			tab->setEnabled(false);
 		}
 
-		count=model->getObjectCount(ObjectType::ForeignTable);
-		for(i=0; i < count; i++)
+		count = model->getObjectCount(ObjectType::ForeignTable);
+		for(i = 0; i < count; i++)
 		{
-			tab=new TableView(model->getForeignTable(i));
+			tab = new TableView(model->getForeignTable(i));
 			scene->addItem(tab);
-			graph_objs.append(tab);
+			tab->setEnabled(false);
 		}
 
-		count=model->getObjectCount(ObjectType::View);
-		for(i=0; i < count; i++)
+		count = model->getObjectCount(ObjectType::View);
+		for(i = 0; i < count; i++)
 		{
-			view=new GraphicalView(model->getView(i));
+			view = new GraphicalView(model->getView(i));
 			scene->addItem(view);
-			graph_objs.append(view);
+			view->setEnabled(false);
 		}
 
-		count=model->getObjectCount(ObjectType::Relationship);
-		for(i=0; i < count; i++)
+		count = model->getObjectCount(ObjectType::Relationship);
+		for(i = 0; i < count; i++)
 		{
-			rel=new RelationshipView(model->getRelationship(i, ObjectType::Relationship));
+			rel = new RelationshipView(model->getRelationship(i, ObjectType::Relationship));
 			scene->addItem(rel);
-			graph_objs.append(rel);
+			rel->setEnabled(false);
 		}
 
-		count=model->getObjectCount(ObjectType::BaseRelationship);
-		for(i=0; i < count; i++)
+		count = model->getObjectCount(ObjectType::BaseRelationship);
+		for(i = 0; i < count; i++)
 		{
-			rel=new RelationshipView(model->getRelationship(i, ObjectType::BaseRelationship));
+			rel = new RelationshipView(model->getRelationship(i, ObjectType::BaseRelationship));
 			scene->addItem(rel);
-			graph_objs.append(rel);
+			rel->setEnabled(false);
 		}
 
-		count=model->getObjectCount(ObjectType::Textbox);
-		for(i=0; i < count; i++)
+		count = model->getObjectCount(ObjectType::Textbox);
+		for(i = 0; i < count; i++)
 		{
-			txtbox=new StyledTextboxView(model->getTextbox(i));
-			txtbox->setSelected(i==0);
+			txtbox = new StyledTextboxView(model->getTextbox(i));
 			scene->addItem(txtbox);
-			graph_objs.append(txtbox);
+			txtbox->setEnabled(false);
 		}
 
-		for(auto &obj : graph_objs)
-		{
-			obj->setFlag(QGraphicsItem::ItemIsSelectable, false);
-			obj->setFlag(QGraphicsItem::ItemIsMovable, false);
-		}
-
-		placeholder->setRect(QRectF(400, 280, 200, 150));
+		placeholder->setRect(QRectF(400, 150, 200, 150));
 		updatePlaceholderItem();
 		scene->addItem(placeholder);
 		scene->setActiveLayers(QList<unsigned>({0}));
 		scene->setSceneRect(scene->itemsBoundingRect(false));
-
 	}
 	catch(Exception &e)
 	{
@@ -472,29 +475,29 @@ void AppearanceConfigWidget::loadConfiguration()
 {
 	try
 	{
+		// Storing the original system palette before loading the appearance config file
+		system_pal = qApp->palette();
+
 		BaseConfigWidget::loadConfiguration(GlobalAttributes::AppearanceConf, config_params, { Attributes::Id }, true);
 
 		ui_theme_cmb->blockSignals(true);
-		syntax_hl_theme_cmb->blockSignals(true);
 		icons_size_cmb->blockSignals(true);
 
 		int idx = ui_theme_cmb->findData(config_params[GlobalAttributes::AppearanceConf][Attributes::UiTheme], Qt::UserRole, Qt::MatchExactly);
 		ui_theme_cmb->setCurrentIndex(idx < 0 ? 0 : idx);
 
-		idx = syntax_hl_theme_cmb->findData(config_params[GlobalAttributes::AppearanceConf][Attributes::SyntaxHlTheme], Qt::UserRole, Qt::MatchExactly);
-		syntax_hl_theme_cmb->setCurrentIndex(idx < 0 ? 0 : idx);
-
 		idx = icons_size_cmb->findData(config_params[GlobalAttributes::AppearanceConf][Attributes::IconsSize], Qt::UserRole, Qt::MatchExactly);
 		icons_size_cmb->setCurrentIndex(idx < 0 ? 0 : idx);
 
 		ui_theme_cmb->blockSignals(false);
-		syntax_hl_theme_cmb->blockSignals(false);
 		icons_size_cmb->blockSignals(false);
 
 		custom_scale_chk->setChecked(config_params[GlobalAttributes::AppearanceConf].count(Attributes::CustomScale));
 		custom_scale_spb->setValue(config_params[GlobalAttributes::AppearanceConf][Attributes::CustomScale].toDouble());
+		expansion_factor_spb->setValue(config_params[Attributes::Design][Attributes::ExpansionFactor].toUInt());
 
 		applyConfiguration();
+		setConfigurationChanged(false);
 	}
 	catch(Exception &e)
 	{
@@ -611,12 +614,11 @@ void AppearanceConfigWidget::saveConfiguration()
 	{
 		attribs_map attribs;
 		AppearanceConfigItem item;
-		QString attrib_id, hl_theme = syntax_hl_theme_cmb->currentData(Qt::UserRole).toString();
+		QString attrib_id;
 		QFont font;
 
 		config_params.erase(GlobalAttributes::AppearanceConf);
 		attribs[Attributes::UiTheme] =  ui_theme_cmb->currentData(Qt::UserRole).toString();
-		attribs[Attributes::SyntaxHlTheme] = hl_theme;
 		attribs[Attributes::IconsSize] = icons_size_cmb->currentData(Qt::UserRole).toString();
 
 		attribs[Attributes::CustomScale] = custom_scale_chk->isChecked() ?
@@ -633,6 +635,8 @@ void AppearanceConfigWidget::saveConfiguration()
 		attribs[Attributes::GridColor] = grid_color_cp->getColor(0).name();
 		attribs[Attributes::CanvasColor] = canvas_color_cp->getColor(0).name();
 		attribs[Attributes::DelimitersColor] = delimiters_color_cp->getColor(0).name();
+		attribs[Attributes::ExpansionFactor] = QString::number(expansion_factor_spb->value());
+
 		config_params[Attributes::Design] = attribs;
 		attribs.clear();
 
@@ -644,6 +648,7 @@ void AppearanceConfigWidget::saveConfiguration()
 		attribs[Attributes::LineNumbersBgColor]=line_numbers_bg_cp->getColor(0).name();
 		attribs[Attributes::LineHighlightColor]=line_highlight_cp->getColor(0).name();
 		attribs[Attributes::TabWidth]=QString::number(tab_width_chk->isChecked() ? tab_width_spb->value() : 0);
+
 		config_params[Attributes::Code] = attribs;
 		attribs.clear();
 
@@ -692,6 +697,8 @@ void AppearanceConfigWidget::saveConfiguration()
 		config_params[Attributes::Objects] = attribs;
 		BaseConfigWidget::saveConfiguration(GlobalAttributes::AppearanceConf, config_params);
 
+		QString hl_theme = __getUiThemeId();
+
 		/* Copying the syntax highilighting files from the selected theme folder to the user's storage
 		 * in order to reflect the new syntax highlighting setting in the whole application */
 		QStringList theme_hl_files = {
@@ -724,6 +731,8 @@ void AppearanceConfigWidget::saveConfiguration()
 												tr("The template file `%1' could not be accessed!").arg(theme_hl_files[i]) : "");
 			}
 		}
+
+		setConfigurationChanged(false);
 	}
 	catch(Exception &e)
 	{
@@ -819,31 +828,13 @@ void AppearanceConfigWidget::applyConfiguration()
 	applyUiTheme();
 	applyDesignCodeStyle();
 	applyObjectsStyle();
+	previewCanvasColors();
 
-	ObjectsScene::setCanvasColor(canvas_color_cp->getColor(0));
-	ObjectsScene::setGridColor(grid_color_cp->getColor(0));
-	ObjectsScene::setDelimitersColor(delimiters_color_cp->getColor(0));
-	ObjectsScene::setGridPattern(grid_pattern_cmb->currentIndex() == 0 ?
-																 ObjectsScene::SquarePattern : ObjectsScene::DotPattern);
-	ObjectsScene::setGridSize(grid_size_spb->value());
 	BaseTableView::setAttributesPerPage(BaseTable::AttribsSection, attribs_per_page_spb->value());
 	BaseTableView::setAttributesPerPage(BaseTable::ExtAttribsSection, ext_attribs_per_page_spb->value());
 	ModelWidget::setMinimumObjectOpacity(min_obj_opacity_spb->value());
-
-	double fnt_size = config_params[Attributes::Code][Attributes::FontSize].toDouble();
-	QFont fnt;
-
-	if(fnt_size < 5.0)
-		fnt_size = 5.0;
-
-	fnt.setFamily(config_params[Attributes::Code][Attributes::Font]);
-	fnt.setPointSizeF(fnt_size);
-	NumberedTextEditor::setLineNumbersVisible(disp_line_numbers_chk->isChecked());
-	NumberedTextEditor::setLineHighlightColor(line_highlight_cp->getColor(0));
-	NumberedTextEditor::setHighlightLines(hightlight_lines_chk->isChecked());
-	NumberedTextEditor::setDefaultFont(fnt);
-	LineNumbersWidget::setColors(line_numbers_cp->getColor(0), line_numbers_bg_cp->getColor(0));
-	SyntaxHighlighter::setDefaultFont(fnt);
+	ObjectsScene::setExpansionFactor(expansion_factor_spb->value());
+	GuiUtilsNs::updateDropShadows(qApp->allWidgets());
 
 	loadExampleModel();
 	model->setObjectsModified();
@@ -911,12 +902,17 @@ void AppearanceConfigWidget::previewCodeFontStyle()
 
 void AppearanceConfigWidget::previewCanvasColors()
 {
+	ObjectsScene::setShowGrid(true);
+	ObjectsScene::setShowPageDelimiters(true);
+
 	ObjectsScene::setCanvasColor(canvas_color_cp->getColor(0));
 	ObjectsScene::setGridPattern(grid_pattern_cmb->currentIndex() == 0 ?
 																 ObjectsScene::SquarePattern : ObjectsScene::DotPattern);
+
 	ObjectsScene::setGridColor(grid_color_cp->getColor(0));
-	ObjectsScene::setDelimitersColor(delimiters_color_cp->getColor(0));
+	ObjectsScene::setPageDelimitersColor(delimiters_color_cp->getColor(0));
 	ObjectsScene::setGridSize(grid_size_spb->value());
+
 	scene->update();
 	setConfigurationChanged(true);
 }
@@ -926,27 +922,23 @@ void AppearanceConfigWidget::applyUiTheme()
 	std::map<QString, std::map<QPalette::ColorRole, QStringList> *> color_maps = {
 		{ { Attributes::System }, { &system_ui_colors } },
 		{ { Attributes::Dark }, { &dark_ui_colors } },
-		{ { Attributes::Light }, { &light_ui_colors } }
+		{ { Attributes::Light }, { &light_ui_colors } },
+		{ { Attributes::InkSaver }, { &light_ui_colors } }
 	};
 
 	std::map<QString, QStringList *> item_color_lists = {
 		{ { Attributes::System }, { &light_tab_item_colors } },
 		{ { Attributes::Dark }, { &dark_tab_item_colors } },
-		{ { Attributes::Light }, { &light_tab_item_colors } }
+		{ { Attributes::Light }, { &light_tab_item_colors } },
+		{ { Attributes::InkSaver }, { &light_tab_item_colors } },
 	};
 
-	QString ui_theme = ui_theme_cmb->currentData(Qt::UserRole).toString();
+	QString ui_theme = __getUiThemeId();
 	std::map<QPalette::ColorRole, QStringList> *color_map = color_maps[ui_theme];
 	QStringList *item_colors = item_color_lists[ui_theme];
+	QPalette pal = system_pal;
 
-	/* Storing an immutable copy of the original application's palette
-	 * in order to use it on each time the UI theme changes.
-	 *
-	 * NOTE: if we just copy the qApp palette everytime to pal we don't get
-	 * the desired result, instead, the color theme switches randomly from dark to
-	 * light and vice-versa.*/
-	static const QPalette orig_pal = qApp->palette();
-	QPalette pal = orig_pal;
+	UiThemeId = ui_theme;
 
 	for(unsigned idx = 0; idx < static_cast<unsigned>(item_colors->size()); idx++)
 	{
@@ -975,29 +967,49 @@ void AppearanceConfigWidget::applyUiTheme()
 	setConfigurationChanged(true);
 }
 
+QString AppearanceConfigWidget::__getUiThemeId()
+{
+	if(ui_theme_cmb->currentIndex() > 0)
+		return ui_theme_cmb->currentData(Qt::UserRole).toString();
+
+	/* If the user chose the "System default" theme
+	 * we check if the system is using dark theme (text color lightness greater
+	 * than window color lightness) or light theme */
+	return getUiLightness(system_pal);
+}
+
+QString AppearanceConfigWidget::getUiThemeId()
+{
+	return UiThemeId;
+}
+
+QString AppearanceConfigWidget::getUiLightness(const QPalette &pal)
+{
+	if(pal.color(QPalette::WindowText).lightness() >
+			pal.color(QPalette::Window).lightness())
+		return Attributes::Dark;
+
+	return Attributes::Light;
+}
+
 void AppearanceConfigWidget::previewUiSettings()
 {
-	int idx = ui_theme_cmb->currentIndex() - 1;
-
-	if(idx < 0 )
-		idx = 0;
-
-	syntax_hl_theme_cmb->blockSignals(true);
-	syntax_hl_theme_cmb->setCurrentIndex(idx);
-	syntax_hl_theme_cmb->blockSignals(false);
-
-	QApplication::setOverrideCursor(Qt::WaitCursor);
+	qApp->setOverrideCursor(Qt::WaitCursor);
 	applyUiTheme();
 	applyDesignCodeTheme();
-	updateDropShadows(ui_theme_cmb->currentData(Qt::UserRole).toString());
-	QApplication::restoreOverrideCursor();
+
+	model->setObjectsModified();
+	scene->update();
+
+	GuiUtilsNs::updateDropShadows(qApp->allWidgets());
+	qApp->restoreOverrideCursor();
 }
 
 void AppearanceConfigWidget::applySyntaxHighlightTheme()
 {
 	QString filename = GlobalAttributes::getTmplConfigurationFilePath(GlobalAttributes::ThemesDir +
 																																		GlobalAttributes::DirSeparator +
-																																		syntax_hl_theme_cmb->currentData(Qt::UserRole).toString().toLower(),
+																																				__getUiThemeId(),
 																																		GlobalAttributes::SQLHighlightConf +
 																																		GlobalAttributes::ConfigurationExt);
 
@@ -1017,7 +1029,7 @@ void AppearanceConfigWidget::applyDesignCodeTheme()
 {
 	QString filename = GlobalAttributes::getTmplConfigurationFilePath(GlobalAttributes::ThemesDir +
 																																		GlobalAttributes::DirSeparator +
-																																		syntax_hl_theme_cmb->currentData(Qt::UserRole).toString().toLower(),
+																																				__getUiThemeId(),
 																																		GlobalAttributes::AppearanceConf +
 																																		GlobalAttributes::ConfigurationExt);
 
@@ -1053,15 +1065,18 @@ void AppearanceConfigWidget::applyUiStyleSheet()
 	else
 	{
 		QByteArray ui_stylesheet = ui_style.readAll();
-		QString ico_style_conf = GlobalAttributes::getTmplConfigurationFilePath("",
-																																						"icons-" + icons_size_cmb->currentData().toString().toLower() +
-																																						GlobalAttributes::ConfigurationExt);
-		QString ui_theme = ui_theme_cmb->currentData(Qt::UserRole).toString(),
+
+		QString icon_size = icons_size_cmb->currentData().toString().toLower(),
+				ico_style_conf = GlobalAttributes::getTmplConfigurationFilePath("",
+																																				"icons-" + icon_size +
+																																				GlobalAttributes::ConfigurationExt);
+		QString ui_theme = __getUiThemeId(), extra_style_conf;
+
 		extra_style_conf = GlobalAttributes::getTmplConfigurationFilePath(GlobalAttributes::ThemesDir +
-																																		 GlobalAttributes::DirSeparator +
-																																		 ui_theme,
-																																		 "extra-" + GlobalAttributes::UiStyleConf +
-																																		 GlobalAttributes::ConfigurationExt);
+																																			GlobalAttributes::DirSeparator +
+																																			ui_theme,
+																																			"extra-" + GlobalAttributes::UiStyleConf +
+																																			GlobalAttributes::ConfigurationExt);
 
 		if(QFileInfo::exists(extra_style_conf))
 		{
@@ -1080,13 +1095,25 @@ void AppearanceConfigWidget::applyUiStyleSheet()
 			{
 				Messagebox msg;
 				msg.show(Exception(Exception::getErrorMessage(ErrorCode::FileDirectoryNotAccessed).arg(ico_style_conf),
-													 ErrorCode::FileDirectoryNotAccessed,__PRETTY_FUNCTION__,__FILE__,__LINE__));
+														ErrorCode::FileDirectoryNotAccessed,__PRETTY_FUNCTION__,__FILE__,__LINE__));
 			}
 			else
-				ui_stylesheet.append(ico_style.readAll());		
+				ui_stylesheet.append(ico_style.readAll());
 		}
 
 		qApp->setStyleSheet(ui_stylesheet);
+
+		// Overriding pixel metrics of small icons in table headers, menu icons, etc
+		int small_ico_sz = 0;
+
+		if(icon_size == Attributes::Small)
+			small_ico_sz = 16;
+		else if(icon_size == Attributes::Medium)
+			small_ico_sz = 18;
+		else
+			small_ico_sz = 20;
+
+		CustomUiStyle::setPixelMetricValue(QStyle::PM_SmallIconSize, small_ico_sz);
 	}
 }
 
