@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,12 +18,11 @@
 
 #include "generalconfigwidget.h"
 #include "objectsscene.h"
+#include "relationshipview.h"
 #include "widgets/modelwidget.h"
 #include "operationlist.h"
-#include "utils/syntaxhighlighter.h"
 #include "mainwindow.h"
 #include "widgets/numberedtexteditor.h"
-#include "widgets/linenumberswidget.h"
 #include "tools/sqlexecutionwidget.h"
 #include "tools/modeldatabasediffform.h"
 #include "tools/databaseimportform.h"
@@ -45,17 +44,17 @@ GeneralConfigWidget::GeneralConfigWidget(QWidget * parent) : BaseConfigWidget(pa
 	confs_dir_sel = new FileSelectorWidget(this);
 	confs_dir_sel->setToolTip(tr("pgModeler configurations directory for the current user"));
 	confs_dir_sel->setReadOnly(true);
-	confs_dir_sel->setFileMode(QFileDialog::Directory);
+	confs_dir_sel->setDirectoryMode(true);
 	confs_dir_sel->setSelectedFile(GlobalAttributes::getConfigurationsPath());
 	general_grid->addWidget(confs_dir_sel, 1, 1, 1, 1);
 
 	source_editor_sel = new FileSelectorWidget(this);
-	source_editor_sel->setToolTip(tr("pgModeler configurations directory for the current user"));
 	source_editor_sel->setAllowFilenameInput(true);
-	source_editor_sel->setFileMode(QFileDialog::ExistingFile);
+	source_editor_sel->setFileMustExist(true);
 	source_editor_sel->setAcceptMode(QFileDialog::AcceptOpen);
 	source_editor_sel->setWindowTitle(tr("Select application"));
 	source_editor_sel->setToolTip(tr("External source code editor application"));
+	source_editor_sel->setCheckExecutionFlag(true);
 	general_grid->addWidget(source_editor_sel, 2, 1, 1, 1);
 
 	int i = 0;
@@ -73,6 +72,10 @@ GeneralConfigWidget::GeneralConfigWidget(QWidget * parent) : BaseConfigWidget(pa
 	connect(save_restore_geometry_chk, &QCheckBox::toggled, reset_sizes_tb, &QToolButton::setEnabled);
 	connect(reset_sizes_tb, &QToolButton::clicked, this, &GeneralConfigWidget::resetDialogsSizes);
 
+	connect(trunc_columns_data_chk, &QCheckBox::toggled, trunc_columns_data_spb, &QComboBox::setEnabled);
+	connect(trunc_columns_data_chk, &QCheckBox::toggled, disable_inline_editor_chk, &QComboBox::setEnabled);
+	connect(trunc_columns_data_chk, &QCheckBox::toggled, bytes_lbl, &QLabel::setEnabled);
+
 	config_params[Attributes::Configuration][Attributes::GridSize]="";
 	config_params[Attributes::Configuration][Attributes::OpListSize]="";
 	config_params[Attributes::Configuration][Attributes::AutoSaveInterval]="";
@@ -106,9 +109,35 @@ GeneralConfigWidget::GeneralConfigWidget(QWidget * parent) : BaseConfigWidget(pa
 	config_params[Attributes::Configuration][Attributes::UseCurvedLines]="";
 	config_params[Attributes::Configuration][Attributes::SaveRestoreGeometry]="";
 	config_params[Attributes::Configuration][Attributes::LowVerbosity]="";
+	config_params[Attributes::Configuration][Attributes::DefaultSchema]="";
 
 	selectPaperSize();
 
+#ifdef NO_UPDATE_CHECK
+	check_update_chk->setChecked(false);
+	check_update_chk->setVisible(false);
+	check_versions_cmb->setVisible(false);
+#endif
+
+	//Retrieving the available UI dictionaries
+	QStringList langs = QDir(GlobalAttributes::getLanguagesPath() +
+													 GlobalAttributes::DirSeparator,
+													 "*.qm", QDir::Name, QDir::AllEntries | QDir::NoDotAndDotDot).entryList();
+
+	langs.replaceInStrings(".qm", "");
+	ui_language_cmb->addItem(tr("System default"));
+	QString native_lang;
+
+	for(auto &lang : langs)
+	{
+		native_lang = QLocale(lang).nativeLanguageName();
+		native_lang[0] = native_lang[0].toUpper();
+		ui_language_cmb->addItem(QString("%1 (%2 : %3)")
+														 .arg(native_lang)
+														 .arg(QLocale::languageToString(QLocale(lang).language()))
+														 .arg(lang), lang);
+	}
+
 	QList<QCheckBox *> chk_boxes=this->findChildren<QCheckBox *>();
 	QList<QSpinBox *> spin_boxes=this->findChildren<QSpinBox *>();
 	QList<QDoubleSpinBox *> dspin_boxes=this->findChildren<QDoubleSpinBox *>();
@@ -118,7 +147,7 @@ GeneralConfigWidget::GeneralConfigWidget(QWidget * parent) : BaseConfigWidget(pa
 	for(QCheckBox *chk : chk_boxes)
 	{
 		child_wgts.push_back(chk);
-		connect(chk, &QCheckBox::clicked, this, &GeneralConfigWidget::setConfigurationChanged);
+		connect(chk, &QCheckBox::toggled, this, &GeneralConfigWidget::setConfigurationChanged);
 	}
 
 	for(QSpinBox *spin : spin_boxes)
@@ -142,36 +171,24 @@ GeneralConfigWidget::GeneralConfigWidget(QWidget * parent) : BaseConfigWidget(pa
 	for(QRadioButton *radio : radios)
 	{
 		child_wgts.push_back(radio);
-		connect(radio, &QRadioButton::clicked, this, &GeneralConfigWidget::setConfigurationChanged);
+		connect(radio, &QRadioButton::toggled, this, &GeneralConfigWidget::setConfigurationChanged);
 	}
 
-	connect(clear_sql_history_tb, &QToolButton::clicked, [](){
+	connect(source_editor_sel, &FileSelectorWidget::s_selectorChanged, this, &GeneralConfigWidget::setConfigurationChanged);
+
+	connect(clear_sql_history_tb, &QToolButton::clicked, this, [](){
 		SQLExecutionWidget::destroySQLHistory();
 	});
 
-#ifdef NO_UPDATE_CHECK
-	check_update_chk->setChecked(false);
-	check_update_chk->setVisible(false);
-#endif
+	connect(reset_alerts_choices_tb, &QToolButton::clicked, this, &GeneralConfigWidget::resetAlertChoices);
+}
 
-	//Retrieving the available UI dictionaries
-	QStringList langs = QDir(GlobalAttributes::getLanguagesPath() +
-													 GlobalAttributes::DirSeparator,
-													 QString("*.qm"), QDir::Name, QDir::AllEntries | QDir::NoDotAndDotDot).entryList();
+void GeneralConfigWidget::showEvent(QShowEvent *)
+{
+	reset_alerts_choices_tb->setEnabled(config_params[Attributes::Configuration][Attributes::AlertUnsavedModels] != Attributes::True ||
+																			 config_params[Attributes::Configuration][Attributes::AlertOpenSqlTabs] != Attributes::True ||
+																			 config_params[Attributes::Configuration][Attributes::UseDefDisambiguation] == Attributes::True);
 
-	langs.replaceInStrings(QString(".qm"), "");
-	ui_language_cmb->addItem(tr("System default"));
-	QString native_lang;
-
-	for(QString lang : langs)
-	{
-		native_lang = QLocale(lang).nativeLanguageName();
-		native_lang[0] = native_lang[0].toUpper();
-		ui_language_cmb->addItem(QString("%1 (%2 : %3)")
-														 .arg(native_lang)
-														 .arg(QLocale::languageToString(QLocale(lang).language()))
-														 .arg(lang), lang);
-	}
 }
 
 void GeneralConfigWidget::loadConfiguration()
@@ -187,6 +204,11 @@ void GeneralConfigWidget::loadConfiguration()
 
 		BaseConfigWidget::loadConfiguration(GlobalAttributes::GeneralConf, config_params, { Attributes::Id });
 
+		if(!config_params[Attributes::Configuration].count(Attributes::AlertUnsavedModels) ||
+			 !config_params[Attributes::Configuration].count(Attributes::AlertOpenSqlTabs) ||
+			 !config_params[Attributes::Configuration].count(Attributes::UseDefDisambiguation))
+			resetAlertChoices();
+
 		oplist_size_spb->setValue((config_params[Attributes::Configuration][Attributes::OpListSize]).toUInt());
 		history_max_length_spb->setValue(config_params[Attributes::Configuration][Attributes::HistoryMaxLength].toUInt());
 
@@ -235,6 +257,7 @@ void GeneralConfigWidget::loadConfiguration()
 		hide_rel_name_chk->setChecked(config_params[Attributes::Configuration][Attributes::HideRelName]==Attributes::True);
 		hide_table_tags_chk->setChecked(config_params[Attributes::Configuration][Attributes::HideTableTags]==Attributes::True);
 		hide_sch_name_usr_types_chk->setChecked(config_params[Attributes::Configuration][Attributes::HideSchNameUserTypes]==Attributes::True);
+		hide_obj_shadows_chk->setChecked(config_params[Attributes::Configuration][Attributes::HideObjShadows]==Attributes::True);
 
 		source_editor_sel->setSelectedFile(config_params[Attributes::Configuration][Attributes::SourceEditorApp]);
 		source_editor_args_edt->setText(config_params[Attributes::Configuration][Attributes::SourceEditorArgs]);
@@ -244,6 +267,18 @@ void GeneralConfigWidget::loadConfiguration()
 		low_verbosity_chk->setChecked(config_params[Attributes::Configuration][Attributes::LowVerbosity]==Attributes::True);
 		escape_comments_chk->setChecked(config_params[Attributes::Configuration][Attributes::EscapeComment]==Attributes::True);
 
+		trunc_columns_data_chk->setChecked(config_params[Attributes::Configuration][Attributes::TruncateColumnData]==Attributes::True);
+		trunc_columns_data_spb->setValue(config_params[Attributes::Configuration][Attributes::ColumnTruncThreshold].toInt());
+
+		trunc_columns_data_spb->setEnabled(trunc_columns_data_chk->isChecked());
+		bytes_lbl->setEnabled(trunc_columns_data_chk->isChecked());
+
+		disable_inline_editor_chk->setChecked(config_params[Attributes::Configuration][Attributes::DisableInlineEditor]==Attributes::True);
+		disable_inline_editor_chk->setEnabled(disable_inline_editor_chk->isChecked());
+
+		hide_obj_sel_info_chk->setChecked(config_params[Attributes::Configuration][Attributes::HideObjectsSelInfo]==Attributes::True);
+		hide_cur_pos_zoom_info_chk->setChecked(config_params[Attributes::Configuration][Attributes::HideCurPosZoomInfo]==Attributes::True);
+
 		int ui_idx = ui_language_cmb->findData(config_params[Attributes::Configuration][Attributes::UiLanguage]);
 		ui_language_cmb->setCurrentIndex(ui_idx >= 0 ? ui_idx : 0);
 
@@ -251,7 +286,7 @@ void GeneralConfigWidget::loadConfiguration()
 			wgt->blockSignals(false);
 
 		widgets_geom.clear();
-		for(auto itr : config_params)
+		for(auto &itr : config_params)
 		{
 			if(itr.second.count(Attributes::XPos))
 			{
@@ -264,7 +299,8 @@ void GeneralConfigWidget::loadConfiguration()
 			}
 		}
 
-		this->applyConfiguration();
+		applyConfiguration();
+		setConfigurationChanged(false);
 	}
 	catch(Exception &e)
 	{
@@ -272,12 +308,12 @@ void GeneralConfigWidget::loadConfiguration()
 	}
 }
 
-void GeneralConfigWidget::addConfigurationParam(const QString &param, const attribs_map &attribs)
+void GeneralConfigWidget::setConfigurationSection(const QString &section_id, const attribs_map &params)
 {
-	BaseConfigWidget::addConfigurationParam(config_params, param, attribs);
+	BaseConfigWidget::setConfigurationSection(config_params, section_id, params);
 }
 
-void GeneralConfigWidget::removeConfigurationParam(const QRegularExpression &param_reg)
+void GeneralConfigWidget::removeConfigurationSection(const QRegularExpression &section_regex)
 {
 	std::map<QString, attribs_map>::iterator itr, itr_end;
 
@@ -286,7 +322,7 @@ void GeneralConfigWidget::removeConfigurationParam(const QRegularExpression &par
 
 	while(itr!=itr_end)
 	{
-		if(param_reg.match(itr->first).hasMatch())
+		if(section_regex.match(itr->first).hasMatch())
 		{
 			config_params.erase(itr);
 			itr=config_params.begin();
@@ -302,12 +338,16 @@ std::map<QString, attribs_map> GeneralConfigWidget::getConfigurationParams()
 	return config_params;
 }
 
+void GeneralConfigWidget::appendConfigurationSection(const QString &section_id, const attribs_map &params)
+{
+	BaseConfigWidget::appendConfigurationSection(config_params, section_id, params);
+}
+
 QString GeneralConfigWidget::getConfigurationParam(const QString &section_id, const QString &param_name)
 {
-  if(config_params.count(section_id) &&
-	 config_params[section_id].count(param_name))
-	return config_params[section_id][param_name];
-  else
+	if(config_params.count(section_id) &&	config_params[section_id].count(param_name))
+		return config_params[section_id][param_name];
+
 	return "";
 }
 
@@ -429,6 +469,7 @@ void GeneralConfigWidget::saveConfiguration()
 		config_params[Attributes::Configuration][Attributes::HideRelName]=(hide_rel_name_chk->isChecked() ? Attributes::True : "");
 		config_params[Attributes::Configuration][Attributes::HideTableTags]=(hide_table_tags_chk->isChecked() ? Attributes::True : "");
 		config_params[Attributes::Configuration][Attributes::HideSchNameUserTypes]=(hide_sch_name_usr_types_chk->isChecked() ? Attributes::True : "");
+		config_params[Attributes::Configuration][Attributes::HideObjShadows]=(hide_obj_shadows_chk->isChecked() ? Attributes::True : "");
 
 		config_params[Attributes::Configuration][Attributes::SourceEditorApp]=source_editor_sel->getSelectedFile();
 		config_params[Attributes::Configuration][Attributes::SourceEditorArgs]=source_editor_args_edt->text();
@@ -440,6 +481,14 @@ void GeneralConfigWidget::saveConfiguration()
 		config_params[Attributes::Configuration][Attributes::EscapeComment]=(escape_comments_chk->isChecked() ? Attributes::True : "");
 		config_params[Attributes::Configuration][Attributes::OldPgSqlVersions]=(old_pgsql_versions_chk->isChecked() ? Attributes::True : "");
 
+		config_params[Attributes::Configuration][Attributes::TruncateColumnData]=(trunc_columns_data_chk->isChecked() ? Attributes::True : "");
+		config_params[Attributes::Configuration][Attributes::ColumnTruncThreshold]=QString::number(trunc_columns_data_spb->value());
+		config_params[Attributes::Configuration][Attributes::DisableInlineEditor]=(trunc_columns_data_chk->isChecked() &&
+																																							 disable_inline_editor_chk->isChecked() ? Attributes::True : "");
+
+		config_params[Attributes::Configuration][Attributes::HideObjectsSelInfo]=(hide_obj_sel_info_chk->isChecked() ? Attributes::True : "");
+		config_params[Attributes::Configuration][Attributes::HideCurPosZoomInfo]=(hide_cur_pos_zoom_info_chk->isChecked() ? Attributes::True : "");
+
 		config_params[Attributes::Configuration][Attributes::File]="";
 		config_params[Attributes::Configuration][Attributes::RecentModels]="";
 
@@ -454,17 +503,14 @@ void GeneralConfigWidget::saveConfiguration()
 		while(itr!=itr_end)
 		{
 			//Checking if the current attribute is a file to be stored in a <session> tag
-			if((itr->first).contains(QRegularExpression(QString("(") + Attributes::File + QString(")([0-9]+)"))))
+			if((itr->first).contains(QRegularExpression("(" + Attributes::File + ")([0-9]+)")))
 			{
-				config_params[Attributes::Configuration][Attributes::File]+=
-						XmlParser::convertCharsToXMLEntities(schparser.getSourceCode(file_sch, itr->second));
+				config_params[Attributes::Configuration][Attributes::File] +=	schparser.getSourceCode(file_sch, itr->second);
 			}
 			//Checking if the current attribute is a file to be stored in a <recent-models> tag
-			else if(recent_mdl_idx < MaxRecentModels && (itr->first).contains(QRegularExpression(QString("(") + Attributes::Recent + QString(")([0-9]+)"))))
+			else if(recent_mdl_idx < MaxRecentModels && (itr->first).contains(QRegularExpression("(" + Attributes::Recent + ")([0-9]+)")))
 			{
-				config_params[Attributes::Configuration][Attributes::RecentModels]+=
-						XmlParser::convertCharsToXMLEntities(schparser.getSourceCode(file_sch, itr->second));
-
+				config_params[Attributes::Configuration][Attributes::RecentModels] +=	schparser.getSourceCode(file_sch, itr->second);
 				recent_mdl_idx++;
 			}
 			else if(itr->first==Attributes::Validator ||
@@ -508,6 +554,7 @@ void GeneralConfigWidget::saveConfiguration()
 		}
 
 		BaseConfigWidget::saveConfiguration(GlobalAttributes::GeneralConf, config_params);
+		setConfigurationChanged(false);
 	}
 	catch(Exception &e)
 	{
@@ -565,12 +612,16 @@ void GeneralConfigWidget::applyConfiguration()
 
 	BaseObjectView::setCompactViewEnabled(config_params[Attributes::Configuration][Attributes::CompactView]==Attributes::True);
 	BaseObjectView::setPlaceholderEnabled(use_placeholders_chk->isChecked());
+	BaseObjectView::setShadowHidden(hide_obj_shadows_chk->isChecked());
 
 	SQLExecutionWidget::setSQLHistoryMaxLength(history_max_length_spb->value());
 	ModelDatabaseDiffForm::setLowVerbosity(low_verbosity_chk->isChecked());
 	DatabaseImportForm::setLowVerbosity(low_verbosity_chk->isChecked());
 	ModelExportForm::setLowVerbosity(low_verbosity_chk->isChecked());
 	Connection::setIgnoreDbVersion(old_pgsql_versions_chk->isChecked());
+
+	PlainTextItemDelegate::setMaxDisplayLength(trunc_columns_data_chk->isChecked() ? trunc_columns_data_spb->value() : 0);
+	PlainTextItemDelegate::setTextEditorEnabled(trunc_columns_data_chk->isChecked() ? !disable_inline_editor_chk->isChecked() : false);
 }
 
 void GeneralConfigWidget::restoreDefaults()
@@ -581,8 +632,8 @@ void GeneralConfigWidget::restoreDefaults()
 		BaseConfigWidget::restoreDefaults(GlobalAttributes::XMLHighlightConf, true);
 		BaseConfigWidget::restoreDefaults(GlobalAttributes::SQLHighlightConf, true);
 		BaseConfigWidget::restoreDefaults(GlobalAttributes::SchHighlightConf, true);
-		this->loadConfiguration();
-		this->applyConfiguration();
+		loadConfiguration();
+		applyConfiguration();
 		setConfigurationChanged(true);
 	}
 	catch(Exception &e)
@@ -625,6 +676,14 @@ void GeneralConfigWidget::selectPaperSize()
 	height_spb->setVisible(visible);
 }
 
+void GeneralConfigWidget::setConfigurationChanged(bool changed)
+{
+	if(child_wgts.contains(sender()))
+		BaseConfigWidget::setConfigurationChanged(true);
+	else
+		BaseConfigWidget::setConfigurationChanged(changed);
+}
+
 void GeneralConfigWidget::resetDialogsSizes()
 {
 	Messagebox msg_box;
@@ -632,5 +691,13 @@ void GeneralConfigWidget::resetDialogsSizes()
 						Messagebox::ConfirmIcon, Messagebox::YesNoButtons);
 
 	if(msg_box.result() == QDialog::Accepted)
-	  widgets_geom.clear();
+		widgets_geom.clear();
+}
+
+void GeneralConfigWidget::resetAlertChoices()
+{
+	config_params[Attributes::Configuration][Attributes::AlertUnsavedModels] = Attributes::True;
+	config_params[Attributes::Configuration][Attributes::AlertOpenSqlTabs] = Attributes::True;
+	config_params[Attributes::Configuration][Attributes::UseDefDisambiguation] = Attributes::False;
+	reset_alerts_choices_tb->setEnabled(false);
 }
