@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,18 +17,18 @@
 */
 
 #include "pluginsconfigwidget.h"
+#include "guiutilsns.h"
 
 PluginsConfigWidget::PluginsConfigWidget(QWidget *parent) : BaseConfigWidget(parent)
 {
 	setupUi(this);
 
 	QGridLayout *grid=new QGridLayout(loaded_plugins_gb);
-	QDir dir=QDir(GlobalAttributes::getPluginsPath());
 
 	root_dir_sel = new FileSelectorWidget(this);
 	root_dir_sel->setToolTip(tr("pgModeler plugins directory"));
 	root_dir_sel->setReadOnly(true);
-	root_dir_sel->setFileMode(QFileDialog::Directory);
+	root_dir_sel->setDirectoryMode(true);
 	root_dir_sel->setSelectedFile(GlobalAttributes::getPluginsPath());
 	plugins_layout->insertWidget(1, root_dir_sel);
 
@@ -48,10 +48,10 @@ PluginsConfigWidget::PluginsConfigWidget(QWidget *parent) : BaseConfigWidget(par
 
 PluginsConfigWidget::~PluginsConfigWidget()
 {
-	while(!plugins.empty())
+	while(!plugins.isEmpty())
 	{
-		delete plugins.back();
-		plugins.pop_back();
+		delete plugins.last();
+		plugins.removeLast();
 	}
 }
 
@@ -63,77 +63,82 @@ void PluginsConfigWidget::showPluginInfo(int idx)
 void PluginsConfigWidget::loadConfiguration()
 {
 	std::vector<Exception> errors;
-	QString lib, plugin_name,
+	QString lib,
 			dir_plugins=GlobalAttributes::getPluginsPath() +
 						GlobalAttributes::DirSeparator;
 	QPluginLoader plugin_loader;
 	QStringList dir_list;
-	PgModelerPlugin *plugin=nullptr;
+	PgModelerGuiPlugin *plugin = nullptr;
 	QFileInfo fi;
+	unsigned row = 0;
+	QJsonObject metadata;
 
 	//The plugin loader must resolve all symbols otherwise return an error if some symbol is missing on library
 	plugin_loader.setLoadHints(QLibrary::ResolveAllSymbolsHint);
 
 	/* Configures an QDir instance to list only directories on the plugins/ subdir.
 		If the user does not put the plugin in it's directory the file is ignored  */
-	dir_list=QDir(dir_plugins, "*", QDir::Name, QDir::AllDirs | QDir::NoDotAndDotDot).entryList();
+	dir_list = QDir(dir_plugins, "*", QDir::Name, QDir::AllDirs | QDir::NoDotAndDotDot).entryList();
 
 	/* Removing the "schemas" dir from the list since it is reserved to shared schema files
 	 * for configuration file generation */
 	dir_list.removeAll(GlobalAttributes::SchemasDir);
 
-	while(!dir_list.isEmpty())
+	for(auto &plugin_name : dir_list)
 	{
-		plugin_name=dir_list.front();
-
 		/* Configures the basic path to the library on the form:
-
 		 [PLUGINS ROOT DIR]/[PLUGIN NAME]/lib[PLUGIN NAME].[EXTENSION] */
 #ifdef Q_OS_WIN
-		lib=dir_plugins + plugin_name +
-            GlobalAttributes::DirSeparator  +
-			plugin_name + ".dll";
+		lib = dir_plugins + plugin_name +
+					GlobalAttributes::DirSeparator  +
+					plugin_name + ".dll";
 #else
-#ifdef Q_OS_MAC
-		lib=dir_plugins + plugin_name +
-            GlobalAttributes::DirSeparator  +
-			"lib" + plugin_name + ".dylib";
-#else
-		lib=dir_plugins + plugin_name +
-			GlobalAttributes::DirSeparator  +
-			"lib" + plugin_name + ".so";
-#endif
+	#ifdef Q_OS_MAC
+			lib = dir_plugins + plugin_name +
+						GlobalAttributes::DirSeparator  +
+						"lib" + plugin_name + ".dylib";
+	#else
+			lib = dir_plugins + plugin_name +
+						GlobalAttributes::DirSeparator  +
+						"lib" + plugin_name + ".so";
+	#endif
 #endif
 
 		//Try to load the library
 		plugin_loader.setFileName(lib);
+		metadata = plugin_loader.metaData();
 
-		if(plugin_loader.load())
+		/* Ignores the plugin if it doesn't implement the correct interface,
+		 * in this case PgModelerGuiPlugin */
+		if(metadata["IID"] != "PgModelerGuiPlugin")
+			continue;
+
+		plugin = qobject_cast<PgModelerGuiPlugin *>(plugin_loader.instance());
+
+		if(plugin)
 		{
-			fi.setFile(lib);
-
 			//Inserts the loaded plugin on the vector
-			plugin = qobject_cast<PgModelerPlugin *>(plugin_loader.instance());
+			fi.setFile(lib);
 			plugin->setLibraryName(fi.fileName());
 			plugin->setPluginName(plugin_name);
-			plugins.push_back(plugin);
+			plugins.append(plugin);
 
 			plugins_tab->addRow();
 			plugins_tab->setCellText(plugin->getPluginTitle(), plugins_tab->getRowCount()-1, 0);
 			plugins_tab->setCellIcon(QIcon(plugin->getPluginIcon(plugin_name)), plugins_tab->getRowCount()-1, 0);
 			plugins_tab->setCellText(plugin->getPluginVersion(), plugins_tab->getRowCount()-1, 1);
 			plugins_tab->setCellText(fi.fileName(), plugins_tab->getRowCount()-1, 2);
+			plugins_tab->setRowData(QVariant::fromValue<void *>(plugin), row++);
 		}
 		else
 		{
 			errors.push_back(Exception(Exception::getErrorMessage(ErrorCode::PluginNotLoaded)
-																 .arg(dir_list.front())
+																 .arg(plugin_name)
 																 .arg(lib)
 																 .arg(plugin_loader.errorString()),
 																 ErrorCode::PluginNotLoaded, __PRETTY_FUNCTION__,__FILE__,__LINE__));
 		}
 
-		dir_list.pop_front();
 		plugins_tab->clearSelection();
 		plugins_tab->adjustColumnToContents(0);
 	}
@@ -144,8 +149,9 @@ void PluginsConfigWidget::loadConfiguration()
 
 void PluginsConfigWidget::initPlugins(MainWindow *main_window)
 {
-	std::vector<PgModelerPlugin *> inv_plugins;
+	QList<PgModelerGuiPlugin *> inv_plugins;
 	std::vector<Exception> errors;
+	int row_idx = -1;
 
 	for(auto &plugin : plugins)
 	{
@@ -155,7 +161,7 @@ void PluginsConfigWidget::initPlugins(MainWindow *main_window)
 		}
 		catch(Exception &e)
 		{
-			inv_plugins.push_back(plugin);
+			inv_plugins.append(plugin);
 			errors.push_back(e);
 		}
 	}
@@ -163,9 +169,14 @@ void PluginsConfigWidget::initPlugins(MainWindow *main_window)
 	// Erasing the plugins/actions related to the ones that failed to initialize
 	while(!inv_plugins.empty())
 	{
-		plugins.erase(std::find(plugins.begin(), plugins.end(), inv_plugins.back()));
-		delete inv_plugins.back();
-		inv_plugins.pop_back();
+		row_idx = plugins_tab->getRowIndex(QVariant::fromValue<void *>(inv_plugins.last()));
+		plugins.removeOne(inv_plugins.last());
+
+		if(row_idx >= 0)
+			plugins_tab->removeRow(row_idx);
+
+		delete inv_plugins.last();
+		inv_plugins.removeLast();
 	}
 
 	if(!errors.empty())
@@ -206,25 +217,24 @@ QList<QAction *> PluginsConfigWidget::getPluginsModelsActions()
 
 	for(auto &plugin : plugins)
 	{
-		if(plugin->getModelAction())
-			list.append(plugin->getModelAction());
+		if(plugin->getAction(PgModelerGuiPlugin::ModelAction))
+			list.append(plugin->getAction(PgModelerGuiPlugin::ModelAction));
 	}
 
 	return list;
 }
 
-QList<QAction *> PluginsConfigWidget::installPluginsActions(QMenu *conf_menu)
+void PluginsConfigWidget::installPluginsActions(QMenu *conf_menu, QList<QAction *> &tb_actions, QList<QToolButton *> &db_expl_btns)
 {
-	QList<QAction  *> tb_actions;
-
 	for(auto &plugin : plugins)
 	{
-		if(conf_menu && plugin->getConfigAction())
-			conf_menu->addAction(plugin->getConfigAction());
+		if(conf_menu && plugin->getAction(PgModelerGuiPlugin::ConfigAction))
+			conf_menu->addAction(plugin->getAction(PgModelerGuiPlugin::ConfigAction));
 
-		if(plugin->getToolbarAction())
-			tb_actions.append(plugin->getToolbarAction());
-	}	
+		if(plugin->getAction(PgModelerGuiPlugin::ToolbarAction))
+			tb_actions.append(plugin->getAction(PgModelerGuiPlugin::ToolbarAction));
 
-	return tb_actions;
+		if(plugin->getToolButton())
+			db_expl_btns.append(plugin->getToolButton());
+	}
 }
