@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,9 @@
 */
 
 #include "relationshipconfigwidget.h"
+#include "attributes.h"
+#include "utils/syntaxhighlighter.h"
+#include "relationshipview.h"
 
 std::map<QString, attribs_map> RelationshipConfigWidget::config_params;
 
@@ -39,7 +42,7 @@ RelationshipConfigWidget::RelationshipConfigWidget(QWidget * parent) : BaseConfi
 
 	for(int i=0; i < pattern_fields.size(); i++)
 	{
-		pattern_hl=new SyntaxHighlighter(pattern_fields[i], true);
+		pattern_hl=new SyntaxHighlighter(pattern_fields[i], true, false, font().pointSizeF());
 		pattern_hl->loadConfiguration(GlobalAttributes::getPatternHighlightConfPath());
 
 		connect(pattern_fields[i], &QPlainTextEdit::textChanged, this, &RelationshipConfigWidget::updatePattern);
@@ -65,7 +68,10 @@ RelationshipConfigWidget::RelationshipConfigWidget(QWidget * parent) : BaseConfi
 
 	connect(deferrable_chk, &QCheckBox::toggled, deferral_lbl, &QLabel::setEnabled);
 	connect(deferrable_chk, &QCheckBox::toggled, deferral_cmb, &QComboBox::setEnabled);
-	connect(deferrable_chk, &QCheckBox::toggled, this, &RelationshipConfigWidget::setConfigurationChanged);
+
+	connect(deferrable_chk, &QCheckBox::toggled, this, [this]() {
+		setConfigurationChanged(true);
+	});
 
 	connect(rel_type_cmb,  &QComboBox::currentIndexChanged, this,&RelationshipConfigWidget::fillNamePatterns);
 
@@ -116,7 +122,8 @@ void RelationshipConfigWidget::loadConfiguration()
 		patterns[Attributes::RelationshipPart]=config_params[Attributes::RelationshipPart];
 
 		fillNamePatterns();
-		this->applyConfiguration();
+		applyConfiguration();
+		setConfigurationChanged(false);
 	}
 	catch(Exception &e)
 	{
@@ -158,6 +165,7 @@ void RelationshipConfigWidget::saveConfiguration()
 		}
 
 		BaseConfigWidget::saveConfiguration(GlobalAttributes::RelationshipsConf, config_params);
+		setConfigurationChanged(false);
 	}
 	catch(Exception &e)
 	{
@@ -185,7 +193,7 @@ void RelationshipConfigWidget::restoreDefaults()
 	try
 	{
 		BaseConfigWidget::restoreDefaults(GlobalAttributes::RelationshipsConf, false);
-		this->loadConfiguration();
+		loadConfiguration();
 		setConfigurationChanged(true);
 	}
 	catch(Exception &e)
