@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
 */
 
 #include "resultsetmodel.h"
+#include "guiutilsns.h"
+#include <pgsqltypes/pgsqltype.h>
 
 ResultSetModel::ResultSetModel(ResultSet &res, Catalog &catalog, QObject *parent) : QAbstractTableModel(parent)
 {
@@ -29,14 +31,16 @@ ResultSetModel::ResultSetModel(ResultSet &res, Catalog &catalog, QObject *parent
 		std::map<int, QString> type_names;
 		int col = 0;
 
+		header_icons.clear();
 		col_count = res.getColumnCount();
 		row_count = res.getTupleCount();
+
 		insertColumns(0, col_count);
 		insertRows(0, row_count);
 
 		for(col=0; col < col_count; col++)
 		{
-			header_data.push_back(res.getColumnName(col));
+			header_data.push_back(" " + res.getColumnName(col));
 			type_ids.push_back(res.getColumnTypeId(col));
 		}
 
@@ -47,10 +51,7 @@ ResultSetModel::ResultSetModel(ResultSet &res, Catalog &catalog, QObject *parent
 				//Fills the current row with the values of current tuple
 				for(int col=0; col < col_count; col++)
 				{
-					if(res.isColumnBinaryFormat(col))
-						item_data.push_back(tr("[binary data]"));
-					else
-						item_data.push_back(res.getColumnValue(col));
+					item_data.push_back(res.getColumnValue(col));
 				}
 			}
 			while(res.accessTuple(ResultSet::NextTuple));
@@ -65,10 +66,15 @@ ResultSetModel::ResultSetModel(ResultSet &res, Catalog &catalog, QObject *parent
 		col = 0;
 
 		for(auto &tp : types)
-			type_names[tp[Attributes::Oid].toInt()]=tp[Attributes::Name];
+			type_names[tp[Attributes::Oid].toInt()] = tp[Attributes::Name];
 
+		int tp_id = 0;
 		for(col=0; col < col_count; col++)
-			tooltip_data.push_back(type_names[res.getColumnTypeId(col)]);
+		{
+			tp_id = res.getColumnTypeId(col);
+			header_icons.append(QIcon(GuiUtilsNs::getIconPath(getPgTypeIconName(type_names[tp_id]))));
+			tooltip_data.push_back(type_names[tp_id]);
+		}
 	}
 	catch(Exception &e)
 	{
@@ -120,6 +126,9 @@ QVariant ResultSetModel::headerData(int section, Qt::Orientation orientation, in
 		if(role == Qt::DisplayRole)
 			return header_data.at(section);
 
+		if(role == Qt::DecorationRole)
+			return header_icons.at(section);
+
 		if(role == Qt::ToolTipRole)
 			return tooltip_data.at(section);
 
@@ -177,3 +186,45 @@ bool ResultSetModel::isEmpty()
 	return (row_count <= 0);
 }
 
+QString ResultSetModel::getPgTypeIconName(const QString &type)
+{
+	try
+	{
+		static QStringList category_icons = {
+			/* OidType */ "typeoid",
+			/* PolymorphicType */ "typepolymorphic",
+			/* PseudoType */ "typepseudo",
+			/* TimezoneType */ "typetimezone",
+			/* DateTimeType */ "typedatetime",
+			/* NumericType */ "typenumeric",
+			/* IntegerType */ "typeinteger",
+			/* FloatPointType */ "typefloatpoint",
+			/* CharacterType */ "typecharacter",
+			/* NetworkType */ "typenetwork",
+			/* MonetaryType */ "typemonetary",
+			/* BinaryType */ "typebinary",
+			/* BooleanType */ "typeboolean",
+			/* GeometricType */ "typegeometric",
+			/* BitStringType */ "typebitstring",
+			/* TextSearchType */ "typetextsearch",
+			/* UuidType */ "typeuuid",
+			/* XmlType */ "typexml",
+			/* JsonType */ "typejson",
+			/* RangeType */ "typerange",
+			/* PostGiSType */ "typepostgis",
+			/* OtherType */ "typeother"
+			/* SerialType (not used) */
+			/* UserType (not used) */
+		};
+
+		PgSqlType pgtype = PgSqlType::parseString(type);
+		PgSqlType::TypeCategory cat = pgtype.getCategory();
+
+		return cat < category_icons.size() ?
+					 category_icons.at(cat) : "usertype";
+	}
+	catch(Exception &)
+	{
+		return "usertype";
+	}
+}
