@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 
 #include "ui_csvloadwidget.h"
 #include "fileselectorwidget.h"
-#include "csvparser.h"
+#include "csvdocument.h"
 
 class __libgui CsvLoadWidget : public QWidget, Ui::CsvLoadWidget {
 	private:
