@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,11 +25,12 @@
 #ifndef DONATE_WIDGET_H
 #define DONATE_WIDGET_H
 
+#include "guiglobal.h"
 #include <QWidget>
 #include <QGraphicsDropShadowEffect>
 #include "ui_donatewidget.h"
 
-class DonateWidget: public QWidget, public Ui::DonateWidget {
+class __libgui DonateWidget: public QWidget, public Ui::DonateWidget {
 	private:
 		Q_OBJECT
 		
