@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
 #define MODEL_OVERVIEW_WIDGET_H
 
 #include <QtWidgets>
-#include "exception.h"
 #include "ui_modeloverviewwidget.h"
 #include "modelwidget.h"
 
@@ -34,8 +33,6 @@ class __libgui ModelOverviewWidget: public QWidget, public Ui::ModelOverviewWidg
 	private:
 		Q_OBJECT
 
-		QScrollArea *scrollarea;
-
 		//! \brief Model which object are drawn on the overview widget
 		ModelWidget *model;
 
@@ -53,10 +50,15 @@ class __libgui ModelOverviewWidget: public QWidget, public Ui::ModelOverviewWidg
 
 		QSize pixmap_size;
 
+		//! \brief Indicates that the viewport frame is being moved by the user via mouse move event
+		bool moving_frame;
+
 		//! \brief Resize factor applied to overview widgets (default: 20% of the scene original size)
 		static constexpr double ResizeFactor = 0.20;
 
-		void mouseDoubleClickEvent(QMouseEvent *);
+		//! \brief The screen size threshold used to determine if the scroll area must be displayed or not
+		static constexpr double ScreenSzThreshold = 0.50;
+
 		void mousePressEvent(QMouseEvent *event);
 		void mouseReleaseEvent(QMouseEvent *event);
 		void mouseMoveEvent(QMouseEvent *event);
@@ -76,7 +78,7 @@ class __libgui ModelOverviewWidget: public QWidget, public Ui::ModelOverviewWidg
 		void updateOverview();
 
 		//! \brief Resizes the frame that represents the visualization window
-		void resizeWindowFrame();
+		void resizeViewportFrame();
 
 		//! \brief Resizes the whole overview widget
 		void resizeOverview();
