@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@
 
 #include "ui_objectdepsrefswidget.h"
 #include "dbobjects/baseobjectwidget.h"
-#include "baseobjectview.h"
 
 class __libgui ObjectDepsRefsWidget: public BaseObjectWidget, public Ui::ObjectDepsRefsWidget {
 	private:
@@ -45,9 +44,8 @@ class __libgui ObjectDepsRefsWidget: public BaseObjectWidget, public Ui::ObjectD
 		void applyConfiguration();
 
 	private slots:
-		void clearTables();
 		void updateObjectTables();
-		void handleItemSelection(QTableWidgetItem *item);
+		void handleItemSelection(const QModelIndex &index);
 };
 
 #endif
