@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,19 +28,21 @@
 #include "ui_sourcecodewidget.h"
 #include "dbobjects/baseobjectwidget.h"
 #include "numberedtexteditor.h"
-#include "widgets/findreplacewidget.h"
+#include "widgets/searchreplacewidget.h"
+#include "utils/syntaxhighlighter.h"
 
 class __libgui SourceCodeWidget: public BaseObjectWidget, public Ui::SourceCodeWidget {
 	private:
 		Q_OBJECT
 
 		NumberedTextEditor *sqlcode_txt,
-		*xmlcode_txt;
+				*xmlcode_txt;
 
 		SyntaxHighlighter *hl_sqlcode,
-		*hl_xmlcode;
+				*hl_xmlcode;
 
-		FindReplaceWidget *find_sql_wgt;
+		SearchReplaceWidget *search_sql_wgt,
+				*search_xml_wgt;
 
 	public:
 		SourceCodeWidget(QWidget * parent = nullptr);
