@@ -282,6 +282,7 @@ namespace Attributes {
 	HandlerFunc("handler"),
 	HasChanges("has-changes"),
 	Hashes("hashes"),
+	HasOptions("has-options"),
 	HbaFile("hba-file"),
 	Height("height"),
 	HideDescription("hide-description"),
@@ -290,6 +291,8 @@ namespace Attributes {
 	HideRelName("hide-rel-name"),
 	HideSchNameUserTypes("hide-schema-names-of-types"),
 	HideTableTags("hide-table-tags"),
+	HideObjectsSelInfo("hide-objects-sel-info"),
+	HideCurPosZoomInfo("hide-cur-pos-zoom-info"),
 	HighlightLines("highlight-lines"),
 	HighlightOrder("highlight-order"),
 	HistoryMaxLength("history-max-length"),
