@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,14 +37,18 @@ namespace Attributes {
 	ActiveLayers,
 	AdminOption,
 	AdminRoles,
+	AlertUnsavedModels,
+	AlertOpenSqlTabs,
 	Alias,
 	Alignment,
 	AlignObjsToGrid,
 	AllVersions,
+	AllowCompletion,
 	AllowConns,
 	AlterCmds,
 	AnalyzeFunc,
 	AncestorTable,
+	Any,
 	AppendAtEod,
 	AppendedSql,
 	Application,
@@ -72,6 +76,7 @@ namespace Attributes {
 	Bold,
 	BorderColor,
 	Bottom,
+	BlogPost,
 	Buffering,
 	BypassRls,
 	ByValue,
@@ -91,6 +96,7 @@ namespace Attributes {
 	CheckVersions,
 	CkConstr,
 	ClientEncoding,
+	CloseChar,
 	Code,
 	CodeCompletion,
 	ColIndexes,
@@ -104,6 +110,7 @@ namespace Attributes {
 	ColsComment,
 	Column,
 	ColumnAlias,
+	ColumnTruncThreshold,
 	Columns,
 	Command,
 	Commands,
@@ -188,6 +195,7 @@ namespace Attributes {
 	Dimension,
 	Directory,
 	DisableSmoothness,
+	DisableInlineEditor,
 	DisplayLineNumbers,
 	DockWidgets,
 	DomConstraint,
@@ -212,6 +220,7 @@ namespace Attributes {
 	ElementsCount,
 	EmptyPassword,
 	Encoding,
+	EnclosingChars,
 	Encrypted,
 	EndExp,
 	EnumType,
@@ -228,6 +237,7 @@ namespace Attributes {
 	ExecutionCost,
 	ExecutPriv,
 	ExistingValue,
+	ExpansionFactor,
 	Explicit,
 	Export,
 	ExportToFile,
@@ -237,6 +247,7 @@ namespace Attributes {
 	ExtAttribsPerPage,
 	ExtObjOids,
 	ExtraCondition,
+	ExtraInfo,
 	Factor,
 	FadedOut,
 	FadeInObjects,
@@ -286,12 +297,17 @@ namespace Attributes {
 	HandlesType,
 	HasChanges,
 	Hashes,
+	HasOptions,
 	HbaFile,
 	Height,
+	HideDescription,
 	HideExtAttribs,
+	HideObjShadows,
 	HideRelName,
 	HideSchNameUserTypes,
 	HideTableTags,
+	HideObjectsSelInfo,
+	HideCurPosZoomInfo,
 	HighlightLines,
 	HighlightOrder,
 	HistoryMaxLength,
@@ -323,6 +339,7 @@ namespace Attributes {
 	InitialCond,
 	InitialData,
 	InitialExp,
+	InkSaver,
 	InlineFunc,
 	InputDatabase,
 	InputDatabase,
@@ -333,6 +350,7 @@ namespace Attributes {
 	IntervalType,
 	InvertRangeSelTrigger,
 	IoCast,
+	IsExtType,
 	IsPartitioned,
 	IsTemplate,
 	Italic,
@@ -398,6 +416,7 @@ namespace Attributes {
 	Mode,
 	ModelAuthor,
 	Name,
+	NameColor,
 	NameFilter,
 	NameLabel,
 	NamePatterns,
@@ -414,12 +433,14 @@ namespace Attributes {
 	NotExtObject,
 	NotNull,
 	NullsFirst,
+	NullsNotDistinct,
 	Object,
 	ObjectFinder,
 	ObjectId,
 	Objects,
 	ObjectType,
 	ObjCount,
+	ObjRelationName,
 	ObjSelection,
 	ObjShadow,
 	Oid,
@@ -431,6 +452,7 @@ namespace Attributes {
 	OldVersion,
 	OpClass,
 	OpClasses,
+	OpenChar,
 	Operator,
 	OperatorFunc,
 	Operators,
@@ -559,6 +581,7 @@ namespace Attributes {
 	Rules,
 	SaveLastPosition,
 	SaveRestoreGeometry,
+	SceneRect,
 	Schema,
 	SchemaOid,
 	SearchPath,
@@ -586,6 +609,7 @@ namespace Attributes {
 	ShowPageDelimiters,
 	ShowSourcePane,
 	Signature,
+	SimpleCol,
 	SimpleExp,
 	SimplifiedObjCreation,
 	SinglePkColumn,
@@ -633,7 +657,6 @@ namespace Attributes {
 	SubtypeDiffFunc,
 	Superuser,
 	Symbol,
-	SyntaxHlTheme,
 	System,
 	Table,
 	TableTogglerButtons,
@@ -661,6 +684,7 @@ namespace Attributes {
 	Triggers,
 	True,
 	Truncate,
+	TruncateColumnData,
 	TruncatePriv,
 	TruncEvent,
 	Trusted,
@@ -689,7 +713,9 @@ namespace Attributes {
 	UqPattern,
 	UsagePriv,
 	UseChangelog,
+	UseColumns,
 	UseCurvedLines,
+	UseDefDisambiguation,
 	UsePlaceholders,
 	UseSignature,
 	UseSorting,
