@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,8 @@
 #include "schemaparser.h"
 #include "attributes.h"
 #include "utilsns.h"
-#include "xmlparser.h"
+#include "pgsqlversions.h"
+#include "exception.h"
 
 const char SchemaParser::CharComment='#';
 const char SchemaParser::CharLineEnd='\n';
@@ -35,36 +36,38 @@ const char SchemaParser::CharStartCompExpr='(';
 const char SchemaParser::CharEndCompExpr=')';
 const char SchemaParser::CharValueDelim='"';
 const char SchemaParser::CharValueOf='@';
+const char SchemaParser::CharToXmlEntity='&';
 
-const QString SchemaParser::TokenIf=QString("if");
-const QString SchemaParser::TokenThen=QString("then");
-const QString SchemaParser::TokenElse=QString("else");
-const QString SchemaParser::TokenEnd=QString("end");
-const QString SchemaParser::TokenOr=QString("or");
-const QString SchemaParser::TokenAnd=QString("and");
-const QString SchemaParser::TokenNot=QString("not");
-const QString SchemaParser::TokenSet=QString("set");
-const QString SchemaParser::TokenUnset=QString("unset");
+const QString SchemaParser::TokenIf("if");
+const QString SchemaParser::TokenThen("then");
+const QString SchemaParser::TokenElse("else");
+const QString SchemaParser::TokenEnd("end");
+const QString SchemaParser::TokenOr("or");
+const QString SchemaParser::TokenAnd("and");
+const QString SchemaParser::TokenNot("not");
+const QString SchemaParser::TokenSet("set");
+const QString SchemaParser::TokenUnset("unset");
 
-const QString SchemaParser::TokenMetaSp=QString("sp");
-const QString SchemaParser::TokenMetaBr=QString("br");
-const QString SchemaParser::TokenMetaTb=QString("tb");
-const QString SchemaParser::TokenMetaOb=QString("ob");
-const QString SchemaParser::TokenMetaCb=QString("cb");
-const QString SchemaParser::TokenMetaOc=QString("oc");
-const QString SchemaParser::TokenMetaCc=QString("cc");
-const QString SchemaParser::TokenMetaMs=QString("ms");
-const QString SchemaParser::TokenMetaPs=QString("ps");
-const QString SchemaParser::TokenMetaHs=QString("hs");
-const QString SchemaParser::TokenMetaAt=QString("at");
-const QString SchemaParser::TokenMetaDs=QString("ds");
+const QString SchemaParser::TokenMetaSp("sp");
+const QString SchemaParser::TokenMetaBr("br");
+const QString SchemaParser::TokenMetaTb("tb");
+const QString SchemaParser::TokenMetaOb("ob");
+const QString SchemaParser::TokenMetaCb("cb");
+const QString SchemaParser::TokenMetaOc("oc");
+const QString SchemaParser::TokenMetaCc("cc");
+const QString SchemaParser::TokenMetaMs("ms");
+const QString SchemaParser::TokenMetaPs("ps");
+const QString SchemaParser::TokenMetaHs("hs");
+const QString SchemaParser::TokenMetaAt("at");
+const QString SchemaParser::TokenMetaDs("ds");
+const QString SchemaParser::TokenMetaAm("am");
 
-const QString SchemaParser::TokenEqOper=QString("==");
-const QString SchemaParser::TokenNeOper=QString("!=");
-const QString SchemaParser::TokenGtOper=QString(">");
-const QString SchemaParser::TokenLtOper=QString("<");
-const QString SchemaParser::TokenGtEqOper=QString(">=");
-const QString SchemaParser::TokenLtEqOper=QString("<=");
+const QString SchemaParser::TokenEqOper("==");
+const QString SchemaParser::TokenNeOper("!=");
+const QString SchemaParser::TokenGtOper(">");
+const QString SchemaParser::TokenLtOper("<");
+const QString SchemaParser::TokenGtEqOper(">=");
+const QString SchemaParser::TokenLtEqOper("<=");
 
 // QRegularExpression::anchoredPattern is used to force the exact match
 const QRegularExpression SchemaParser::AttribRegExp(QRegularExpression::anchoredPattern("^([a-z])([a-z]*|(\\d)*|(\\-)*|(_)*)+"),
@@ -77,7 +80,7 @@ SchemaParser::SchemaParser()
 	pgsql_version=PgSqlVersions::DefaulVersion;
 }
 
-void SchemaParser::__setPgSQLVersion(const QString &pgsql_ver, bool ignore_db_version)
+void SchemaParser::setPgSQLVersion(const QString &pgsql_ver, bool ignore_db_version)
 {
 	try
 	{
@@ -89,10 +92,10 @@ void SchemaParser::__setPgSQLVersion(const QString &pgsql_ver, bool ignore_db_ve
 	}
 }
 
-void SchemaParser::setPgSQLVersion(const QString &pgsql_ver)
+/* void SchemaParser::setPgSQLVersion(const QString &pgsql_ver)
 {
 	__setPgSQLVersion(pgsql_ver, false);
-}
+} */
 
 QString SchemaParser::getPgSQLVersion()
 {
@@ -223,7 +226,7 @@ void SchemaParser::loadFile(const QString &filename)
 	}
 }
 
-QString SchemaParser::getAttribute()
+QString SchemaParser::getAttribute(bool &found_conv_to_xml)
 {
 	QString atrib, current_line;
 	bool start_attrib, end_attrib, error=false;
@@ -231,14 +234,31 @@ QString SchemaParser::getAttribute()
 	//Get the current line from the buffer
 	current_line=buffer[line];
 
-	/* Only start extracting an attribute if it starts with a {
+	/* Only start extracting an attribute if it starts with a { or &{
 		even if the current character is an attribute delimiter */
-	if(current_line[column]!=CharStartAttribute)
+	if((current_line[column] != CharStartAttribute &&
+			current_line[column] != CharToXmlEntity) ||
+
+		 (current_line[column] == CharToXmlEntity &&
+			column + 1 < current_line.length() -  1 &&
+			current_line[column + 1] != CharStartAttribute))
+	{
 		error=true;
+	}
 	else
 	{
-		//Step to the next column in the line
-		column++;
+		//If the starting char is the & we need to move two chars to reach the starting of the attribute name
+		if(current_line[column] == CharToXmlEntity)
+		{
+			found_conv_to_xml = true;
+			column += 2;
+		}
+		//Otherwise move only one char after {
+		else
+		{
+			found_conv_to_xml = false;
+			column++;
+		}
 
 		//Marks the flag indicating start of attribute
 		start_attrib=true;
@@ -446,13 +466,14 @@ bool SchemaParser::isSpecialCharacter(char chr)
 {
 	return chr==CharStartAttribute || chr==CharEndAttribute ||
 			chr==CharStartConditional || chr==CharStartMetachar ||
-			chr==CharStartPlainText || chr==CharEndPlainText;
+			chr==CharStartPlainText || chr==CharEndPlainText ||
+			chr==CharToXmlEntity;
 }
 
 bool SchemaParser::evaluateComparisonExpr()
 {
 	QString curr_line, attrib, value, oper, valid_op_chrs="=!<>fi", extra_error_msg;
-	bool error=false, end_eval=false, expr_is_true=true;
+	bool error = false, end_eval = false, expr_is_true = true, to_xml_entity = false;
 	static QStringList opers = { TokenEqOper, TokenNeOper, TokenGtOper,
 															 TokenLtOper, TokenGtEqOper, TokenLtEqOper };
 
@@ -472,18 +493,19 @@ bool SchemaParser::evaluateComparisonExpr()
 
 			switch(curr_line[column].toLatin1())
 			{
+				case CharToXmlEntity:
 				case CharStartAttribute:
 					/* Extract the attribute (the first element in the expression) only
-			 if the comparison operator and values aren't extracted */
+					 * if the comparison operator and values aren't extracted */
 					if(attrib.isEmpty() && oper.isEmpty() && value.isEmpty())
-						attrib=getAttribute();
+						attrib = getAttribute(to_xml_entity);
 					else
-						error=true;
+						error = true;
 				break;
 
 				case CharValueDelim:
 					/* Extract the value (the last element in the expression) only
-			 if the attribute and operator were extracted */
+					 * if the attribute and operator were extracted */
 					if(value.isEmpty() && !attrib.isEmpty() && !oper.isEmpty())
 					{
 						value+=curr_line[column++];
@@ -522,26 +544,30 @@ bool SchemaParser::evaluateComparisonExpr()
 					else
 					{
 						QVariant left_val, right_val;
+						QString attr_val = to_xml_entity ?
+									UtilsNs::convertToXmlEntities(attributes[attrib]) : attributes[attrib];
+
+						to_xml_entity = false;
 						value.remove(CharValueDelim);
 
 						//Evaluating the attribute value against the one captured on the expression without casting
 						if(oper.endsWith('f'))
 						{
-							left_val = QVariant(attributes[attrib].toFloat());
+							left_val = QVariant(attr_val.toFloat());
 							right_val = QVariant(value.toFloat());
 							oper.remove('f');
 							expr_is_true = getExpressionResult<float>(oper, left_val, right_val);
 						}
 						else if(oper.endsWith('i'))
 						{
-							left_val = QVariant(attributes[attrib].toInt());
+							left_val = QVariant(attr_val.toInt());
 							right_val = QVariant(value.toInt());
 							oper.remove('i');
 							expr_is_true = getExpressionResult<int>(oper, left_val, right_val);
 						}
 						else
 						{
-							left_val = QVariant(attributes[attrib]);
+							left_val = QVariant(attr_val);
 							right_val = QVariant(value);
 							expr_is_true = getExpressionResult<QString>(oper, left_val, right_val);
 						}
@@ -591,13 +617,12 @@ bool SchemaParser::evaluateComparisonExpr()
 
 void SchemaParser::defineAttribute()
 {
-	QString curr_line, attrib, value, new_attrib;
-	bool error=false, end_def=false, use_val_as_name=false;
+	QString curr_line = buffer[line], attrib, value, new_attrib;
+	bool error=false, end_def=false, use_val_as_name=false, to_xml_entity = false;
+	int curr_ln_idx = line;
 
 	try
 	{
-		curr_line=buffer[line];
-
 		while(!end_def && !error)
 		{
 			ignoreBlankChars(curr_line);
@@ -613,7 +638,7 @@ void SchemaParser::defineAttribute()
 					{
 						use_val_as_name=true;
 						column++;
-						new_attrib=getAttribute();
+						new_attrib = getAttribute(to_xml_entity);
 					}
 					else
 						error=true;
@@ -623,13 +648,14 @@ void SchemaParser::defineAttribute()
 					error=true;
 				break;
 
+				case CharToXmlEntity:
 				case CharStartAttribute:
 					if(new_attrib.isEmpty())
-						new_attrib=getAttribute();
+						new_attrib = getAttribute(to_xml_entity);
 					else
 					{
 						//Get the attribute in the middle of the value
-						attrib=getAttribute();
+						attrib = getAttribute(to_xml_entity);
 
 						if(attributes.count(attrib)==0 && !ignore_unk_atribs)
 						{
@@ -638,12 +664,19 @@ void SchemaParser::defineAttribute()
 											ErrorCode::UnkownAttribute,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 						}
 
-						value+=attributes[attrib];
+						value += to_xml_entity ? UtilsNs::convertToXmlEntities(attributes[attrib]) : attributes[attrib];
+						to_xml_entity = false;
 					}
 				break;
 
 				case CharStartPlainText:
-					value+=getPlainText();
+					value += getPlainText();
+
+					/* If we finished the extraction of a plain text
+					 * in which contains multiple lines, we need to stop
+					 * parsing the current line and return the defined
+					 * attribute */
+					end_def = line != curr_ln_idx;
 				break;
 
 				case CharStartMetachar:
@@ -690,7 +723,7 @@ void SchemaParser::defineAttribute()
 void SchemaParser::unsetAttribute()
 {
 	QString curr_line, attrib;
-	bool end_def=false;
+	bool end_def=false, to_xml_entity = false;
 
 	try
 	{
@@ -707,7 +740,7 @@ void SchemaParser::unsetAttribute()
 				break;
 
 				case CharStartAttribute:
-					attrib=getAttribute();
+					attrib = getAttribute(to_xml_entity);
 
 					if(attributes.count(attrib)==0 && !ignore_unk_atribs)
 					{
@@ -729,6 +762,7 @@ void SchemaParser::unsetAttribute()
 					throw Exception(Exception::getErrorMessage(ErrorCode::InvalidSyntax)
 									.arg(filename).arg(getCurrentLine()).arg(getCurrentColumn()),
 									ErrorCode::InvalidSyntax,__PRETTY_FUNCTION__,__FILE__,__LINE__);
+				break;
 			}
 		}
 	}
@@ -740,7 +774,8 @@ void SchemaParser::unsetAttribute()
 bool SchemaParser::evaluateExpression()
 {
 	QString current_line, cond, attrib, prev_cond;
-	bool error=false, end_eval=false, expr_is_true=true, attrib_true=true, comp_true=true;
+	bool error = false, end_eval = false, expr_is_true = true,
+			attrib_true = true, comp_true = true, to_xml_entity = false;
 	unsigned attrib_count=0, and_or_count=0;
 
 	try
@@ -798,8 +833,9 @@ bool SchemaParser::evaluateExpression()
 						and_or_count++;
 				break;
 
+				case CharToXmlEntity:
 				case CharStartAttribute:
-					attrib=getAttribute();
+					attrib = getAttribute(to_xml_entity);
 
 					//Raises an error if the attribute does is unknown
 					if(attributes.count(attrib)==0 && !ignore_unk_atribs)
@@ -898,7 +934,8 @@ QString SchemaParser::translateMetaCharacter(const QString &meta)
 														{ TokenMetaHs, QChar(CharComment) },
 														{ TokenMetaPs, QChar(CharStartConditional) },
 														{ TokenMetaAt, QChar(CharValueOf) },
-														{ TokenMetaDs, UtilsNs::DataSeparator } };
+														{ TokenMetaDs, UtilsNs::DataSeparator },
+														{ TokenMetaAm, QChar(CharToXmlEntity) }};
 
 	if(metas.count(meta)==0)
 	{
@@ -916,7 +953,7 @@ QString SchemaParser::getSourceCode(const QString & obj_name, attribs_map &attri
 	{
 		QString filename;
 
-		if(def_type==SqlCode)
+		/* if(def_type==SqlCode)
 		{
 			//Formats the filename
 			filename = GlobalAttributes::getSchemaFilePath(GlobalAttributes::SQLSchemaDir, obj_name);
@@ -928,8 +965,20 @@ QString SchemaParser::getSourceCode(const QString & obj_name, attribs_map &attri
 		else
 		{
 			filename = GlobalAttributes::getSchemaFilePath(GlobalAttributes::XMLSchemaDir, obj_name);
+			#warning "Fix me!"
 			return XmlParser::convertCharsToXMLEntities(getSourceCode(filename, attribs));
+		} */
+
+		if(def_type == SqlCode)
+		{
+			filename = GlobalAttributes::getSchemaFilePath(GlobalAttributes::SQLSchemaDir, obj_name);
+			attribs[Attributes::PgSqlVersion] = pgsql_version;
 		}
+		else
+			filename = GlobalAttributes::getSchemaFilePath(GlobalAttributes::XMLSchemaDir, obj_name);
+
+		//Try to get the object definitin from the specified path
+		return getSourceCode(filename, attribs);
 	}
 	catch(Exception &e)
 	{
@@ -950,10 +999,10 @@ void SchemaParser::ignoreEmptyAttributes(bool ignore)
 QString SchemaParser::getSourceCode(const attribs_map &attribs)
 {
 	QString object_def;
-	unsigned end_cnt, if_cnt;
-	int if_level, prev_if_level;
+	unsigned end_cnt = 0, if_cnt = 0;
+	int if_level = -1, prev_if_level = -1;
 	QString atrib, cond, prev_cond, word, meta;
-	bool error, if_expr;
+	bool error = false, if_expr = false, to_xml_entity = false;
 	char chr;
 	std::vector<bool> vet_expif, vet_tk_if, vet_tk_then, vet_tk_else;
 	std::map<int, std::vector<QString> > if_map, else_map;
@@ -1003,9 +1052,6 @@ QString SchemaParser::getSourceCode(const attribs_map &attribs)
 					else
 					{
 						//Converting the metacharacter drawn to the character that represents this
-						//chr=translateMetaCharacter(meta);
-						//meta="";
-						//meta+=chr;
 						meta = translateMetaCharacter(meta);
 
 						//If the parser is inside an 'if / else' extracting tokens
@@ -1031,10 +1077,11 @@ QString SchemaParser::getSourceCode(const attribs_map &attribs)
 
 				break;
 
-					//Attribute extraction
+				//Attribute extraction
+				case CharToXmlEntity:
 				case CharStartAttribute:
 				case CharEndAttribute:
-					atrib=getAttribute();
+					atrib = getAttribute(to_xml_entity);
 
 					//Checks if the attribute extracted belongs to the passed list of attributes
 					if(attributes.count(atrib)==0)
@@ -1055,16 +1102,18 @@ QString SchemaParser::getSourceCode(const attribs_map &attribs)
 						//If the parser evaluated the 'if' conditional and is inside the current if block
 						if(!(!if_expr && vet_tk_if[if_level] && !vet_tk_then[if_level]))
 						{
-							word=atrib;
-							atrib="";
-							atrib+=CharStartAttribute;
-							atrib+=word;
-							atrib+=CharEndAttribute;
+							word = atrib;
+							atrib = "";
+
+							if(to_xml_entity)
+								atrib += CharToXmlEntity;
+
+							atrib += CharStartAttribute;
+							atrib += word;
+							atrib += CharEndAttribute;
 
 							//If the parser is in the 'if' section
-							if(vet_tk_if[if_level] &&
-									vet_tk_then[if_level] &&
-									!vet_tk_else[if_level])
+							if(vet_tk_if[if_level] &&	vet_tk_then[if_level] &&	!vet_tk_else[if_level])
 								//Inserts the attribute value in the map of the words of current the 'if' section
 								if_map[if_level].push_back(atrib);
 							else if(vet_tk_else[if_level])
@@ -1085,7 +1134,8 @@ QString SchemaParser::getSourceCode(const attribs_map &attribs)
 
 						/* If the parser is not in an if / else, concatenates the value of the attribute
 							directly in definition in sql */
-						object_def+=attributes[atrib];
+						object_def += to_xml_entity ? UtilsNs::convertToXmlEntities(attributes[atrib]) : attributes[atrib];
+						to_xml_entity = false;
 					}
 				break;
 
@@ -1145,7 +1195,7 @@ QString SchemaParser::getSourceCode(const attribs_map &attribs)
 							/* When the %set instruction is ignored due to the fact of it being under a if expression evaluated as false
 							 * there's the need to create an empty representation of it in the set of attributes so in further expressions
 							 * evaluations the parser isn't broke by a unknow attribute exception */
-							atrib = getAttribute();
+							atrib = getAttribute(to_xml_entity);
 							if(attributes.count(atrib) == 0)
 								attributes[atrib]="";
 
@@ -1252,11 +1302,17 @@ QString SchemaParser::getSourceCode(const attribs_map &attribs)
 									word=(*itr);
 
 									//Check if the word is not an attribute
-									if(!word.isEmpty() && word.startsWith(CharStartAttribute) && word.endsWith(CharEndAttribute))
+									if(!word.isEmpty() &&
+										 (word.startsWith(CharStartAttribute) ||
+											word.startsWith(CharToXmlEntity)) &&
+										 word.endsWith(CharEndAttribute))
 									{
 										//If its an attribute, extracts the name between { } and checks if the same has empty value
-										atrib=word.mid(1, word.size()-2);
-										word=attributes[atrib];
+										bool conv_entity = word.startsWith(CharToXmlEntity);
+										int pos = conv_entity ? 2 : 1;
+
+										atrib = word.mid(pos, word.size() - (pos + 1));
+										word = conv_entity ? UtilsNs::convertToXmlEntities(attributes[atrib]) : attributes[atrib];
 
 										/* If the attribute has no value set and parser must not ignore empty values
 										raises an exception */
@@ -1268,8 +1324,10 @@ QString SchemaParser::getSourceCode(const attribs_map &attribs)
 										}
 									}
 
-									//Else, insert the work directly on the object definition
-									object_def+=word;
+									//Else, insert the word directly on the object definition
+									//object_def += to_xml_entity ? UtilsNs::convertToXmlEntities(word) : word;
+									//to_xml_entity = false;
+									object_def += word;
 								}
 								itr++;
 							}
@@ -1321,11 +1379,10 @@ QString SchemaParser::getSourceCode(const attribs_map &attribs)
 
 					//Extraction of pure text or simple words
 				default:
-					if(chr==CharStartPlainText ||
-							chr==CharEndPlainText)
+					if(chr == CharStartPlainText || chr == CharEndPlainText)
 						word=getPlainText();
 					else
-						word=getWord();
+						word = getWord();
 
 					//Case the parser is in 'if/else'
 					if(if_level>=0)
