@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,27 +29,33 @@
 #include <QString>
 
 namespace UtilsNs {
+	static const QString EntityAmp("&amp;"),
+	EntityLt("&lt;"),
+	EntityGt("&gt;"),
+	EntityQuot("&quot;"),
+	EntityApos("&apos;"),
+
 	//! \brief Default char for data/value separator for special usage
-	static const QString DataSeparator("•");
-
-	//! \brief Default char used as unescaped value start delimiter
-	static const QChar UnescValueStart='/';
-
-	//! \brief Default char used as unescaped value end delimiter
-	static const QChar	UnescValueEnd='/';
-
-	//! \brief Indicates the default wildcard character expected to be found in wildcard patterns
-	static const QChar WildcardChar('*');
-
-	//! \brief Indicates the character used to separate filter fields in the filtering string
-	static const QChar FilterSeparator = ':';
+	DataSeparator("•"),
 
 	//! \brief Indicates the wildcard filtering mode in the object listing
-	static const QString FilterWildcard("wildcard"),
+	FilterWildcard("wildcard"),
 
 	//! \brief Indicates the regexp (POSIX) filtering mode in the object listing
 	FilterRegExp("regexp");
 
+	//! \brief Default char used as unescaped value start delimiter
+	static const QChar UnescValueStart='/',
+
+	//! \brief Default char used as unescaped value end delimiter
+	UnescValueEnd='/',
+
+	//! \brief Indicates the default wildcard character expected to be found in wildcard patterns
+	WildcardChar('*'),
+
+	//! \brief Indicates the character used to separate filter fields in the filtering string
+	FilterSeparator = ':';
+
 	/*! \brief Writes the provided buffer to the file specified by its filename
 	 * Raises an exception in case of the file couldn,t be open */
 	extern __libutils void saveFile(const QString &filename, const QByteArray &buffer);
@@ -57,6 +63,14 @@ namespace UtilsNs {
 	/*! \brief Read the contents of the file specified by its filename returning its contents.
 	 * Raises an exception in case of the file couldn,t be open */
 	extern __libutils QByteArray loadFile(const QString &filename);
+
+	//! \brief Converts any chars (operators) < > " to the respective XML entities.
+	extern __libutils QString convertToXmlEntities(const QString value);
+
+	extern __libutils QString getStringHash(const QString &string);
+
+	//! \brief Replaces the sequence of chars [`'] by html tags <strong></strong> and [()] by <em></em>
+	extern __libutils QString formatMessage(const QString &msg);
 }
 
 #endif
