@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ class BaseObjectTest: public QObject {
   private slots:
     void quoteNameIfKeyword();
     void nameIsInvalidIfStartsWithNumber();
+		void dontFormatNameIfAlreadyQuoted();
 };
 
 void BaseObjectTest::quoteNameIfKeyword()
@@ -42,6 +43,11 @@ void BaseObjectTest::nameIsInvalidIfStartsWithNumber()
   QCOMPARE(BaseObject::isValidName("nameA"), true);
 }
 
+void BaseObjectTest::dontFormatNameIfAlreadyQuoted()
+{
+	QString name = "\"SomeObjName\"";
+	QCOMPARE(BaseObject::formatName(name), name);
+}
 
 QTEST_MAIN(BaseObjectTest)
 #include "baseobjecttest.moc"
