@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 */
 
 #include <QtTest/QtTest>
-#include "xmlparser.h"
+#include "utilsns.h"
+#include "exception.h"
 
 class XmlParserTest: public QObject {
 	private:
@@ -35,7 +36,7 @@ void XmlParserTest::correctlyConvertJsonValsToXmlEntites()
 
 	try
 	{
-		result = XmlParser::convertCharsToXMLEntities(value);
+		result = UtilsNs::convertToXmlEntities(value);
 		QCOMPARE(result, expected);
 	}
 	catch(Exception &e)
